@@ -1,10 +1,9 @@
 /**
  * @file hash_table.c
  * @author Radek Krejci <rkrejci@cesnet.cz>
- * @author Michal Vasko <mvasko@cesnet.cz>
- * @brief libyang generic hash table implementation
+ * @brief libyang dictionary for storing strings and generic hash table
  *
- * Copyright (c) 2015 - 2023 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2018 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -26,8 +25,80 @@
 #include "dict.h"
 #include "log.h"
 
-LIBYANG_API_DEF uint32_t
-lyht_hash_multi(uint32_t hash, const char *key_part, size_t len)
+#define LYDICT_MIN_SIZE 1024
+
+/**
+ * @brief Comparison callback for dictionary's hash table
+ *
+ * Implementation of ::lyht_value_equal_cb.
+ */
+static ly_bool
+lydict_val_eq(void *val1_p, void *val2_p, ly_bool UNUSED(mod), void *cb_data)
+{
+    LY_CHECK_ARG_RET(NULL, val1_p, val2_p, cb_data, 0);
+
+    const char *str1 = ((struct dict_rec *)val1_p)->value;
+    const char *str2 = ((struct dict_rec *)val2_p)->value;
+
+    LY_CHECK_ERR_RET(!str1, LOGARG(NULL, val1_p), 0);
+    LY_CHECK_ERR_RET(!str2, LOGARG(NULL, val2_p), 0);
+
+    if (strncmp(str1, str2, *(size_t *)cb_data) == 0) {
+        return 1;
+    }
+
+    return 0;
+}
+
+void
+lydict_init(struct dict_table *dict)
+{
+    LY_CHECK_ARG_RET(NULL, dict, );
+
+    dict->hash_tab = lyht_new(LYDICT_MIN_SIZE, sizeof(struct dict_rec), lydict_val_eq, NULL, 1);
+    LY_CHECK_ERR_RET(!dict->hash_tab, LOGINT(NULL), );
+    pthread_mutex_init(&dict->lock, NULL);
+}
+
+void
+lydict_clean(struct dict_table *dict)
+{
+    struct dict_rec *dict_rec = NULL;
+    struct ht_rec *rec = NULL;
+
+    LY_CHECK_ARG_RET(NULL, dict, );
+
+    for (uint32_t i = 0; i < dict->hash_tab->size; i++) {
+        /* get ith record */
+        rec = (struct ht_rec *)&dict->hash_tab->recs[i * dict->hash_tab->rec_size];
+        if (rec->hits == 1) {
+            /*
+             * this should not happen, all records inserted into
+             * dictionary are supposed to be removed using lydict_remove()
+             * before calling lydict_clean()
+             */
+            dict_rec = (struct dict_rec *)rec->val;
+            LOGWRN(NULL, "String \"%s\" not freed from the dictionary, refcount %d", dict_rec->value, dict_rec->refcount);
+            /* if record wasn't removed before free string allocated for that record */
+#ifdef NDEBUG
+            free(dict_rec->value);
+#endif
+        }
+    }
+
+    /* free table and destroy mutex */
+    lyht_free(dict->hash_tab);
+    pthread_mutex_destroy(&dict->lock);
+}
+
+/*
+ * Usage:
+ * - init hash to 0
+ * - repeatedly call dict_hash_multi(), provide hash from the last call
+ * - call dict_hash_multi() with key_part = NULL to finish the hash
+ */
+uint32_t
+dict_hash_multi(uint32_t hash, const char *key_part, size_t len)
 {
     uint32_t i;
 
@@ -46,25 +117,203 @@ lyht_hash_multi(uint32_t hash, const char *key_part, size_t len)
     return hash;
 }
 
-LIBYANG_API_DEF uint32_t
-lyht_hash(const char *key, size_t len)
+/*
+ * Bob Jenkin's one-at-a-time hash
+ * http://www.burtleburtle.net/bob/hash/doobs.html
+ *
+ * Spooky hash is faster, but it works only for little endian architectures.
+ */
+uint32_t
+dict_hash(const char *key, size_t len)
 {
     uint32_t hash;
 
-    hash = lyht_hash_multi(0, key, len);
-    return lyht_hash_multi(hash, NULL, len);
+    hash = dict_hash_multi(0, key, len);
+    return dict_hash_multi(hash, NULL, len);
 }
 
-struct ly_ht_rec *
+static ly_bool
+lydict_resize_val_eq(void *val1_p, void *val2_p, ly_bool mod, void *cb_data)
+{
+    LY_CHECK_ARG_RET(NULL, val1_p, val2_p, 0);
+
+    const char *str1 = ((struct dict_rec *)val1_p)->value;
+    const char *str2 = ((struct dict_rec *)val2_p)->value;
+
+    LY_CHECK_ERR_RET(!str1, LOGARG(NULL, val1_p), 0);
+    LY_CHECK_ERR_RET(!str2, LOGARG(NULL, val2_p), 0);
+
+    if (mod) {
+        /* used when inserting new values */
+        if (strcmp(str1, str2) == 0) {
+            return 1;
+        }
+    } else {
+        /* used when finding the original value again in the resized table */
+        return lydict_val_eq(val1_p, val2_p, mod, cb_data);
+    }
+
+    return 0;
+}
+
+API LY_ERR
+lydict_remove(const struct ly_ctx *ctx, const char *value)
+{
+    LY_ERR ret = LY_SUCCESS;
+    size_t len;
+    uint32_t hash;
+    struct dict_rec rec, *match = NULL;
+    char *val_p;
+
+    if (!ctx || !value) {
+        return LY_SUCCESS;
+    }
+
+    LOGDBG(LY_LDGDICT, "removing \"%s\"", value);
+
+    len = strlen(value);
+    hash = dict_hash(value, len);
+
+    /* create record for lyht_find call */
+    rec.value = (char *)value;
+    rec.refcount = 0;
+
+    pthread_mutex_lock((pthread_mutex_t *)&ctx->dict.lock);
+    /* set len as data for compare callback */
+    lyht_set_cb_data(ctx->dict.hash_tab, (void *)&len);
+    /* check if value is already inserted */
+    ret = lyht_find(ctx->dict.hash_tab, &rec, hash, (void **)&match);
+
+    if (ret == LY_SUCCESS) {
+        LY_CHECK_ERR_GOTO(!match, LOGINT(ctx), finish);
+
+        /* if value is already in dictionary, decrement reference counter */
+        match->refcount--;
+        if (match->refcount == 0) {
+            /*
+             * remove record
+             * save pointer to stored string before lyht_remove to
+             * free it after it is removed from hash table
+             */
+            val_p = match->value;
+            ret = lyht_remove_with_resize_cb(ctx->dict.hash_tab, &rec, hash, lydict_resize_val_eq);
+            free(val_p);
+            LY_CHECK_ERR_GOTO(ret, LOGINT(ctx), finish);
+        }
+    } else if (ret == LY_ENOTFOUND) {
+        LOGERR(ctx, LY_ENOTFOUND, "Value \"%s\" was not found in the dictionary.", value);
+    } else {
+        LOGINT(ctx);
+    }
+
+finish:
+    pthread_mutex_unlock((pthread_mutex_t *)&ctx->dict.lock);
+    return ret;
+}
+
+LY_ERR
+dict_insert(const struct ly_ctx *ctx, char *value, size_t len, ly_bool zerocopy, const char **str_p)
+{
+    LY_ERR ret = LY_SUCCESS;
+    struct dict_rec *match = NULL, rec;
+    uint32_t hash;
+
+    LOGDBG(LY_LDGDICT, "inserting \"%.*s\"", (int)len, value);
+
+    hash = dict_hash(value, len);
+    /* set len as data for compare callback */
+    lyht_set_cb_data(ctx->dict.hash_tab, (void *)&len);
+    /* create record for lyht_insert */
+    rec.value = value;
+    rec.refcount = 1;
+
+    ret = lyht_insert_with_resize_cb(ctx->dict.hash_tab, (void *)&rec, hash, lydict_resize_val_eq, (void **)&match);
+    if (ret == LY_EEXIST) {
+        match->refcount++;
+        if (zerocopy) {
+            free(value);
+        }
+        ret = LY_SUCCESS;
+    } else if (ret == LY_SUCCESS) {
+        if (!zerocopy) {
+            /*
+             * allocate string for new record
+             * record is already inserted in hash table
+             */
+            match->value = malloc(sizeof *match->value * (len + 1));
+            LY_CHECK_ERR_RET(!match->value, LOGMEM(ctx), LY_EMEM);
+            if (len) {
+                memcpy(match->value, value, len);
+            }
+            match->value[len] = '\0';
+        }
+    } else {
+        /* lyht_insert returned error */
+        if (zerocopy) {
+            free(value);
+        }
+        return ret;
+    }
+
+    if (str_p) {
+        *str_p = match->value;
+    }
+
+    return ret;
+}
+
+API LY_ERR
+lydict_insert(const struct ly_ctx *ctx, const char *value, size_t len, const char **str_p)
+{
+    LY_ERR result;
+
+    LY_CHECK_ARG_RET(ctx, ctx, str_p, LY_EINVAL);
+
+    if (!value) {
+        *str_p = NULL;
+        return LY_SUCCESS;
+    }
+
+    if (!len) {
+        len = strlen(value);
+    }
+
+    pthread_mutex_lock((pthread_mutex_t *)&ctx->dict.lock);
+    result = dict_insert(ctx, (char *)value, len, 0, str_p);
+    pthread_mutex_unlock((pthread_mutex_t *)&ctx->dict.lock);
+
+    return result;
+}
+
+API LY_ERR
+lydict_insert_zc(const struct ly_ctx *ctx, char *value, const char **str_p)
+{
+    LY_ERR result;
+
+    LY_CHECK_ARG_RET(ctx, ctx, str_p, LY_EINVAL);
+
+    if (!value) {
+        *str_p = NULL;
+        return LY_SUCCESS;
+    }
+
+    pthread_mutex_lock((pthread_mutex_t *)&ctx->dict.lock);
+    result = dict_insert(ctx, value, strlen(value), 1, str_p);
+    pthread_mutex_unlock((pthread_mutex_t *)&ctx->dict.lock);
+
+    return result;
+}
+
+struct ht_rec *
 lyht_get_rec(unsigned char *recs, uint16_t rec_size, uint32_t idx)
 {
-    return (struct ly_ht_rec *)&recs[idx * rec_size];
+    return (struct ht_rec *)&recs[idx * rec_size];
 }
 
-LIBYANG_API_DEF struct ly_ht *
+struct hash_table *
 lyht_new(uint32_t size, uint16_t val_size, lyht_value_equal_cb val_equal, void *cb_data, uint16_t resize)
 {
-    struct ly_ht *ht;
+    struct hash_table *ht;
 
     /* check that 2^x == size (power of 2) */
     assert(size && !(size & (size - 1)));
@@ -85,7 +334,7 @@ lyht_new(uint32_t size, uint16_t val_size, lyht_value_equal_cb val_equal, void *
     ht->cb_data = cb_data;
     ht->resize = resize;
 
-    ht->rec_size = (sizeof(struct ly_ht_rec) - 1) + val_size;
+    ht->rec_size = (sizeof(struct ht_rec) - 1) + val_size;
     /* allocate the records correctly */
     ht->recs = calloc(size, ht->rec_size);
     LY_CHECK_ERR_RET(!ht->recs, free(ht); LOGMEM(NULL), NULL);
@@ -93,8 +342,8 @@ lyht_new(uint32_t size, uint16_t val_size, lyht_value_equal_cb val_equal, void *
     return ht;
 }
 
-LIBYANG_API_DEF lyht_value_equal_cb
-lyht_set_cb(struct ly_ht *ht, lyht_value_equal_cb new_val_equal)
+lyht_value_equal_cb
+lyht_set_cb(struct hash_table *ht, lyht_value_equal_cb new_val_equal)
 {
     lyht_value_equal_cb prev;
 
@@ -103,8 +352,8 @@ lyht_set_cb(struct ly_ht *ht, lyht_value_equal_cb new_val_equal)
     return prev;
 }
 
-LIBYANG_API_DEF void *
-lyht_set_cb_data(struct ly_ht *ht, void *new_cb_data)
+void *
+lyht_set_cb_data(struct hash_table *ht, void *new_cb_data)
 {
     void *prev;
 
@@ -113,14 +362,14 @@ lyht_set_cb_data(struct ly_ht *ht, void *new_cb_data)
     return prev;
 }
 
-LIBYANG_API_DEF struct ly_ht *
-lyht_dup(const struct ly_ht *orig)
+struct hash_table *
+lyht_dup(const struct hash_table *orig)
 {
-    struct ly_ht *ht;
+    struct hash_table *ht;
 
     LY_CHECK_ARG_RET(NULL, orig, NULL);
 
-    ht = lyht_new(orig->size, orig->rec_size - (sizeof(struct ly_ht_rec) - 1), orig->val_equal, orig->cb_data, orig->resize ? 1 : 0);
+    ht = lyht_new(orig->size, orig->rec_size - (sizeof(struct ht_rec) - 1), orig->val_equal, orig->cb_data, orig->resize ? 1 : 0);
     if (!ht) {
         return NULL;
     }
@@ -131,26 +380,13 @@ lyht_dup(const struct ly_ht *orig)
     return ht;
 }
 
-LIBYANG_API_DEF void
-lyht_free(struct ly_ht *ht, void (*val_free)(void *val_p))
+void
+lyht_free(struct hash_table *ht)
 {
-    struct ly_ht_rec *rec;
-    uint32_t i;
-
-    if (!ht) {
-        return;
+    if (ht) {
+        free(ht->recs);
+        free(ht);
     }
-
-    if (val_free) {
-        for (i = 0; i < ht->size; ++i) {
-            rec = lyht_get_rec(ht->recs, ht->rec_size, i);
-            if (rec->hits > 0) {
-                val_free(&rec->val);
-            }
-        }
-    }
-    free(ht->recs);
-    free(ht);
 }
 
 /**
@@ -161,9 +397,9 @@ lyht_free(struct ly_ht *ht, void (*val_free)(void *val_p))
  * @return LY_ERR value.
  */
 static LY_ERR
-lyht_resize(struct ly_ht *ht, int operation)
+lyht_resize(struct hash_table *ht, int operation)
 {
-    struct ly_ht_rec *rec;
+    struct ht_rec *rec;
     unsigned char *old_recs;
     uint32_t i, old_size;
 
@@ -190,7 +426,6 @@ lyht_resize(struct ly_ht *ht, int operation)
         rec = lyht_get_rec(old_recs, ht->rec_size, i);
         if (rec->hits > 0) {
             LY_ERR ret = lyht_insert(ht, rec->val, rec->hash, NULL);
-
             assert(!ret);
             (void)ret;
         }
@@ -211,9 +446,9 @@ lyht_resize(struct ly_ht *ht, int operation)
  * @return LY_ENOTFOUND hash not found, returned the record where it would be inserted.
  */
 static LY_ERR
-lyht_find_first(struct ly_ht *ht, uint32_t hash, struct ly_ht_rec **rec_p)
+lyht_find_first(struct hash_table *ht, uint32_t hash, struct ht_rec **rec_p)
 {
-    struct ly_ht_rec *rec;
+    struct ht_rec *rec;
     uint32_t i, idx;
 
     if (rec_p) {
@@ -263,9 +498,9 @@ lyht_find_first(struct ly_ht *ht, uint32_t hash, struct ly_ht_rec **rec_p)
  * @return LY_ENOTFOUND when hash collision not found, \p last points to the record where it would be inserted.
  */
 static LY_ERR
-lyht_find_collision(struct ly_ht *ht, struct ly_ht_rec **last, struct ly_ht_rec *first)
+lyht_find_collision(struct hash_table *ht, struct ht_rec **last, struct ht_rec *first)
 {
-    struct ly_ht_rec *empty = NULL;
+    struct ht_rec *empty = NULL;
     uint32_t i, idx;
 
     assert(last && *last);
@@ -316,10 +551,10 @@ lyht_find_collision(struct ly_ht *ht, struct ly_ht_rec **last, struct ly_ht_rec
  * @return LY_SUCCESS if record was found.
  */
 static LY_ERR
-lyht_find_rec(struct ly_ht *ht, void *val_p, uint32_t hash, ly_bool mod, struct ly_ht_rec **crec_p, uint32_t *col,
-        struct ly_ht_rec **rec_p)
+lyht_find_rec(struct hash_table *ht, void *val_p, uint32_t hash, ly_bool mod, struct ht_rec **crec_p, uint32_t *col,
+        struct ht_rec **rec_p)
 {
-    struct ly_ht_rec *rec, *crec;
+    struct ht_rec *rec, *crec;
     uint32_t i, c;
     LY_ERR r;
 
@@ -372,10 +607,10 @@ lyht_find_rec(struct ly_ht *ht, void *val_p, uint32_t hash, ly_bool mod, struct
     return LY_ENOTFOUND;
 }
 
-LIBYANG_API_DEF LY_ERR
-lyht_find(struct ly_ht *ht, void *val_p, uint32_t hash, void **match_p)
+LY_ERR
+lyht_find(struct hash_table *ht, void *val_p, uint32_t hash, void **match_p)
 {
-    struct ly_ht_rec *rec;
+    struct ht_rec *rec;
 
     lyht_find_rec(ht, val_p, hash, 0, NULL, NULL, &rec);
 
@@ -385,40 +620,27 @@ lyht_find(struct ly_ht *ht, void *val_p, uint32_t hash, void **match_p)
     return rec ? LY_SUCCESS : LY_ENOTFOUND;
 }
 
-LIBYANG_API_DEF LY_ERR
-lyht_find_next_with_collision_cb(struct ly_ht *ht, void *val_p, uint32_t hash,
-        lyht_value_equal_cb collision_val_equal, void **match_p)
+LY_ERR
+lyht_find_next(struct hash_table *ht, void *val_p, uint32_t hash, void **match_p)
 {
-    struct ly_ht_rec *rec, *crec;
+    struct ht_rec *rec, *crec;
     uint32_t i, c;
     LY_ERR r;
 
-    /* find the record of the previously found value */
+    /* found the record of the previously found value */
     if (lyht_find_rec(ht, val_p, hash, 1, &crec, &i, &rec)) {
         /* not found, cannot happen */
         LOGINT_RET(NULL);
     }
 
-    /* go through collisions and find the next one after the previous one */
+    /* go through collisions and find next one after the previous one */
     c = crec->hits;
     for (++i; i < c; ++i) {
         r = lyht_find_collision(ht, &rec, crec);
         assert(!r);
         (void)r;
 
-        if (rec->hash != hash) {
-            continue;
-        }
-
-        if (collision_val_equal) {
-            if (collision_val_equal(val_p, &rec->val, 0, ht->cb_data)) {
-                /* even the value matches */
-                if (match_p) {
-                    *match_p = rec->val;
-                }
-                return LY_SUCCESS;
-            }
-        } else if (ht->val_equal(val_p, &rec->val, 0, ht->cb_data)) {
+        if ((rec->hash == hash) && ht->val_equal(val_p, &rec->val, 0, ht->cb_data)) {
             /* even the value matches */
             if (match_p) {
                 *match_p = rec->val;
@@ -431,18 +653,12 @@ lyht_find_next_with_collision_cb(struct ly_ht *ht, void *val_p, uint32_t hash,
     return LY_ENOTFOUND;
 }
 
-LIBYANG_API_DEF LY_ERR
-lyht_find_next(struct ly_ht *ht, void *val_p, uint32_t hash, void **match_p)
-{
-    return lyht_find_next_with_collision_cb(ht, val_p, hash, NULL, match_p);
-}
-
-LIBYANG_API_DEF LY_ERR
-lyht_insert_with_resize_cb(struct ly_ht *ht, void *val_p, uint32_t hash, lyht_value_equal_cb resize_val_equal,
+LY_ERR
+lyht_insert_with_resize_cb(struct hash_table *ht, void *val_p, uint32_t hash, lyht_value_equal_cb resize_val_equal,
         void **match_p)
 {
     LY_ERR r, ret = LY_SUCCESS;
-    struct ly_ht_rec *rec, *crec = NULL;
+    struct ht_rec *rec, *crec = NULL;
     int32_t i;
     lyht_value_equal_cb old_val_equal = NULL;
 
@@ -483,7 +699,7 @@ lyht_insert_with_resize_cb(struct ly_ht *ht, void *val_p, uint32_t hash, lyht_va
     }
     rec->hash = hash;
     rec->hits = 1;
-    memcpy(&rec->val, val_p, ht->rec_size - (sizeof(struct ly_ht_rec) - 1));
+    memcpy(&rec->val, val_p, ht->rec_size - (sizeof(struct ht_rec) - 1));
     if (match_p) {
         *match_p = (void *)&rec->val;
     }
@@ -524,16 +740,16 @@ lyht_insert_with_resize_cb(struct ly_ht *ht, void *val_p, uint32_t hash, lyht_va
     return ret;
 }
 
-LIBYANG_API_DEF LY_ERR
-lyht_insert(struct ly_ht *ht, void *val_p, uint32_t hash, void **match_p)
+LY_ERR
+lyht_insert(struct hash_table *ht, void *val_p, uint32_t hash, void **match_p)
 {
     return lyht_insert_with_resize_cb(ht, val_p, hash, NULL, match_p);
 }
 
-LIBYANG_API_DEF LY_ERR
-lyht_remove_with_resize_cb(struct ly_ht *ht, void *val_p, uint32_t hash, lyht_value_equal_cb resize_val_equal)
+LY_ERR
+lyht_remove_with_resize_cb(struct hash_table *ht, void *val_p, uint32_t hash, lyht_value_equal_cb resize_val_equal)
 {
-    struct ly_ht_rec *rec, *crec;
+    struct ht_rec *rec, *crec;
     int32_t i;
     ly_bool first_matched = 0;
     LY_ERR r, ret = LY_SUCCESS;
@@ -613,32 +829,8 @@ lyht_remove_with_resize_cb(struct ly_ht *ht, void *val_p, uint32_t hash, lyht_va
     return ret;
 }
 
-LIBYANG_API_DEF LY_ERR
-lyht_remove(struct ly_ht *ht, void *val_p, uint32_t hash)
+LY_ERR
+lyht_remove(struct hash_table *ht, void *val_p, uint32_t hash)
 {
     return lyht_remove_with_resize_cb(ht, val_p, hash, NULL);
 }
-
-LIBYANG_API_DEF uint32_t
-lyht_get_fixed_size(uint32_t item_count)
-{
-    uint32_t i, size = 0;
-
-    /* detect number of upper zero bits in the items' counter value ... */
-    for (i = (sizeof item_count * CHAR_BIT) - 1; i > 0; i--) {
-        size = item_count << i;
-        size = size >> i;
-        if (size == item_count) {
-            break;
-        }
-    }
-    assert(i);
-
-    /* ... and then we convert it to the position of the highest non-zero bit ... */
-    i = (sizeof item_count * CHAR_BIT) - i;
-
-    /* ... and by using it to shift 1 to the left we get the closest sufficient hash table size */
-    size = 1 << i;
-
-    return size;
-}
