@@ -24,6 +24,12 @@
 #include "json.h"
 #include "tree_schema_internal.h"
 
+#define JSON_PUSH_STATUS_RET(CTX, STATUS) \
+    LY_CHECK_RET(ly_set_add(&CTX->status, (void *)(uintptr_t)(STATUS), 1, NULL))
+
+#define JSON_POP_STATUS_RET(CTX) \
+    assert(CTX->status.count); CTX->status.count--;
+
 const char *
 lyjson_token2str(enum LYJSON_PARSER_STATUS status)
 {
@@ -72,7 +78,7 @@ skip_ws(struct lyjson_ctx *jsonctx)
         ly_in_skip(jsonctx->in, 1);
     }
     if (*jsonctx->in->current == '\0') {
-        LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_END);
+        JSON_PUSH_STATUS_RET(jsonctx, LYJSON_END);
     }
 
     return LY_SUCCESS;
@@ -164,7 +170,6 @@ lyjson_string_(struct lyjson_ctx *jsonctx)
              * (one-char) entities and character references */
             if (len + offset + 4 >= size) {
                 size_t increment;
-
                 for (increment = BUFSIZE_STEP; len + offset + 4 >= size + increment; increment += BUFSIZE_STEP) {}
                 buf = ly_realloc(buf, size + increment);
                 LY_CHECK_ERR_RET(!buf, LOGMEM(jsonctx->ctx), LY_EMEM);
@@ -313,7 +318,7 @@ lyjson_string(struct lyjson_ctx *jsonctx)
 {
     LY_CHECK_RET(lyjson_string_(jsonctx));
 
-    LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_STRING);
+    JSON_PUSH_STATUS_RET(jsonctx, LYJSON_STRING);
     LY_CHECK_RET(lyjson_check_next(jsonctx));
 
     return LY_SUCCESS;
@@ -489,7 +494,7 @@ lyjson_exp_number(const struct ly_ctx *ctx, const char *in, const char *exponent
     /* Final position of decimal point in the buf. */
     int32_t dp_position;
     /* Exponent as integer. */
-    long long e_val;
+    long long int e_val;
     /* Byte for the decimal point. */
     int8_t dot;
     /* Required additional byte for the minus sign. */
@@ -713,7 +718,7 @@ invalid_character:
     }
     ly_in_skip(jsonctx->in, offset);
 
-    LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_NUMBER);
+    JSON_PUSH_STATUS_RET(jsonctx, LYJSON_NUMBER);
     LY_CHECK_RET(lyjson_check_next(jsonctx));
 
     return LY_SUCCESS;
@@ -753,21 +758,23 @@ lyjson_object(struct lyjson_ctx *jsonctx)
         /* empty object */
         ly_in_skip(jsonctx->in, 1);
         lyjson_ctx_set_value(jsonctx, NULL, 0, 0);
-        LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_OBJECT_EMPTY);
+        JSON_PUSH_STATUS_RET(jsonctx, LYJSON_OBJECT_EMPTY);
         return LY_SUCCESS;
     }
 
     LY_CHECK_RET(lyjson_object_name(jsonctx));
 
     /* output data are set by lyjson_string_() */
-    LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_OBJECT);
+    JSON_PUSH_STATUS_RET(jsonctx, LYJSON_OBJECT);
 
     return LY_SUCCESS;
 }
 
-/**
+/*
  * @brief Process JSON array envelope
  *
+ *
+ *
  * @param[in] jsonctx JSON parser context
  * @return LY_SUCCESS or LY_EMEM
  */
@@ -779,9 +786,9 @@ lyjson_array(struct lyjson_ctx *jsonctx)
     if (*jsonctx->in->current == ']') {
         /* empty array */
         ly_in_skip(jsonctx->in, 1);
-        LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_ARRAY_EMPTY);
+        JSON_PUSH_STATUS_RET(jsonctx, LYJSON_ARRAY_EMPTY);
     } else {
-        LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_ARRAY);
+        JSON_PUSH_STATUS_RET(jsonctx, LYJSON_ARRAY);
     }
 
     /* erase previous values, array has no value on its own */
@@ -801,21 +808,21 @@ lyjson_value(struct lyjson_ctx *jsonctx)
         /* false */
         lyjson_ctx_set_value(jsonctx, jsonctx->in->current, ly_strlen_const("false"), 0);
         ly_in_skip(jsonctx->in, ly_strlen_const("false"));
-        LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_FALSE);
+        JSON_PUSH_STATUS_RET(jsonctx, LYJSON_FALSE);
         LY_CHECK_RET(lyjson_check_next(jsonctx));
 
     } else if ((*jsonctx->in->current == 't') && !strncmp(jsonctx->in->current, "true", ly_strlen_const("true"))) {
         /* true */
         lyjson_ctx_set_value(jsonctx, jsonctx->in->current, ly_strlen_const("true"), 0);
         ly_in_skip(jsonctx->in, ly_strlen_const("true"));
-        LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_TRUE);
+        JSON_PUSH_STATUS_RET(jsonctx, LYJSON_TRUE);
         LY_CHECK_RET(lyjson_check_next(jsonctx));
 
     } else if ((*jsonctx->in->current == 'n') && !strncmp(jsonctx->in->current, "null", ly_strlen_const("null"))) {
         /* none */
         lyjson_ctx_set_value(jsonctx, "", 0, 0);
         ly_in_skip(jsonctx->in, ly_strlen_const("null"));
-        LYJSON_STATUS_PUSH_RET(jsonctx, LYJSON_NULL);
+        JSON_PUSH_STATUS_RET(jsonctx, LYJSON_NULL);
         LY_CHECK_RET(lyjson_check_next(jsonctx));
 
     } else if (*jsonctx->in->current == '"') {
@@ -830,7 +837,11 @@ lyjson_value(struct lyjson_ctx *jsonctx)
 
     } else if (*jsonctx->in->current == '{') {
         jsonctx->depth++;
-
+        if (jsonctx->depth > LY_MAX_BLOCK_DEPTH) {
+            LOGERR(jsonctx->ctx, LY_EINVAL,
+                    "The maximum number of block nestings has been exceeded.");
+            return LY_EINVAL;
+        }
         /* object */
         ly_in_skip(jsonctx->in, 1);
         LY_CHECK_RET(lyjson_object(jsonctx));
@@ -846,19 +857,11 @@ lyjson_value(struct lyjson_ctx *jsonctx)
         return LY_EVALID;
     }
 
-    if (jsonctx->depth > LY_MAX_BLOCK_DEPTH) {
-        LOGERR(jsonctx->ctx, LY_EINVAL, "Maximum number %d of block nestings has been exceeded.", LY_MAX_BLOCK_DEPTH);
-        return LY_EINVAL;
-    } else if (jsonctx->status.count > LY_MAX_BLOCK_DEPTH * 10) {
-        LOGERR(jsonctx->ctx, LY_EINVAL, "Maximum number %d of nestings has been exceeded.", LY_MAX_BLOCK_DEPTH * 10);
-        return LY_EINVAL;
-    }
-
     return LY_SUCCESS;
 }
 
 LY_ERR
-lyjson_ctx_new(const struct ly_ctx *ctx, struct ly_in *in, ly_bool subtree, struct lyjson_ctx **jsonctx_p)
+lyjson_ctx_new(const struct ly_ctx *ctx, struct ly_in *in, struct lyjson_ctx **jsonctx_p)
 {
     LY_ERR ret = LY_SUCCESS;
     struct lyjson_ctx *jsonctx;
@@ -873,7 +876,7 @@ lyjson_ctx_new(const struct ly_ctx *ctx, struct ly_in *in, ly_bool subtree, stru
     jsonctx->ctx = ctx;
     jsonctx->in = in;
 
-    LOG_LOCSET(NULL, NULL, NULL, in);
+    LOG_LOCINIT(NULL, NULL, NULL, in);
 
     /* parse JSON value, if any */
     LY_CHECK_GOTO(ret = skip_ws(jsonctx), cleanup);
@@ -882,12 +885,8 @@ lyjson_ctx_new(const struct ly_ctx *ctx, struct ly_in *in, ly_bool subtree, stru
         goto cleanup;
     }
 
-    if (subtree) {
-        ret = lyjson_object(jsonctx);
-        jsonctx->depth++;
-    } else {
-        ret = lyjson_value(jsonctx);
-    }
+    ret = lyjson_value(jsonctx);
+
     if ((jsonctx->status.count > 1) && (lyjson_ctx_status(jsonctx, 0) == LYJSON_END)) {
         LOGVAL(jsonctx->ctx, LY_VCODE_EOF);
         ret = LY_EVALID;
@@ -951,7 +950,7 @@ lyjson_ctx_next(struct lyjson_ctx *jsonctx, enum LYJSON_PARSER_STATUS *status)
         goto result;
     } else {
         /* the previous token is closed and should be completely processed */
-        LYJSON_STATUS_POP_RET(jsonctx);
+        JSON_POP_STATUS_RET(jsonctx);
         prev = lyjson_ctx_status(jsonctx, 0);
     }
 
@@ -968,7 +967,7 @@ lyjson_ctx_next(struct lyjson_ctx *jsonctx, enum LYJSON_PARSER_STATUS *status)
 
     if (toplevel) {
         /* we are done */
-        goto result;
+        return LY_SUCCESS;
     }
 
     /* continue with the next token */
@@ -986,15 +985,14 @@ lyjson_ctx_next(struct lyjson_ctx *jsonctx, enum LYJSON_PARSER_STATUS *status)
             /* ... array - get another complete value */
             ret = lyjson_value(jsonctx);
         }
-    } else if (((prev == LYJSON_OBJECT) && (*jsonctx->in->current == '}')) ||
-            ((prev == LYJSON_ARRAY) && (*jsonctx->in->current == ']'))) {
+    } else if (((prev == LYJSON_OBJECT) && (*jsonctx->in->current == '}')) || ((prev == LYJSON_ARRAY) && (*jsonctx->in->current == ']'))) {
         if (*jsonctx->in->current == '}') {
             assert(jsonctx->depth);
             jsonctx->depth--;
         }
         ly_in_skip(jsonctx->in, 1);
-        LYJSON_STATUS_POP_RET(jsonctx);
-        LYJSON_STATUS_PUSH_RET(jsonctx, prev + 1);
+        JSON_POP_STATUS_RET(jsonctx);
+        JSON_PUSH_STATUS_RET(jsonctx, prev + 1);
     } else {
         /* unexpected value */
         LOGVAL(jsonctx->ctx, LY_VCODE_INSTREXP, LY_VCODE_INSTREXP_len(jsonctx->in->current), jsonctx->in->current,
