@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief LYB data parser for libyang
  *
- * Copyright (c) 2020 - 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2020 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -30,8 +30,6 @@
 #include "log.h"
 #include "parser_data.h"
 #include "parser_internal.h"
-#include "plugins_exts.h"
-#include "plugins_exts/metadata.h"
 #include "set.h"
 #include "tree.h"
 #include "tree_data.h"
@@ -41,23 +39,22 @@
 #include "validation.h"
 #include "xml.h"
 
-static LY_ERR lyb_parse_siblings(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_node **first_p,
-        struct ly_set *parsed);
+static LY_ERR _lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
+        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts,
+        struct ly_set *parsed, struct lyd_ctx **lydctx_p);
+
+static LY_ERR lyb_parse_siblings(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_node **first_p, struct ly_set *parsed);
 
 void
 lylyb_ctx_free(struct lylyb_ctx *ctx)
 {
     LY_ARRAY_COUNT_TYPE u;
 
-    if (!ctx) {
-        return;
-    }
-
     LY_ARRAY_FREE(ctx->siblings);
     LY_ARRAY_FREE(ctx->models);
 
     LY_ARRAY_FOR(ctx->sib_hts, u) {
-        lyht_free(ctx->sib_hts[u].ht, NULL);
+        lyht_free(ctx->sib_hts[u].ht);
     }
     LY_ARRAY_FREE(ctx->sib_hts);
 
@@ -69,10 +66,6 @@ lyd_lyb_ctx_free(struct lyd_ctx *lydctx)
 {
     struct lyd_lyb_ctx *ctx = (struct lyd_lyb_ctx *)lydctx;
 
-    if (!lydctx) {
-        return;
-    }
-
     lyd_ctx_free(lydctx);
     lylyb_ctx_free(ctx->lybctx);
     free(ctx);
@@ -338,150 +331,82 @@ lyb_read_start_siblings(struct lylyb_ctx *lybctx)
 }
 
 /**
- * @brief Read YANG model info.
+ * @brief Parse YANG model info.
  *
  * @param[in] lybctx LYB context.
- * @param[out] mod_name Module name, if any.
- * @param[out] mod_rev Module revision, "" if none.
- * @param[in,out] feat_set Set to add the names of enabled features to. If not set, enabled features are not parsed.
+ * @param[in] parse_options Flag with options for parsing.
+ * @param[out] model Parsed module.
  * @return LY_ERR value.
  */
 static LY_ERR
-lyb_read_model(struct lylyb_ctx *lybctx, char **mod_name, char mod_rev[], struct ly_set *feat_set)
+lyb_parse_model(struct lylyb_ctx *lybctx, uint32_t parse_options, const struct lys_module **model)
 {
-    uint16_t i, rev, length;
-    char *str;
-
-    *mod_name = NULL;
-    mod_rev[0] = '\0';
+    LY_ERR ret = LY_SUCCESS;
+    const struct lys_module *mod = NULL;
+    char *mod_name = NULL, mod_rev[LY_REV_SIZE];
+    uint16_t rev, length;
 
     lyb_read_number(&length, 2, 2, lybctx);
-    if (!length) {
-        return LY_SUCCESS;
+
+    if (length) {
+        mod_name = malloc((length + 1) * sizeof *mod_name);
+        LY_CHECK_ERR_RET(!mod_name, LOGMEM(lybctx->ctx), LY_EMEM);
+        lyb_read(((uint8_t *)mod_name), length, lybctx);
+        mod_name[length] = '\0';
+    } else {
+        goto cleanup;
     }
 
-    /* module name */
-    *mod_name = malloc(length + 1);
-    LY_CHECK_ERR_RET(!*mod_name, LOGMEM(lybctx->ctx), LY_EMEM);
-    lyb_read(((uint8_t *)*mod_name), length, lybctx);
-    (*mod_name)[length] = '\0';
-
-    /* module revision */
+    /* revision */
     lyb_read_number(&rev, sizeof rev, 2, lybctx);
 
     if (rev) {
         sprintf(mod_rev, "%04u-%02u-%02u", ((rev & LYB_REV_YEAR_MASK) >> LYB_REV_YEAR_SHIFT) + LYB_REV_YEAR_OFFSET,
                 (rev & LYB_REV_MONTH_MASK) >> LYB_REV_MONTH_SHIFT, rev & LYB_REV_DAY_MASK);
-    }
-
-    if (!feat_set) {
-        /* enabled features not printed */
-        return LY_SUCCESS;
-    }
-
-    /* enabled feature count */
-    lyb_read_number(&length, sizeof length, sizeof length, lybctx);
-    if (!length) {
-        return LY_SUCCESS;
-    }
-
-    /* enabled features */
-    for (i = 0; i < length; ++i) {
-        LY_CHECK_RET(lyb_read_string(&str, sizeof length, lybctx));
-        ly_set_add(feat_set, str, 1, NULL);
-    }
-
-    return LY_SUCCESS;
-}
-
-/**
- * @brief Parse YANG model info.
- *
- * @param[in] lybctx LYB context.
- * @param[in] parse_options Flag with options for parsing.
- * @param[in] with_features Whether the enabled features were also printed and should be read.
- * @param[out] mod Parsed module.
- * @return LY_ERR value.
- */
-static LY_ERR
-lyb_parse_model(struct lylyb_ctx *lybctx, uint32_t parse_options, ly_bool with_features, const struct lys_module **mod)
-{
-    LY_ERR ret = LY_SUCCESS;
-    const struct lys_module *m = NULL;
-    char *mod_name = NULL, mod_rev[LY_REV_SIZE];
-    struct ly_set feat_set = {0};
-    struct lysp_feature *f = NULL;
-    uint32_t i, idx = 0;
-    ly_bool enabled;
-
-    /* read module info */
-    if ((ret = lyb_read_model(lybctx, &mod_name, mod_rev, with_features ? &feat_set : NULL))) {
-        goto cleanup;
-    }
-
-    /* get the module */
-    if (mod_rev[0]) {
-        m = ly_ctx_get_module(lybctx->ctx, mod_name, mod_rev);
-        if ((parse_options & LYD_PARSE_LYB_MOD_UPDATE) && !m) {
+        mod = ly_ctx_get_module(lybctx->ctx, mod_name, mod_rev);
+        if ((parse_options & LYD_PARSE_LYB_MOD_UPDATE) && !mod) {
             /* try to use an updated module */
-            m = ly_ctx_get_module_implemented(lybctx->ctx, mod_name);
-            if (m && (!m->revision || (strcmp(m->revision, mod_rev) < 0))) {
+            mod = ly_ctx_get_module_implemented(lybctx->ctx, mod_name);
+            if (mod && (!mod->revision || (strcmp(mod->revision, mod_rev) < 0))) {
                 /* not an implemented module in a newer revision */
-                m = NULL;
+                mod = NULL;
             }
         }
     } else {
-        m = ly_ctx_get_module_latest(lybctx->ctx, mod_name);
+        mod = ly_ctx_get_module_latest(lybctx->ctx, mod_name);
     }
+    /* TODO data_clb supported?
+    if (lybctx->ctx->data_clb) {
+        if (!*mod) {
+            *mod = lybctx->ctx->data_clb(lybctx->ctx, mod_name, NULL, 0, lybctx->ctx->data_clb_data);
+        } else if (!(*mod)->implemented) {
+            *mod = lybctx->ctx->data_clb(lybctx->ctx, mod_name, (*mod)->ns, LY_MODCLB_NOT_IMPLEMENTED, lybctx->ctx->data_clb_data);
+        }
+    }*/
 
-    if (!m || !m->implemented) {
+    if (!mod || !mod->implemented) {
         if (parse_options & LYD_PARSE_STRICT) {
-            if (!m) {
+            if (!mod) {
                 LOGERR(lybctx->ctx, LY_EINVAL, "Invalid context for LYB data parsing, missing module \"%s%s%s\".",
-                        mod_name, mod_rev[0] ? "@" : "", mod_rev[0] ? mod_rev : "");
-            } else if (!m->implemented) {
+                        mod_name, rev ? "@" : "", rev ? mod_rev : "");
+            } else if (!mod->implemented) {
                 LOGERR(lybctx->ctx, LY_EINVAL, "Invalid context for LYB data parsing, module \"%s%s%s\" not implemented.",
-                        mod_name, mod_rev[0] ? "@" : "", mod_rev[0] ? mod_rev : "");
+                        mod_name, rev ? "@" : "", rev ? mod_rev : "");
             }
             ret = LY_EINVAL;
             goto cleanup;
         }
 
-        goto cleanup;
     }
 
-    if (with_features) {
-        /* check features */
-        while ((f = lysp_feature_next(f, m->parsed, &idx))) {
-            enabled = 0;
-            for (i = 0; i < feat_set.count; ++i) {
-                if (!strcmp(feat_set.objs[i], f->name)) {
-                    enabled = 1;
-                    break;
-                }
-            }
-
-            if (enabled && !(f->flags & LYS_FENABLED)) {
-                LOGERR(lybctx->ctx, LY_EINVAL, "Invalid context for LYB data parsing, module \"%s\" has \"%s\" feature disabled.",
-                        mod_name, f->name);
-                ret = LY_EINVAL;
-                goto cleanup;
-            } else if (!enabled && (f->flags & LYS_FENABLED)) {
-                LOGERR(lybctx->ctx, LY_EINVAL, "Invalid context for LYB data parsing, module \"%s\" has \"%s\" feature enabled.",
-                        mod_name, f->name);
-                ret = LY_EINVAL;
-                goto cleanup;
-            }
-        }
+    if (mod) {
+        /* fill cached hashes, if not already */
+        lyb_cache_module_hash(mod);
     }
 
-    /* fill cached hashes, if not already */
-    lyb_cache_module_hash(m);
-
 cleanup:
-    *mod = m;
+    *model = mod;
     free(mod_name);
-    ly_set_erase(&feat_set, free);
     return ret;
 }
 
@@ -489,12 +414,11 @@ cleanup:
  * @brief Parse YANG node metadata.
  *
  * @param[in] lybctx LYB context.
- * @param[in] sparent Schema parent node of the metadata.
  * @param[out] meta Parsed metadata.
  * @return LY_ERR value.
  */
 static LY_ERR
-lyb_parse_metadata(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent, struct lyd_meta **meta)
+lyb_parse_metadata(struct lyd_lyb_ctx *lybctx, struct lyd_meta **meta)
 {
     LY_ERR ret = LY_SUCCESS;
     ly_bool dynamic;
@@ -508,7 +432,7 @@ lyb_parse_metadata(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent,
     /* read attributes */
     for (i = 0; i < count; ++i) {
         /* find model */
-        ret = lyb_parse_model(lybctx->lybctx, lybctx->parse_opts, 0, &mod);
+        ret = lyb_parse_model(lybctx->lybctx, lybctx->parse_opts, &mod);
         LY_CHECK_GOTO(ret, cleanup);
 
         if (!mod) {
@@ -531,7 +455,7 @@ lyb_parse_metadata(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent,
 
         /* create metadata */
         ret = lyd_parser_create_meta((struct lyd_ctx *)lybctx, NULL, meta, mod, meta_name, strlen(meta_name), meta_value,
-                ly_strlen(meta_value), &dynamic, LY_VALUE_JSON, NULL, LYD_HINT_DATA, sparent);
+                ly_strlen(meta_value), &dynamic, LY_VALUE_JSON, NULL, LYD_HINT_DATA);
 
         /* free strings */
         free(meta_name);
@@ -573,6 +497,9 @@ lyb_parse_prefix_data(struct lylyb_ctx *lybctx, LY_VALUE_FORMAT format, void **p
     case LY_VALUE_XML:
         /* read count */
         lyb_read(&count, 1, lybctx);
+        if (!count) {
+            return LY_SUCCESS;
+        }
 
         /* read all NS elements */
         LY_CHECK_GOTO(ret = ly_set_new(&set), cleanup);
@@ -582,10 +509,6 @@ lyb_parse_prefix_data(struct lylyb_ctx *lybctx, LY_VALUE_FORMAT format, void **p
 
             /* prefix */
             LY_CHECK_GOTO(ret = lyb_read_string(&ns->prefix, sizeof(uint16_t), lybctx), cleanup);
-            if (!strlen(ns->prefix)) {
-                free(ns->prefix);
-                ns->prefix = NULL;
-            }
 
             /* namespace */
             LY_CHECK_GOTO(ret = lyb_read_string(&ns->uri, sizeof(uint16_t), lybctx), cleanup);
@@ -823,7 +746,7 @@ lyb_parse_schema_hash(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparen
             break;
         }
         /* skip schema nodes from models not present during printing */
-        if (((sibling->module->ctx != lybctx->lybctx->ctx) || lyb_has_schema_model(sibling, lybctx->lybctx->models)) &&
+        if (lyb_has_schema_model(sibling, lybctx->lybctx->models) &&
                 lyb_is_schema_hash_match((struct lysc_node *)sibling, hash, hash_count)) {
             /* match found */
             break;
@@ -850,50 +773,6 @@ lyb_parse_schema_hash(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparen
     return LY_SUCCESS;
 }
 
-/**
- * @brief Parse schema node name of a nested extension data node.
- *
- * @param[in] lybctx LYB context.
- * @param[in] parent Data parent.
- * @param[in] mod_name Module name of the node.
- * @param[out] snode Parsed found schema node of a nested extension.
- * @return LY_ERR value.
- */
-static LY_ERR
-lyb_parse_schema_nested_ext(struct lyd_lyb_ctx *lybctx, const struct lyd_node *parent, const char *mod_name,
-        const struct lysc_node **snode)
-{
-    LY_ERR rc = LY_SUCCESS, r;
-    char *name = NULL;
-    struct lysc_ext_instance *ext;
-
-    assert(parent);
-
-    /* read schema node name */
-    LY_CHECK_GOTO(rc = lyb_read_string(&name, sizeof(uint16_t), lybctx->lybctx), cleanup);
-
-    /* check for extension data */
-    r = ly_nested_ext_schema(parent, NULL, mod_name, mod_name ? strlen(mod_name) : 0, LY_VALUE_JSON, NULL, name,
-            strlen(name), snode, &ext);
-    if (r == LY_ENOT) {
-        /* failed to parse */
-        LOGERR(lybctx->lybctx->ctx, LY_EINVAL, "Failed to parse node \"%s\" as nested extension instance data.", name);
-        rc = LY_EINVAL;
-        goto cleanup;
-    } else if (r) {
-        /* error */
-        rc = r;
-        goto cleanup;
-    }
-
-    /* fill cached hashes in the module, it may be from a different context */
-    lyb_cache_module_hash((*snode)->module);
-
-cleanup:
-    free(name);
-    return rc;
-}
-
 /**
  * @brief Read until the end of the current siblings.
  *
@@ -911,6 +790,46 @@ lyb_skip_siblings(struct lylyb_ctx *lybctx)
     } while (LYB_LAST_SIBLING(lybctx).written);
 }
 
+/**
+ * @brief Parse the context of anydata/anyxml node.
+ *
+ * @param[in] ctx libyang context.
+ * @param[in] data LYB data to parse.
+ * @param[out] tree Parsed tree.
+ * @return LY_ERR value.
+ */
+static LY_ERR
+lyb_parse_any_content(const struct ly_ctx *ctx, const char *data, struct lyd_node **tree)
+{
+    LY_ERR ret;
+    uint32_t prev_lo;
+    struct ly_in *in;
+    struct lyd_ctx *lydctx = NULL;
+
+    *tree = NULL;
+
+    LY_CHECK_RET(ly_in_new_memory(data, &in));
+
+    /* turn logging off */
+    prev_lo = ly_log_options(0);
+
+    ret = _lyd_parse_lyb(ctx, NULL, NULL, tree, in, LYD_PARSE_ONLY | LYD_PARSE_OPAQ | LYD_PARSE_STRICT, 0,
+            LYD_INTOPT_ANY | LYD_INTOPT_WITH_SIBLINGS, NULL, &lydctx);
+
+    /* turn logging on again */
+    ly_log_options(prev_lo);
+
+    ly_in_free(in, 0);
+    if (lydctx) {
+        lydctx->free(lydctx);
+    }
+    if (ret) {
+        lyd_free_siblings(*tree);
+        *tree = NULL;
+    }
+    return ret;
+}
+
 /**
  * @brief Insert new node to @p parsed set.
  *
@@ -928,11 +847,7 @@ lyb_insert_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_
         struct ly_set *parsed)
 {
     /* insert, keep first pointer correct */
-    if (parent && (LYD_CTX(parent) != LYD_CTX(node))) {
-        lyplg_ext_insert(parent, node);
-    } else {
-        lyd_insert_node(parent, first_p, node, lybctx->parse_opts & LYD_PARSE_ORDERED ? 1 : 0);
-    }
+    lyd_insert_node(parent, first_p, node, lybctx->parse_opts & LYD_PARSE_ORDERED ? 1 : 0);
     while (!parent && (*first_p)->prev->next) {
         *first_p = (*first_p)->prev;
     }
@@ -1004,14 +919,7 @@ lyb_finish_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, uint32_t fl
     (*node)->meta = *meta;
     *meta = NULL;
 
-    /* insert into parent */
     lyb_insert_node(lybctx, parent, *node, first_p, parsed);
-
-    if (!(lybctx->parse_opts & LYD_PARSE_ONLY)) {
-        /* store for ext instance node validation, if needed */
-        (void)lyd_validate_node_ext(*node, &lybctx->ext_node);
-    }
-
     *node = NULL;
 }
 
@@ -1019,18 +927,17 @@ lyb_finish_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, uint32_t fl
  * @brief Parse header for non-opaq node.
  *
  * @param[in] lybctx LYB context.
- * @param[in] sparent Schema parent node of the metadata.
  * @param[out] flags Parsed node flags.
  * @param[out] meta Parsed metadata of the node.
  * @return LY_ERR value.
  */
 static LY_ERR
-lyb_parse_node_header(struct lyd_lyb_ctx *lybctx, const struct lysc_node *sparent, uint32_t *flags, struct lyd_meta **meta)
+lyb_parse_node_header(struct lyd_lyb_ctx *lybctx, uint32_t *flags, struct lyd_meta **meta)
 {
     LY_ERR ret;
 
     /* create and read metadata */
-    ret = lyb_parse_metadata(lybctx, sparent, meta);
+    ret = lyb_parse_metadata(lybctx, meta);
     LY_CHECK_RET(ret);
 
     /* read flags */
@@ -1090,13 +997,14 @@ lyb_validate_node_inner(struct lyd_lyb_ctx *lybctx, const struct lysc_node *snod
 
     if (!(lybctx->parse_opts & LYD_PARSE_ONLY)) {
         /* new node validation, autodelete CANNOT occur, all nodes are new */
-        ret = lyd_validate_new(lyd_node_child_p(node), snode, NULL, 0, NULL);
+        ret = lyd_validate_new(lyd_node_child_p(node), snode, NULL, NULL);
         LY_CHECK_RET(ret);
 
         /* add any missing default children */
         impl_opts = (lybctx->val_opts & LYD_VALIDATE_NO_STATE) ? LYD_IMPLICIT_NO_STATE : 0;
-        ret = lyd_new_implicit_r(node, lyd_node_child_p(node), NULL, NULL, &lybctx->node_when, &lybctx->node_types,
-                &lybctx->ext_node, impl_opts, NULL);
+        ret = lyd_new_implicit_r(node, lyd_node_child_p(node), NULL,
+                NULL, &lybctx->node_when, &lybctx->node_exts,
+                &lybctx->node_types, impl_opts, NULL);
         LY_CHECK_RET(ret);
     }
 
@@ -1207,22 +1115,22 @@ lyb_parse_node_any(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const st
         struct lyd_node **first_p, struct ly_set *parsed)
 {
     LY_ERR ret;
-    struct lyd_node *node = NULL, *tree = NULL;
+    struct lyd_node *node = NULL, *tree;
     struct lyd_meta *meta = NULL;
     LYD_ANYDATA_VALUETYPE value_type;
-    struct ly_in *in;
-    struct lyd_ctx *lydctx = NULL;
     char *value = NULL;
+    const char *val_dict;
     uint32_t flags;
     const struct ly_ctx *ctx = lybctx->lybctx->ctx;
 
     /* read necessary basic data */
-    ret = lyb_parse_node_header(lybctx, snode, &flags, &meta);
+    ret = lyb_parse_node_header(lybctx, &flags, &meta);
     LY_CHECK_GOTO(ret, error);
 
     /* parse value type */
     lyb_read_number(&value_type, sizeof value_type, sizeof value_type, lybctx->lybctx);
-    if ((value_type == LYD_ANYDATA_DATATREE) || ((snode->nodetype == LYS_ANYDATA) && (value_type != LYD_ANYDATA_LYB))) {
+    if (value_type == LYD_ANYDATA_DATATREE) {
+        /* invalid situation */
         LOGINT(ctx);
         ret = LY_EINT;
         goto error;
@@ -1233,31 +1141,38 @@ lyb_parse_node_any(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const st
     LY_CHECK_GOTO(ret, error);
 
     if (value_type == LYD_ANYDATA_LYB) {
-        /* parse LYB into a data tree */
-        LY_CHECK_RET(ly_in_new_memory(value, &in));
-        ret = lyd_parse_lyb(ctx, NULL, NULL, &tree, in, LYD_PARSE_ONLY | LYD_PARSE_OPAQ | LYD_PARSE_STRICT, 0,
-                LYD_INTOPT_ANY | LYD_INTOPT_WITH_SIBLINGS, NULL, NULL, &lydctx);
-        ly_in_free(in, 0);
-        if (lydctx) {
-            lydctx->free(lydctx);
+        /* try to parse LYB into a data tree */
+        if (!lyb_parse_any_content(ctx, value, &tree)) {
+            /* successfully parsed */
+            free(value);
+            value = (char *)tree;
+            value_type = LYD_ANYDATA_DATATREE;
         }
-        LY_CHECK_ERR_GOTO(ret, lyd_free_siblings(tree), error);
-
-        /* use the parsed tree as the value */
-        free(value);
-        value = (char *)tree;
-        value_type = LYD_ANYDATA_DATATREE;
     }
 
     /* create the node */
     switch (value_type) {
+    case LYD_ANYDATA_LYB:
     case LYD_ANYDATA_DATATREE:
-    case LYD_ANYDATA_STRING:
-    case LYD_ANYDATA_XML:
-    case LYD_ANYDATA_JSON:
         /* use the value directly */
         ret = lyd_create_any(snode, value, value_type, 1, &node);
         LY_CHECK_GOTO(ret, error);
+
+        break;
+    case LYD_ANYDATA_STRING:
+    case LYD_ANYDATA_XML:
+    case LYD_ANYDATA_JSON:
+        /* value is expected to be in the dictionary */
+        ret = lydict_insert_zc(ctx, value, &val_dict);
+        value = NULL;
+        LY_CHECK_GOTO(ret, error);
+
+        /* use the value in the dictionary */
+        ret = lyd_create_any(snode, val_dict, value_type, 1, &node);
+        if (ret) {
+            lydict_remove(ctx, val_dict);
+            goto error;
+        }
         break;
     default:
         LOGINT(ctx);
@@ -1297,7 +1212,7 @@ lyb_parse_node_inner(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const
     uint32_t flags;
 
     /* read necessary basic data */
-    ret = lyb_parse_node_header(lybctx, snode, &flags, &meta);
+    ret = lyb_parse_node_header(lybctx, &flags, &meta);
     LY_CHECK_GOTO(ret, error);
 
     /* create node */
@@ -1348,7 +1263,7 @@ lyb_parse_node_leaf(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const s
     uint32_t flags;
 
     /* read necessary basic data */
-    ret = lyb_parse_node_header(lybctx, snode, &flags, &meta);
+    ret = lyb_parse_node_header(lybctx, &flags, &meta);
     LY_CHECK_GOTO(ret, error);
 
     /* read value of term node and create it */
@@ -1423,7 +1338,7 @@ lyb_parse_node_list(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, const s
 
     while (LYB_LAST_SIBLING(lybctx->lybctx).written) {
         /* read necessary basic data */
-        ret = lyb_parse_node_header(lybctx, snode, &flags, &meta);
+        ret = lyb_parse_node_header(lybctx, &flags, &meta);
         LY_CHECK_GOTO(ret, error);
 
         /* create list node */
@@ -1460,12 +1375,12 @@ error:
 }
 
 /**
- * @brief Parse a node.
+ * @brief Parse node.
  *
+ * @param[in] out Out structure.
+ * @param[in,out] printed_node Current data node to print. Sets to the last printed node.
+ * @param[in,out] sibling_ht Cached hash table for these siblings, created if NULL.
  * @param[in] lybctx LYB context.
- * @param[in] parent Data parent of the sibling, must be set if @p first_p is not.
- * @param[in,out] first_p First top-level sibling, must be set if @p parent is not.
- * @param[in,out] parsed Set of all successfully parsed nodes to add to.
  * @return LY_ERR value.
  */
 static LY_ERR
@@ -1475,33 +1390,19 @@ lyb_parse_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_n
     LY_ERR ret;
     const struct lysc_node *snode;
     const struct lys_module *mod;
-    enum lylyb_node_type lyb_type;
-    char *mod_name = NULL, mod_rev[LY_REV_SIZE];
 
-    /* read node type */
-    lyb_read_number(&lyb_type, sizeof lyb_type, 1, lybctx->lybctx);
-
-    switch (lyb_type) {
-    case LYB_NODE_TOP:
-        /* top-level, read module name */
-        LY_CHECK_GOTO(ret = lyb_parse_model(lybctx->lybctx, lybctx->parse_opts, 0, &mod), cleanup);
+    if (!parent || !parent->schema) {
+        /* top-level or opaque, read module name */
+        ret = lyb_parse_model(lybctx->lybctx, lybctx->parse_opts, &mod);
+        LY_CHECK_RET(ret);
 
         /* read hash, find the schema node starting from mod */
-        LY_CHECK_GOTO(ret = lyb_parse_schema_hash(lybctx, NULL, mod, &snode), cleanup);
-        break;
-    case LYB_NODE_CHILD:
-    case LYB_NODE_OPAQ:
-        /* read hash, find the schema node starting from parent schema, if any */
-        LY_CHECK_GOTO(ret = lyb_parse_schema_hash(lybctx, parent ? parent->schema : NULL, NULL, &snode), cleanup);
-        break;
-    case LYB_NODE_EXT:
-        /* ext, read module name */
-        LY_CHECK_GOTO(ret = lyb_read_model(lybctx->lybctx, &mod_name, mod_rev, NULL), cleanup);
-
-        /* read schema node name, find the nexted ext schema node */
-        LY_CHECK_GOTO(ret = lyb_parse_schema_nested_ext(lybctx, parent, mod_name, &snode), cleanup);
-        break;
+        ret = lyb_parse_schema_hash(lybctx, NULL, mod, &snode);
+    } else {
+        /* read hash, find the schema node starting from parent schema */
+        ret = lyb_parse_schema_hash(lybctx, parent->schema, NULL, &snode);
     }
+    LY_CHECK_RET(ret);
 
     if (!snode) {
         ret = lyb_parse_node_opaq(lybctx, parent, first_p, parsed);
@@ -1516,10 +1417,8 @@ lyb_parse_node(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_n
     } else {
         ret = lyb_parse_node_leaf(lybctx, parent, snode, first_p, parsed);
     }
-    LY_CHECK_GOTO(ret, cleanup);
+    LY_CHECK_RET(ret);
 
-cleanup:
-    free(mod_name);
     return ret;
 }
 
@@ -1536,15 +1435,18 @@ static LY_ERR
 lyb_parse_siblings(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct lyd_node **first_p,
         struct ly_set *parsed)
 {
+    LY_ERR ret;
     ly_bool top_level;
 
     top_level = !LY_ARRAY_COUNT(lybctx->lybctx->siblings);
 
     /* register a new siblings */
-    LY_CHECK_RET(lyb_read_start_siblings(lybctx->lybctx));
+    ret = lyb_read_start_siblings(lybctx->lybctx);
+    LY_CHECK_RET(ret);
 
     while (LYB_LAST_SIBLING(lybctx->lybctx).written) {
-        LY_CHECK_RET(lyb_parse_node(lybctx, parent, first_p, parsed));
+        ret = lyb_parse_node(lybctx, parent, first_p, parsed);
+        LY_CHECK_RET(ret);
 
         if (top_level && !(lybctx->int_opts & LYD_INTOPT_WITH_SIBLINGS)) {
             break;
@@ -1552,9 +1454,10 @@ lyb_parse_siblings(struct lyd_lyb_ctx *lybctx, struct lyd_node *parent, struct l
     }
 
     /* end the siblings */
-    LY_CHECK_RET(lyb_read_stop_siblings(lybctx->lybctx));
+    ret = lyb_read_stop_siblings(lybctx->lybctx);
+    LY_CHECK_RET(ret);
 
-    return LY_SUCCESS;
+    return ret;
 }
 
 /**
@@ -1579,7 +1482,7 @@ lyb_parse_data_models(struct lylyb_ctx *lybctx, uint32_t parse_options)
 
         /* read modules */
         for (u = 0; u < count; ++u) {
-            ret = lyb_parse_model(lybctx, parse_options, 1, &lybctx->models[u]);
+            ret = lyb_parse_model(lybctx, parse_options, &lybctx->models[u]);
             LY_CHECK_RET(ret);
             LY_ARRAY_INCREMENT(lybctx->models);
         }
@@ -1643,10 +1546,10 @@ lyb_parse_header(struct lylyb_ctx *lybctx)
     return LY_SUCCESS;
 }
 
-LY_ERR
-lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
+static LY_ERR
+_lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
         struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, uint32_t int_opts,
-        struct ly_set *parsed, ly_bool *subtree_sibling, struct lyd_ctx **lydctx_p)
+        struct ly_set *parsed, struct lyd_ctx **lydctx_p)
 {
     LY_ERR rc = LY_SUCCESS;
     struct lyd_lyb_ctx *lybctx;
@@ -1654,12 +1557,6 @@ lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, str
     assert(!(parse_opts & ~LYD_PARSE_OPTS_MASK));
     assert(!(val_opts & ~LYD_VALIDATE_OPTS_MASK));
 
-    LY_CHECK_ARG_RET(ctx, !(parse_opts & LYD_PARSE_SUBTREE), LY_EINVAL);
-
-    if (subtree_sibling) {
-        *subtree_sibling = 0;
-    }
-
     lybctx = calloc(1, sizeof *lybctx);
     LY_CHECK_ERR_RET(!lybctx, LOGMEM(ctx), LY_EMEM);
     lybctx->lybctx = calloc(1, sizeof *lybctx->lybctx);
@@ -1719,12 +1616,44 @@ cleanup:
     return rc;
 }
 
-LIBYANG_API_DEF int
+LY_ERR
+lyd_parse_lyb(const struct ly_ctx *ctx, const struct lysc_ext_instance *ext, struct lyd_node *parent,
+        struct lyd_node **first_p, struct ly_in *in, uint32_t parse_opts, uint32_t val_opts, enum lyd_type data_type,
+        struct ly_set *parsed, struct lyd_ctx **lydctx_p)
+{
+    uint32_t int_opts;
+
+    assert(!(parse_opts & ~LYD_PARSE_OPTS_MASK));
+    assert(!(val_opts & ~LYD_VALIDATE_OPTS_MASK));
+
+    switch (data_type) {
+    case LYD_TYPE_DATA_YANG:
+        int_opts = LYD_INTOPT_WITH_SIBLINGS;
+        break;
+    case LYD_TYPE_RPC_YANG:
+        int_opts = LYD_INTOPT_RPC | LYD_INTOPT_ACTION | LYD_INTOPT_NO_SIBLINGS;
+        break;
+    case LYD_TYPE_NOTIF_YANG:
+        int_opts = LYD_INTOPT_NOTIF | LYD_INTOPT_NO_SIBLINGS;
+        break;
+    case LYD_TYPE_REPLY_YANG:
+        int_opts = LYD_INTOPT_REPLY | LYD_INTOPT_NO_SIBLINGS;
+        break;
+    default:
+        LOGINT(ctx);
+        return LY_EINT;
+    }
+
+    return _lyd_parse_lyb(ctx, ext, parent, first_p, in, parse_opts, val_opts, int_opts, parsed, lydctx_p);
+}
+
+API int
 lyd_lyb_data_length(const char *data)
 {
     LY_ERR ret = LY_SUCCESS;
     struct lylyb_ctx *lybctx;
-    uint32_t count, feat_count, len = 0, i, j;
+    int count, i;
+    size_t len;
     uint8_t buf[LYB_SIZE_MAX];
     uint8_t zero[LYB_SIZE_BYTES] = {0};
 
@@ -1751,6 +1680,7 @@ lyd_lyb_data_length(const char *data)
     /* read all models */
     for (i = 0; i < count; ++i) {
         /* module name length */
+        len = 0;
         lyb_read_number(&len, sizeof len, 2, lybctx);
 
         /* model name */
@@ -1758,18 +1688,6 @@ lyd_lyb_data_length(const char *data)
 
         /* revision */
         lyb_read(buf, 2, lybctx);
-
-        /* enabled feature count */
-        lyb_read_number(&feat_count, sizeof feat_count, 2, lybctx);
-
-        /* enabled features */
-        for (j = 0; j < feat_count; ++j) {
-            /* feature name length */
-            lyb_read_number(&len, sizeof len, 2, lybctx);
-
-            /* feature name */
-            lyb_read(buf, len, lybctx);
-        }
     }
 
     if (memcmp(zero, lybctx->in->current, LYB_SIZE_BYTES)) {
@@ -1796,5 +1714,5 @@ cleanup:
     ly_in_free(lybctx->in, 0);
     lylyb_ctx_free(lybctx);
 
-    return ret ? -1 : (int)count;
+    return ret ? -1 : count;
 }
