@@ -134,7 +134,6 @@ ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, size_t prefix_le
         mod = ly_schema_resolved_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
         break;
     case LY_VALUE_XML:
-    case LY_VALUE_STR_NS:
         mod = ly_xml_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
         break;
     case LY_VALUE_CANON:
@@ -147,26 +146,23 @@ ly_resolve_prefix(const struct ly_ctx *ctx, const void *prefix, size_t prefix_le
     return mod;
 }
 
-LIBYANG_API_DEF const struct lys_module *
-lyplg_type_identity_module(const struct ly_ctx *ctx, const struct lysc_node *ctx_node, const char *prefix,
-        size_t prefix_len, LY_VALUE_FORMAT format, const void *prefix_data)
+API const struct lys_module *
+lyplg_type_identity_module(const struct ly_ctx *ctx, const struct lysc_node *ctx_node,
+        const char *prefix, size_t prefix_len, LY_VALUE_FORMAT format, const void *prefix_data)
 {
     if (prefix_len) {
         return ly_resolve_prefix(ctx, prefix, prefix_len, format, prefix_data);
     } else {
         switch (format) {
         case LY_VALUE_SCHEMA:
-            /* use local module */
-            return ly_schema_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
         case LY_VALUE_SCHEMA_RESOLVED:
-            /* use local module */
-            return ly_schema_resolved_resolve_prefix(ctx, prefix, prefix_len, prefix_data);
+            /* use context node module, handles augments */
+            return ctx_node->module;
         case LY_VALUE_CANON:
         case LY_VALUE_JSON:
         case LY_VALUE_LYB:
-        case LY_VALUE_STR_NS:
             /* use context node module (as specified) */
-            return ctx_node ? ctx_node->module : NULL;
+            return ctx_node->module;
         case LY_VALUE_XML:
             /* use the default namespace */
             return ly_xml_resolve_prefix(ctx, NULL, 0, prefix_data);
@@ -255,7 +251,6 @@ ly_get_prefix(const struct lys_module *mod, LY_VALUE_FORMAT format, void *prefix
         prefix = ly_schema_resolved_get_prefix(mod, prefix_data);
         break;
     case LY_VALUE_XML:
-    case LY_VALUE_STR_NS:
         prefix = ly_xml_get_prefix(mod, prefix_data);
         break;
     case LY_VALUE_CANON:
@@ -268,13 +263,13 @@ ly_get_prefix(const struct lys_module *mod, LY_VALUE_FORMAT format, void *prefix
     return prefix;
 }
 
-LIBYANG_API_DEF const char *
+API const char *
 lyplg_type_get_prefix(const struct lys_module *mod, LY_VALUE_FORMAT format, void *prefix_data)
 {
     return ly_get_prefix(mod, format, prefix_data);
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_compare_simple(const struct lyd_value *val1, const struct lyd_value *val2)
 {
     if (val1->realtype != val2->realtype) {
@@ -288,7 +283,7 @@ lyplg_type_compare_simple(const struct lyd_value *val1, const struct lyd_value *
     return LY_ENOT;
 }
 
-LIBYANG_API_DEF const void *
+API const void *
 lyplg_type_print_simple(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *value, LY_VALUE_FORMAT UNUSED(format),
         void *UNUSED(prefix_data), ly_bool *dynamic, size_t *value_len)
 {
@@ -301,7 +296,7 @@ lyplg_type_print_simple(const struct ly_ctx *UNUSED(ctx), const struct lyd_value
     return value->_canonical;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_dup_simple(const struct ly_ctx *ctx, const struct lyd_value *original, struct lyd_value *dup)
 {
     memset(dup, 0, sizeof *dup);
@@ -311,14 +306,14 @@ lyplg_type_dup_simple(const struct ly_ctx *ctx, const struct lyd_value *original
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF void
+API void
 lyplg_type_free_simple(const struct ly_ctx *ctx, struct lyd_value *value)
 {
     lydict_remove(ctx, value->_canonical);
     value->_canonical = NULL;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_parse_int(const char *datatype, int base, int64_t min, int64_t max, const char *value, size_t value_len,
         int64_t *ret, struct ly_err_item **err)
 {
@@ -343,7 +338,7 @@ lyplg_type_parse_int(const char *datatype, int base, int64_t min, int64_t max, c
     }
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_parse_uint(const char *datatype, int base, uint64_t max, const char *value, size_t value_len, uint64_t *ret,
         struct ly_err_item **err)
 {
@@ -371,7 +366,7 @@ lyplg_type_parse_uint(const char *datatype, int base, uint64_t max, const char *
     }
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_parse_dec64(uint8_t fraction_digits, const char *value, size_t value_len, int64_t *ret, struct ly_err_item **err)
 {
     LY_ERR ret_val;
@@ -466,7 +461,7 @@ decimal:
     return ret_val;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_validate_patterns(struct lysc_pattern **patterns, const char *str, size_t str_len, struct ly_err_item **err)
 {
     int rc, match_opts;
@@ -513,7 +508,7 @@ lyplg_type_validate_patterns(struct lysc_pattern **patterns, const char *str, si
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_validate_range(LY_DATA_TYPE basetype, struct lysc_range *range, int64_t value, const char *strval,
         size_t strval_len, struct ly_err_item **err)
 {
@@ -574,7 +569,7 @@ lyplg_type_validate_range(LY_DATA_TYPE basetype, struct lysc_range *range, int64
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_prefix_data_new(const struct ly_ctx *ctx, const void *value, size_t value_len, LY_VALUE_FORMAT format,
         const void *prefix_data, LY_VALUE_FORMAT *format_p, void **prefix_data_p)
 {
@@ -584,7 +579,7 @@ lyplg_type_prefix_data_new(const struct ly_ctx *ctx, const void *value, size_t v
     return ly_store_prefix_data(ctx, value, value_len, format, prefix_data, format_p, (void **)prefix_data_p);
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_prefix_data_dup(const struct ly_ctx *ctx, LY_VALUE_FORMAT format, const void *orig, void **dup)
 {
     LY_CHECK_ARG_RET(NULL, dup, LY_EINVAL);
@@ -597,7 +592,7 @@ lyplg_type_prefix_data_dup(const struct ly_ctx *ctx, LY_VALUE_FORMAT format, con
     return ly_dup_prefix_data(ctx, format, orig, (void **)dup);
 }
 
-LIBYANG_API_DEF void
+API void
 lyplg_type_prefix_data_free(LY_VALUE_FORMAT format, void *prefix_data)
 {
     ly_free_prefix_data(format, prefix_data);
@@ -620,7 +615,7 @@ type_get_hints_base(uint32_t hints)
     }
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_check_hints(uint32_t hints, const char *value, size_t value_len, LY_DATA_TYPE type, int *base,
         struct ly_err_item **err)
 {
@@ -689,7 +684,7 @@ lyplg_type_check_hints(uint32_t hints, const char *value, size_t value_len, LY_D
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_check_status(const struct lysc_node *ctx_node, uint16_t val_flags, LY_VALUE_FORMAT format, void *prefix_data,
         const char *val_name, struct ly_err_item **err)
 {
@@ -724,7 +719,7 @@ lyplg_type_check_status(const struct lysc_node *ctx_node, uint16_t val_flags, LY
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_lypath_check_status(const struct lysc_node *ctx_node, const struct ly_path *path, LY_VALUE_FORMAT format,
         void *prefix_data, struct ly_err_item **err)
 {
@@ -764,7 +759,7 @@ lyplg_type_lypath_check_status(const struct lysc_node *ctx_node, const struct ly
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_lypath_new(const struct ly_ctx *ctx, const char *value, size_t value_len, uint32_t options,
         LY_VALUE_FORMAT format, void *prefix_data, const struct lysc_node *ctx_node, struct lys_glob_unres *unres,
         struct ly_path **path, struct ly_err_item **err)
@@ -787,7 +782,6 @@ lyplg_type_lypath_new(const struct ly_ctx *ctx, const char *value, size_t value_
     case LY_VALUE_CANON:
     case LY_VALUE_LYB:
     case LY_VALUE_JSON:
-    case LY_VALUE_STR_NS:
         prefix_opt = LY_PATH_PREFIX_STRICT_INHERIT;
         break;
     }
@@ -824,13 +818,13 @@ cleanup:
     return ret;
 }
 
-LIBYANG_API_DEF void
+API void
 lyplg_type_lypath_free(const struct ly_ctx *ctx, struct ly_path *path)
 {
     ly_path_free(ctx, path);
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_make_implemented(struct lys_module *mod, const char **features, struct lys_glob_unres *unres)
 {
     if (mod->implemented) {
@@ -843,7 +837,7 @@ lyplg_type_make_implemented(struct lys_module *mod, const char **features, struc
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_identity_isderived(const struct lysc_ident *base, const struct lysc_ident *der)
 {
     LY_ARRAY_COUNT_TYPE u;
@@ -859,13 +853,13 @@ lyplg_type_identity_isderived(const struct lysc_ident *base, const struct lysc_i
     return LY_ENOTFOUND;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct lyd_node *node, struct lyd_value *value,
         const struct lyd_node *tree, struct lyd_node **target, char **errmsg)
 {
     LY_ERR ret;
     struct lyxp_set set = {0};
-    const char *val_str, *xp_err_msg;
+    const char *val_str;
     uint32_t i;
     int rc;
 
@@ -875,19 +869,9 @@ lyplg_type_resolve_leafref(const struct lysc_type_leafref *lref, const struct ly
     ret = lyxp_eval(LYD_CTX(node), lref->path, node->schema->module, LY_VALUE_SCHEMA_RESOLVED, lref->prefixes,
             node, tree, NULL, &set, LYXP_IGNORE_WHEN);
     if (ret) {
-        if (ly_errcode(LYD_CTX(node)) == ret) {
-            xp_err_msg = ly_errmsg(LYD_CTX(node));
-        } else {
-            xp_err_msg = NULL;
-        }
-
+        ret = LY_ENOTFOUND;
         val_str = lref->plugin->print(LYD_CTX(node), value, LY_VALUE_CANON, NULL, NULL, NULL);
-        if (xp_err_msg) {
-            rc = asprintf(errmsg, "Invalid leafref value \"%s\" - XPath evaluation error (%s).", val_str, xp_err_msg);
-        } else {
-            rc = asprintf(errmsg, "Invalid leafref value \"%s\" - XPath evaluation error.", val_str);
-        }
-        if (rc == -1) {
+        if (asprintf(errmsg, "Invalid leafref value \"%s\" - XPath evaluation error.", val_str) == -1) {
             *errmsg = NULL;
             ret = LY_EMEM;
         }
