@@ -36,7 +36,7 @@
  */
 
 /**
- * @brief Convert compiled path (node-instance-identifier) or NULL ("/") into string.
+ * @brief Convert compiled path (instance-identifier) into string.
  *
  * @param[in] path Compiled path.
  * @param[in] format Value format.
@@ -45,7 +45,7 @@
  * @return LY_ERR value.
  */
 static LY_ERR
-node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, void *prefix_data, char **str)
+instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, void *prefix_data, char **str)
 {
     LY_ERR ret = LY_SUCCESS;
     LY_ARRAY_COUNT_TYPE u, v;
@@ -54,12 +54,6 @@ node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, voi
     ly_bool inherit_prefix = 0, d;
     const char *strval;
 
-    if (!path) {
-        /* special path */
-        ret = ly_strcat(&result, "/");
-        goto cleanup;
-    }
-
     switch (format) {
     case LY_VALUE_XML:
     case LY_VALUE_SCHEMA:
@@ -70,7 +64,6 @@ node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, voi
     case LY_VALUE_CANON:
     case LY_VALUE_JSON:
     case LY_VALUE_LYB:
-    case LY_VALUE_STR_NS:
         /* the same prefix is inherited and skipped */
         inherit_prefix = 1;
         break;
@@ -90,7 +83,9 @@ node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, voi
         LY_ARRAY_FOR(path[u].predicates, v) {
             struct ly_path_predicate *pred = &path[u].predicates[v];
 
-            switch (pred->type) {
+            switch (path[u].pred_type) {
+            case LY_PATH_PREDTYPE_NONE:
+                break;
             case LY_PATH_PREDTYPE_POSITION:
                 /* position predicate */
                 ret = ly_strcat(&result, "[%" PRIu64 "]", pred->position);
@@ -131,16 +126,6 @@ node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, voi
                     free((char *)strval);
                 }
                 break;
-            case LY_PATH_PREDTYPE_LIST_VAR:
-                /* key-predicate with a variable */
-                if (inherit_prefix) {
-                    /* always the same prefix as the parent */
-                    ret = ly_strcat(&result, "[%s=$%s]", pred->key->name, pred->variable);
-                } else {
-                    ret = ly_strcat(&result, "[%s:%s=$%s]", lyplg_type_get_prefix(pred->key->module, format, prefix_data),
-                            pred->key->name, pred->variable);
-                }
-                break;
             }
 
             LY_CHECK_GOTO(ret, cleanup);
@@ -167,7 +152,7 @@ lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_typ
     LY_ERR ret = LY_SUCCESS;
     struct lyxp_expr *exp = NULL;
     uint32_t prefix_opt = 0;
-    struct ly_path *path = NULL;
+    struct ly_path *path;
     char *canon;
 
     /* init storage */
@@ -178,11 +163,6 @@ lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_typ
     ret = lyplg_type_check_hints(hints, value, value_len, type->basetype, NULL, err);
     LY_CHECK_GOTO(ret, cleanup);
 
-    if ((((char *)value)[0] == '/') && (value_len == 1)) {
-        /* special path */
-        goto store;
-    }
-
     switch (format) {
     case LY_VALUE_SCHEMA:
     case LY_VALUE_SCHEMA_RESOLVED:
@@ -192,7 +172,6 @@ lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_typ
     case LY_VALUE_CANON:
     case LY_VALUE_LYB:
     case LY_VALUE_JSON:
-    case LY_VALUE_STR_NS:
         prefix_opt = LY_PATH_PREFIX_STRICT_INHERIT;
         break;
     }
@@ -201,7 +180,7 @@ lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_typ
     ret = ly_path_parse(ctx, ctx_node, value, value_len, 0, LY_PATH_BEGIN_ABSOLUTE, prefix_opt, LY_PATH_PRED_SIMPLE, &exp);
     if (ret) {
         ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL,
-                "Invalid node-instance-identifier \"%.*s\" value - syntax error.", (int)value_len, (char *)value);
+                "Invalid instance-identifier \"%.*s\" value - syntax error.", (int)value_len, (char *)value);
         goto cleanup;
     }
 
@@ -210,18 +189,15 @@ lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_typ
         LY_CHECK_GOTO(ret = lys_compile_expr_implement(ctx, exp, format, prefix_data, 1, unres, NULL), cleanup);
     }
 
-    /* resolve it on schema tree, use JSON format instead of LYB because for this type they are equal but for some
-     * nested types (such as numbers in predicates in the path) LYB would be invalid */
-    ret = ly_path_compile(ctx, NULL, ctx_node, NULL, exp, (ctx_node && (ctx_node->flags & LYS_IS_OUTPUT)) ?
-            LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT, LY_PATH_TARGET_MANY, 1, (format == LY_VALUE_LYB) ?
-            LY_VALUE_JSON : format, prefix_data, &path);
+    /* resolve it on schema tree */
+    ret = ly_path_compile(ctx, NULL, ctx_node, NULL, exp, (ctx_node->flags & LYS_IS_OUTPUT) ?
+            LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT, LY_PATH_TARGET_MANY, 1, format, prefix_data, &path);
     if (ret) {
         ret = ly_err_new(err, ret, LYVE_DATA, NULL, NULL,
-                "Invalid node-instance-identifier \"%.*s\" value - semantic error.", (int)value_len, (char *)value);
+                "Invalid instance-identifier \"%.*s\" value - semantic error.", (int)value_len, (char *)value);
         goto cleanup;
     }
 
-store:
     /* store value */
     storage->target = path;
 
@@ -237,7 +213,7 @@ store:
         }
     } else {
         /* JSON format with prefix is the canonical one */
-        ret = node_instanceid_path2str(path, LY_VALUE_JSON, NULL, &canon);
+        ret = instanceid_path2str(path, LY_VALUE_JSON, NULL, &canon);
         LY_CHECK_GOTO(ret, cleanup);
 
         ret = lydict_insert_zc(ctx, canon, &storage->_canonical);
@@ -256,36 +232,6 @@ cleanup:
     return ret;
 }
 
-/**
- * @brief Implementation of ::lyplg_type_print_clb for the node-instance-identifier ietf-netconf-acm type.
- */
-static const void *
-lyplg_type_print_node_instanceid(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *value, LY_VALUE_FORMAT format,
-        void *prefix_data, ly_bool *dynamic, size_t *value_len)
-{
-    char *ret;
-
-    if ((format == LY_VALUE_CANON) || (format == LY_VALUE_JSON) || (format == LY_VALUE_LYB)) {
-        if (dynamic) {
-            *dynamic = 0;
-        }
-        if (value_len) {
-            *value_len = strlen(value->_canonical);
-        }
-        return value->_canonical;
-    }
-
-    /* print the value in the specific format */
-    if (node_instanceid_path2str(value->target, format, prefix_data, &ret)) {
-        return NULL;
-    }
-    *dynamic = 1;
-    if (value_len) {
-        *value_len = strlen(ret);
-    }
-    return ret;
-}
-
 /**
  * @brief Plugin information for instance-identifier type implementation.
  *
@@ -304,7 +250,7 @@ const struct lyplg_type_record plugins_node_instanceid[] = {
         .plugin.validate = NULL,
         .plugin.compare = lyplg_type_compare_instanceid,
         .plugin.sort = NULL,
-        .plugin.print = lyplg_type_print_node_instanceid,
+        .plugin.print = lyplg_type_print_instanceid,
         .plugin.duplicate = lyplg_type_dup_instanceid,
         .plugin.free = lyplg_type_free_instanceid,
         .plugin.lyb_data_len = -1,
@@ -319,7 +265,7 @@ const struct lyplg_type_record plugins_node_instanceid[] = {
         .plugin.validate = NULL,
         .plugin.compare = lyplg_type_compare_instanceid,
         .plugin.sort = NULL,
-        .plugin.print = lyplg_type_print_node_instanceid,
+        .plugin.print = lyplg_type_print_instanceid,
         .plugin.duplicate = lyplg_type_dup_instanceid,
         .plugin.free = lyplg_type_free_instanceid,
         .plugin.lyb_data_len = -1,
