@@ -12,22 +12,17 @@
  *     https://opensource.org/licenses/BSD-3-Clause
  */
 
-#define _GNU_SOURCE
-
 #include "plugins_types.h"
 
-#include <assert.h>
 #include <stdint.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include "libyang.h"
 
 #include "common.h"
 #include "compat.h"
 
-/* internal headers */
-#include "xml.h"
+/* internal header */
 #include "xpath.h"
 
 /**
@@ -39,8 +34,34 @@
  * | string length | yes | `char *` | string JSON format of the XPath expression |
  */
 
-LIBYANG_API_DEF LY_ERR
-lyplg_type_xpath10_print_token(const char *token, uint16_t tok_len, ly_bool is_nametest, const struct lys_module **context_mod,
+/**
+ * @brief Stored value structure for xpath1.0
+ */
+struct lyd_value_xpath10 {
+    struct lyxp_expr *exp;
+    const struct ly_ctx *ctx;
+    void *prefix_data;
+    LY_VALUE_FORMAT format;
+};
+
+/**
+ * @brief Print xpath1.0 token in the specific format.
+ *
+ * @param[in] token Token to transform.
+ * @param[in] tok_len Lenghth of @p token.
+ * @param[in] is_nametest Whether the token is a nametest, it then always requires a prefix in XML @p get_format.
+ * @param[in,out] context_mod Current context module, may be updated.
+ * @param[in] resolve_ctx Context to use for resolving prefixes.
+ * @param[in] resolve_format Format of the resolved prefixes.
+ * @param[in] resolve_prefix_data Resolved prefixes prefix data.
+ * @param[in] get_format Format of the output prefixes.
+ * @param[in] get_prefix_data Format-specific prefix data for the output.
+ * @param[out] token_p Printed token.
+ * @param[out] err Error structure on error.
+ * @return LY_ERR value.
+ */
+static LY_ERR
+xpath10_print_token(const char *token, uint16_t tok_len, ly_bool is_nametest, const struct lys_module **context_mod,
         const struct ly_ctx *resolve_ctx, LY_VALUE_FORMAT resolve_format, const void *resolve_prefix_data,
         LY_VALUE_FORMAT get_format, void *get_prefix_data, char **token_p, struct ly_err_item **err)
 {
@@ -164,7 +185,7 @@ xpath10_print_subexpr_r(uint16_t *cur_idx, enum lyxp_token end_tok, const struct
         if ((cur_tok == LYXP_TOKEN_NAMETEST) || (cur_tok == LYXP_TOKEN_LITERAL)) {
             /* tokens that may include prefixes, get them in the target format */
             is_nt = (cur_tok == LYXP_TOKEN_NAMETEST) ? 1 : 0;
-            LY_CHECK_RET(lyplg_type_xpath10_print_token(cur_exp_ptr, xp_val->exp->tok_len[*cur_idx], is_nt, &context_mod,
+            LY_CHECK_RET(xpath10_print_token(cur_exp_ptr, xp_val->exp->tok_len[*cur_idx], is_nt, &context_mod,
                     xp_val->ctx, xp_val->format, xp_val->prefix_data, format, prefix_data, &str_tok, err));
 
             /* append the converted token */
@@ -216,8 +237,18 @@ error_mem:
     return ly_err_new(err, LY_EMEM, LYVE_DATA, NULL, NULL, "No memory.");
 }
 
-LIBYANG_API_DEF LY_ERR
-lyplg_type_print_xpath10_value(const struct lyd_value_xpath10 *xp_val, LY_VALUE_FORMAT format, void *prefix_data,
+/**
+ * @brief Print xpath1.0 value in the specific format.
+ *
+ * @param[in] xp_val xpath1.0 value structure.
+ * @param[in] format Format to print in.
+ * @param[in] prefix_data Format-specific prefix data.
+ * @param[out] str_value Printed value.
+ * @param[out] err Error structure on error.
+ * @return LY_ERR value.
+ */
+static LY_ERR
+xpath10_print_value(const struct lyd_value_xpath10 *xp_val, LY_VALUE_FORMAT format, void *prefix_data,
         char **str_value, struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
@@ -225,22 +256,21 @@ lyplg_type_print_xpath10_value(const struct lyd_value_xpath10 *xp_val, LY_VALUE_
     uint32_t str_len = 0;
 
     *str_value = NULL;
-    *err = NULL;
 
     /* recursively print the expression */
     ret = xpath10_print_subexpr_r(&expr_idx, 0, NULL, xp_val, format, prefix_data, str_value, &str_len, err);
 
     if (ret) {
         free(*str_value);
-        *str_value = NULL;
     }
     return ret;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_store_xpath10(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, size_t value_len,
-        uint32_t options, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node,
-        struct lyd_value *storage, struct lys_glob_unres *UNUSED(unres), struct ly_err_item **err)
+        uint32_t options, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints,
+        const struct lysc_node *UNUSED(ctx_node), struct lyd_value *storage, struct lys_glob_unres *UNUSED(unres),
+        struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
     struct lysc_type_str *type_str = (struct lysc_type_str *)type;
@@ -268,47 +298,32 @@ lyplg_type_store_xpath10(const struct ly_ctx *ctx, const struct lysc_type *type,
     ret = lyplg_type_validate_patterns(type_str->patterns, value, value_len, err);
     LY_CHECK_GOTO(ret, cleanup);
 
-    /* parse */
-    ret = lyxp_expr_parse(ctx, value_len ? value : "", value_len, 1, &val->exp);
+    /* store format-specific data and context for later prefix resolution */
+    ret = lyplg_type_prefix_data_new(ctx, value, value_len, format, prefix_data, &val->format, &val->prefix_data);
     LY_CHECK_GOTO(ret, cleanup);
     val->ctx = ctx;
 
-    if (ctx_node && !strcmp(ctx_node->name, "parent-reference") && !strcmp(ctx_node->module->name, "ietf-yang-schema-mount")) {
-        /* special case, this type uses prefix-namespace mapping provided directly in data, keep empty for now */
-        val->format = format = LY_VALUE_STR_NS;
-        ret = ly_set_new((struct ly_set **)&val->prefix_data);
-        LY_CHECK_GOTO(ret, cleanup);
-    } else {
-        /* store format-specific data and context for later prefix resolution */
-        ret = lyplg_type_prefix_data_new(ctx, value, value_len, format, prefix_data, &val->format, &val->prefix_data);
-        LY_CHECK_GOTO(ret, cleanup);
-    }
+    /* parse */
+    ret = lyxp_expr_parse(ctx, value, value_len, 1, &val->exp);
+    LY_CHECK_GOTO(ret, cleanup);
 
-    switch (format) {
-    case LY_VALUE_CANON:
-    case LY_VALUE_JSON:
-    case LY_VALUE_LYB:
-    case LY_VALUE_STR_NS:
-        /* store canonical value */
+    /* store canonical value */
+    if ((format == LY_VALUE_CANON) || (format == LY_VALUE_JSON) || (format == LY_VALUE_LYB)) {
         if (options & LYPLG_TYPE_STORE_DYNAMIC) {
             ret = lydict_insert_zc(ctx, (char *)value, &storage->_canonical);
             options &= ~LYPLG_TYPE_STORE_DYNAMIC;
             LY_CHECK_GOTO(ret, cleanup);
         } else {
-            ret = lydict_insert(ctx, value_len ? value : "", value_len, &storage->_canonical);
+            ret = lydict_insert(ctx, value, value_len, &storage->_canonical);
             LY_CHECK_GOTO(ret, cleanup);
         }
-        break;
-    case LY_VALUE_SCHEMA:
-    case LY_VALUE_SCHEMA_RESOLVED:
-    case LY_VALUE_XML:
+    } else {
         /* JSON format with prefix is the canonical one */
-        ret = lyplg_type_print_xpath10_value(val, LY_VALUE_JSON, NULL, &canon, err);
+        ret = xpath10_print_value(val, LY_VALUE_JSON, NULL, &canon, err);
         LY_CHECK_GOTO(ret, cleanup);
 
         ret = lydict_insert_zc(ctx, canon, &storage->_canonical);
         LY_CHECK_GOTO(ret, cleanup);
-        break;
     }
 
 cleanup:
@@ -318,118 +333,11 @@ cleanup:
 
     if (ret) {
         lyplg_type_free_xpath10(ctx, storage);
-    } else if (val->format == LY_VALUE_STR_NS) {
-        /* needs validation */
-        return LY_EINCOMPLETE;
     }
     return ret;
 }
 
-/**
- * @brief Create a namespace and add it into a set.
- *
- * @param[in] set Set of namespaces to add to.
- * @param[in] pref Namespace prefix.
- * @param[in] uri Namespace URI.
- * @return LY_ERR value.
- */
-static LY_ERR
-xpath10_add_ns(struct ly_set *set, const char *pref, const char *uri)
-{
-    LY_ERR rc = LY_SUCCESS;
-    struct lyxml_ns *ns = NULL;
-
-    /* create new ns */
-    ns = calloc(1, sizeof *ns);
-    if (!ns) {
-        rc = LY_EMEM;
-        goto cleanup;
-    }
-    ns->prefix = strdup(pref);
-    ns->uri = strdup(uri);
-    if (!ns->prefix || !ns->uri) {
-        rc = LY_EMEM;
-        goto cleanup;
-    }
-    ns->depth = 1;
-
-    /* add into the XML namespace set */
-    if ((rc = ly_set_add(set, ns, 1, NULL))) {
-        goto cleanup;
-    }
-    ns = NULL;
-
-cleanup:
-    if (ns) {
-        free(ns->prefix);
-        free(ns->uri);
-        free(ns);
-    }
-    return rc;
-}
-
-/**
- * @brief Implementation of ::lyplg_type_validate_clb for the xpath1.0 ietf-yang-types type.
- */
-static LY_ERR
-lyplg_type_validate_xpath10(const struct ly_ctx *UNUSED(ctx), const struct lysc_type *UNUSED(type),
-        const struct lyd_node *ctx_node, const struct lyd_node *UNUSED(tree), struct lyd_value *storage,
-        struct ly_err_item **err)
-{
-    LY_ERR ret = LY_SUCCESS;
-    struct lyd_value_xpath10 *val;
-    struct ly_set *set = NULL;
-    uint32_t i;
-    const char *pref, *uri;
-
-    *err = NULL;
-    LYD_VALUE_GET(storage, val);
-
-    if (val->format != LY_VALUE_STR_NS) {
-        /* nothing to validate */
-        return LY_SUCCESS;
-    }
-
-    /* the XML namespace set must exist */
-    assert(val->prefix_data);
-
-    /* special handling of this particular node */
-    assert(!strcmp(LYD_NAME(ctx_node), "parent-reference") &&
-            !strcmp(ctx_node->schema->module->name, "ietf-yang-schema-mount"));
-
-    /* get all the prefix mappings */
-    if ((ret = lyd_find_xpath(ctx_node, "../../../namespace", &set))) {
-        goto cleanup;
-    }
-
-    for (i = 0; i < set->count; ++i) {
-        assert(!strcmp(LYD_NAME(lyd_child(set->dnodes[i])), "prefix"));
-        pref = lyd_get_value(lyd_child(set->dnodes[i]));
-
-        if (!lyd_child(set->dnodes[i])->next) {
-            /* missing URI - invalid mapping, skip */
-            continue;
-        }
-        assert(!strcmp(LYD_NAME(lyd_child(set->dnodes[i])->next), "uri"));
-        uri = lyd_get_value(lyd_child(set->dnodes[i])->next);
-
-        /* new NS */
-        if ((ret = xpath10_add_ns(val->prefix_data, pref, uri))) {
-            goto cleanup;
-        }
-    }
-
-cleanup:
-    ly_set_free(set, NULL);
-    if (ret == LY_EMEM) {
-        ly_err_new(err, LY_EMEM, LYVE_DATA, NULL, NULL, LY_EMEM_MSG);
-    } else if (ret) {
-        ly_err_new(err, ret, LYVE_DATA, NULL, NULL, "%s", ly_errmsg(LYD_CTX(ctx_node)));
-    }
-    return ret;
-}
-
-LIBYANG_API_DEF const void *
+API const void *
 lyplg_type_print_xpath10(const struct ly_ctx *ctx, const struct lyd_value *value, LY_VALUE_FORMAT format,
         void *prefix_data, ly_bool *dynamic, size_t *value_len)
 {
@@ -439,9 +347,7 @@ lyplg_type_print_xpath10(const struct ly_ctx *ctx, const struct lyd_value *value
 
     LYD_VALUE_GET(value, val);
 
-    /* LY_VALUE_STR_NS should never be transformed */
-    if ((val->format == LY_VALUE_STR_NS) || (format == LY_VALUE_CANON) || (format == LY_VALUE_JSON) ||
-            (format == LY_VALUE_LYB)) {
+    if ((format == LY_VALUE_CANON) || (format == LY_VALUE_JSON) || (format == LY_VALUE_LYB)) {
         /* canonical */
         if (dynamic) {
             *dynamic = 0;
@@ -453,7 +359,7 @@ lyplg_type_print_xpath10(const struct ly_ctx *ctx, const struct lyd_value *value
     }
 
     /* print in the specific format */
-    if (lyplg_type_print_xpath10_value(val, format, prefix_data, &ret, &err)) {
+    if (xpath10_print_value(val, format, prefix_data, &ret, &err)) {
         if (err) {
             LOGVAL_ERRITEM(ctx, err);
             ly_err_free(err);
@@ -468,7 +374,7 @@ lyplg_type_print_xpath10(const struct ly_ctx *ctx, const struct lyd_value *value
     return ret;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyplg_type_dup_xpath10(const struct ly_ctx *ctx, const struct lyd_value *original, struct lyd_value *dup)
 {
     LY_ERR ret = LY_SUCCESS;
@@ -486,7 +392,7 @@ lyplg_type_dup_xpath10(const struct ly_ctx *ctx, const struct lyd_value *origina
     dup_val->ctx = ctx;
 
     LYD_VALUE_GET(original, orig_val);
-    ret = lyxp_expr_dup(ctx, orig_val->exp, 0, 0, &dup_val->exp);
+    ret = lyxp_expr_dup(ctx, orig_val->exp, &dup_val->exp);
     LY_CHECK_GOTO(ret, cleanup);
 
     ret = lyplg_type_prefix_data_dup(ctx, orig_val->format, orig_val->prefix_data, &dup_val->prefix_data);
@@ -500,7 +406,7 @@ cleanup:
     return ret;
 }
 
-LIBYANG_API_DEF void
+API void
 lyplg_type_free_xpath10(const struct ly_ctx *ctx, struct lyd_value *value)
 {
     struct lyd_value_xpath10 *val;
@@ -531,7 +437,7 @@ const struct lyplg_type_record plugins_xpath10[] = {
 
         .plugin.id = "libyang 2 - xpath1.0, version 1",
         .plugin.store = lyplg_type_store_xpath10,
-        .plugin.validate = lyplg_type_validate_xpath10,
+        .plugin.validate = NULL,
         .plugin.compare = lyplg_type_compare_simple,
         .plugin.sort = NULL,
         .plugin.print = lyplg_type_print_xpath10,
