@@ -59,69 +59,69 @@ struct xmlpr_ctx {
  * @return Printed prefix of the namespace to use.
  */
 static const char *
-xml_print_ns(struct xmlpr_ctx *pctx, const char *ns, const char *new_prefix, uint32_t prefix_opts)
+xml_print_ns(struct xmlpr_ctx *ctx, const char *ns, const char *new_prefix, uint32_t prefix_opts)
 {
     uint32_t i;
 
-    for (i = pctx->ns.count; i > 0; --i) {
+    for (i = ctx->ns.count; i > 0; --i) {
         if (!new_prefix) {
             /* find default namespace */
-            if (!pctx->prefix.objs[i - 1]) {
-                if (!strcmp(pctx->ns.objs[i - 1], ns)) {
+            if (!ctx->prefix.objs[i - 1]) {
+                if (!strcmp(ctx->ns.objs[i - 1], ns)) {
                     /* matching default namespace */
-                    return pctx->prefix.objs[i - 1];
+                    return ctx->prefix.objs[i - 1];
                 }
                 /* not matching default namespace */
                 break;
             }
         } else {
             /* find prefixed namespace */
-            if (!strcmp(pctx->ns.objs[i - 1], ns)) {
-                if (!pctx->prefix.objs[i - 1]) {
+            if (!strcmp(ctx->ns.objs[i - 1], ns)) {
+                if (!ctx->prefix.objs[i - 1]) {
                     /* default namespace is not interesting */
                     continue;
                 }
 
-                if (!strcmp(pctx->prefix.objs[i - 1], new_prefix) || !(prefix_opts & LYXML_PREFIX_REQUIRED)) {
+                if (!strcmp(ctx->prefix.objs[i - 1], new_prefix) || !(prefix_opts & LYXML_PREFIX_REQUIRED)) {
                     /* the same prefix or can be any */
-                    return pctx->prefix.objs[i - 1];
+                    return ctx->prefix.objs[i - 1];
                 }
             }
         }
     }
 
     /* suitable namespace not found, must be printed */
-    ly_print_(pctx->out, " xmlns%s%s=\"%s\"", new_prefix ? ":" : "", new_prefix ? new_prefix : "", ns);
+    ly_print_(ctx->out, " xmlns%s%s=\"%s\"", new_prefix ? ":" : "", new_prefix ? new_prefix : "", ns);
 
     /* and added into namespaces */
     if (new_prefix) {
-        LY_CHECK_RET(lydict_insert(pctx->ctx, new_prefix, 0, &new_prefix), NULL);
+        LY_CHECK_RET(lydict_insert(ctx->ctx, new_prefix, 0, &new_prefix), NULL);
     }
-    LY_CHECK_RET(ly_set_add(&pctx->prefix, (void *)new_prefix, 1, NULL), NULL);
-    LY_CHECK_RET(ly_set_add(&pctx->ns, (void *)ns, 1, &i), NULL);
+    LY_CHECK_RET(ly_set_add(&ctx->prefix, (void *)new_prefix, 1, NULL), NULL);
+    LY_CHECK_RET(ly_set_add(&ctx->ns, (void *)ns, 1, &i), NULL);
 
     /* return it */
-    return pctx->prefix.objs[i];
+    return ctx->prefix.objs[i];
 }
 
 static const char *
-xml_print_ns_opaq(struct xmlpr_ctx *pctx, LY_VALUE_FORMAT format, const struct ly_opaq_name *name, uint32_t prefix_opts)
+xml_print_ns_opaq(struct xmlpr_ctx *ctx, LY_VALUE_FORMAT format, const struct ly_opaq_name *name, uint32_t prefix_opts)
 {
     switch (format) {
     case LY_VALUE_XML:
-        return xml_print_ns(pctx, name->module_ns, (prefix_opts & LYXML_PREFIX_DEFAULT) ? NULL : name->prefix, prefix_opts);
+        return xml_print_ns(ctx, name->module_ns, (prefix_opts & LYXML_PREFIX_DEFAULT) ? NULL : name->prefix, prefix_opts);
         break;
     case LY_VALUE_JSON:
         if (name->module_name) {
-            const struct lys_module *mod = ly_ctx_get_module_latest(pctx->ctx, name->module_name);
+            const struct lys_module *mod = ly_ctx_get_module_latest(ctx->ctx, name->module_name);
             if (mod) {
-                return xml_print_ns(pctx, mod->ns, (prefix_opts & LYXML_PREFIX_DEFAULT) ? NULL : name->prefix, prefix_opts);
+                return xml_print_ns(ctx, mod->ns, (prefix_opts & LYXML_PREFIX_DEFAULT) ? NULL : name->prefix, prefix_opts);
             }
         }
         break;
     default:
         /* cannot be created */
-        LOGINT(pctx->ctx);
+        LOGINT(ctx->ctx);
     }
 
     return NULL;
@@ -137,7 +137,7 @@ xml_print_ns_opaq(struct xmlpr_ctx *pctx, LY_VALUE_FORMAT format, const struct l
  * @return LY_ERR value.
  */
 static void
-xml_print_ns_prefix_data(struct xmlpr_ctx *pctx, LY_VALUE_FORMAT format, void *prefix_data, uint32_t prefix_opts)
+xml_print_ns_prefix_data(struct xmlpr_ctx *ctx, LY_VALUE_FORMAT format, void *prefix_data, uint32_t prefix_opts)
 {
     const struct ly_set *set;
     const struct lyxml_ns *ns;
@@ -148,17 +148,12 @@ xml_print_ns_prefix_data(struct xmlpr_ctx *pctx, LY_VALUE_FORMAT format, void *p
         set = prefix_data;
         for (i = 0; i < set->count; ++i) {
             ns = set->objs[i];
-            if (!ns->prefix) {
-                /* default namespace is not for the element */
-                continue;
-            }
-
-            xml_print_ns(pctx, ns->uri, (prefix_opts & LYXML_PREFIX_DEFAULT) ? NULL : ns->prefix, prefix_opts);
+            xml_print_ns(ctx, ns->uri, (prefix_opts & LYXML_PREFIX_DEFAULT) ? NULL : ns->prefix, prefix_opts);
         }
         break;
     default:
         /* cannot be created */
-        LOGINT(pctx->ctx);
+        LOGINT(ctx->ctx);
     }
 }
 
@@ -166,7 +161,7 @@ xml_print_ns_prefix_data(struct xmlpr_ctx *pctx, LY_VALUE_FORMAT format, void *p
  * TODO
  */
 static void
-xml_print_meta(struct xmlpr_ctx *pctx, const struct lyd_node *node)
+xml_print_meta(struct xmlpr_ctx *ctx, const struct lyd_node *node)
 {
     struct lyd_meta *meta;
     const struct lys_module *mod;
@@ -176,12 +171,12 @@ xml_print_meta(struct xmlpr_ctx *pctx, const struct lyd_node *node)
 
     /* with-defaults */
     if (node->schema->nodetype & LYD_NODE_TERM) {
-        if (((node->flags & LYD_DEFAULT) && (pctx->options & (LYD_PRINT_WD_ALL_TAG | LYD_PRINT_WD_IMPL_TAG))) ||
-                ((pctx->options & LYD_PRINT_WD_ALL_TAG) && lyd_is_default(node))) {
+        if (((node->flags & LYD_DEFAULT) && (ctx->options & (LYD_PRINT_WD_ALL_TAG | LYD_PRINT_WD_IMPL_TAG))) ||
+                ((ctx->options & LYD_PRINT_WD_ALL_TAG) && lyd_is_default(node))) {
             /* we have implicit OR explicit default node, print attribute only if context include with-defaults schema */
             mod = ly_ctx_get_module_latest(LYD_CTX(node), "ietf-netconf-with-defaults");
             if (mod) {
-                ly_print_(pctx->out, " %s:default=\"true\"", xml_print_ns(pctx, mod->ns, mod->prefix, 0));
+                ly_print_(ctx->out, " %s:default=\"true\"", xml_print_ns(ctx, mod->ns, mod->prefix, 0));
             }
         }
     }
@@ -202,7 +197,7 @@ xml_print_meta(struct xmlpr_ctx *pctx, const struct lyd_node *node)
         /* print namespaces connected with the value's prefixes */
         for (uint32_t i = 0; i < ns_list.count; ++i) {
             mod = ns_list.objs[i];
-            xml_print_ns(pctx, mod->ns, mod->prefix, 1);
+            xml_print_ns(ctx, mod->ns, mod->prefix, 1);
         }
         ly_set_erase(&ns_list, NULL);
 
@@ -210,17 +205,17 @@ xml_print_meta(struct xmlpr_ctx *pctx, const struct lyd_node *node)
         if (filter_attrs && !strcmp(mod->name, "ietf-netconf") && (!strcmp(meta->name, "type") ||
                 !strcmp(meta->name, "select"))) {
             /* print special NETCONF filter unqualified attributes */
-            ly_print_(pctx->out, " %s=\"", meta->name);
+            ly_print_(ctx->out, " %s=\"", meta->name);
         } else {
             /* print the metadata with its namespace */
-            ly_print_(pctx->out, " %s:%s=\"", xml_print_ns(pctx, mod->ns, mod->prefix, 1), meta->name);
+            ly_print_(ctx->out, " %s:%s=\"", xml_print_ns(ctx, mod->ns, mod->prefix, 1), meta->name);
         }
 
         /* print metadata value */
         if (value && value[0]) {
-            lyxml_dump_text(pctx->out, value, 1);
+            lyxml_dump_text(ctx->out, value, 1);
         }
-        ly_print_(pctx->out, "\"");
+        ly_print_(ctx->out, "\"");
         if (dynamic) {
             free((void *)value);
         }
@@ -236,20 +231,20 @@ xml_print_meta(struct xmlpr_ctx *pctx, const struct lyd_node *node)
  * @param[in] node Data node to be printed.
  */
 static void
-xml_print_node_open(struct xmlpr_ctx *pctx, const struct lyd_node *node)
+xml_print_node_open(struct xmlpr_ctx *ctx, const struct lyd_node *node)
 {
     /* print node name */
-    ly_print_(pctx->out, "%*s<%s", INDENT, node->schema->name);
+    ly_print_(ctx->out, "%*s<%s", INDENT, node->schema->name);
 
     /* print default namespace */
-    xml_print_ns(pctx, node->schema->module->ns, NULL, 0);
+    xml_print_ns(ctx, node->schema->module->ns, NULL, 0);
 
     /* print metadata */
-    xml_print_meta(pctx, node);
+    xml_print_meta(ctx, node);
 }
 
 static LY_ERR
-xml_print_attr(struct xmlpr_ctx *pctx, const struct lyd_node_opaq *node)
+xml_print_attr(struct xmlpr_ctx *ctx, const struct lyd_node_opaq *node)
 {
     const struct lyd_attr *attr;
     const char *pref;
@@ -258,18 +253,18 @@ xml_print_attr(struct xmlpr_ctx *pctx, const struct lyd_node_opaq *node)
         pref = NULL;
         if (attr->name.prefix) {
             /* print attribute namespace */
-            pref = xml_print_ns_opaq(pctx, attr->format, &attr->name, 0);
+            pref = xml_print_ns_opaq(ctx, attr->format, &attr->name, 0);
         }
 
         /* print namespaces connected with the value's prefixes */
         if (attr->val_prefix_data) {
-            xml_print_ns_prefix_data(pctx, attr->format, attr->val_prefix_data, LYXML_PREFIX_REQUIRED);
+            xml_print_ns_prefix_data(ctx, attr->format, attr->val_prefix_data, LYXML_PREFIX_REQUIRED);
         }
 
         /* print the attribute with its prefix and value */
-        ly_print_(pctx->out, " %s%s%s=\"", pref ? pref : "", pref ? ":" : "", attr->name.name);
-        lyxml_dump_text(pctx->out, attr->value, 1);
-        ly_print_(pctx->out, "\""); /* print attribute value terminator */
+        ly_print_(ctx->out, " %s%s%s=\"", pref ? pref : "", pref ? ":" : "", attr->name.name);
+        lyxml_dump_text(ctx->out, attr->value, 1);
+        ly_print_(ctx->out, "\""); /* print attribute value terminator */
 
     }
 
@@ -277,21 +272,21 @@ xml_print_attr(struct xmlpr_ctx *pctx, const struct lyd_node_opaq *node)
 }
 
 static LY_ERR
-xml_print_opaq_open(struct xmlpr_ctx *pctx, const struct lyd_node_opaq *node)
+xml_print_opaq_open(struct xmlpr_ctx *ctx, const struct lyd_node_opaq *node)
 {
     /* print node name */
-    ly_print_(pctx->out, "%*s<%s", INDENT, node->name.name);
+    ly_print_(ctx->out, "%*s<%s", INDENT, node->name.name);
 
     /* print default namespace */
-    xml_print_ns_opaq(pctx, node->format, &node->name, LYXML_PREFIX_DEFAULT);
+    xml_print_ns_opaq(ctx, node->format, &node->name, LYXML_PREFIX_DEFAULT);
 
     /* print attributes */
-    LY_CHECK_RET(xml_print_attr(pctx, node));
+    LY_CHECK_RET(xml_print_attr(ctx, node));
 
     return LY_SUCCESS;
 }
 
-static LY_ERR xml_print_node(struct xmlpr_ctx *pctx, const struct lyd_node *node);
+static LY_ERR xml_print_node(struct xmlpr_ctx *ctx, const struct lyd_node *node);
 
 /**
  * @brief Print XML element representing lyd_node_term.
@@ -301,13 +296,13 @@ static LY_ERR xml_print_node(struct xmlpr_ctx *pctx, const struct lyd_node *node
  * @return LY_ERR value.
  */
 static LY_ERR
-xml_print_term(struct xmlpr_ctx *pctx, const struct lyd_node_term *node)
+xml_print_term(struct xmlpr_ctx *ctx, const struct lyd_node_term *node)
 {
     struct ly_set ns_list = {0};
     ly_bool dynamic;
     const char *value;
 
-    xml_print_node_open(pctx, &node->node);
+    xml_print_node_open(ctx, &node->node);
     value = ((struct lysc_node_leaf *)node->schema)->type->plugin->print(LYD_CTX(node), &node->value, LY_VALUE_XML,
             &ns_list, &dynamic, NULL);
     LY_CHECK_RET(!value, LY_EINVAL);
@@ -315,16 +310,16 @@ xml_print_term(struct xmlpr_ctx *pctx, const struct lyd_node_term *node)
     /* print namespaces connected with the values's prefixes */
     for (uint32_t u = 0; u < ns_list.count; ++u) {
         const struct lys_module *mod = (const struct lys_module *)ns_list.objs[u];
-        ly_print_(pctx->out, " xmlns:%s=\"%s\"", mod->prefix, mod->ns);
+        ly_print_(ctx->out, " xmlns:%s=\"%s\"", mod->prefix, mod->ns);
     }
     ly_set_erase(&ns_list, NULL);
 
     if (!value[0]) {
-        ly_print_(pctx->out, "/>%s", DO_FORMAT ? "\n" : "");
+        ly_print_(ctx->out, "/>%s", DO_FORMAT ? "\n" : "");
     } else {
-        ly_print_(pctx->out, ">");
-        lyxml_dump_text(pctx->out, value, 0);
-        ly_print_(pctx->out, "</%s>%s", node->schema->name, DO_FORMAT ? "\n" : "");
+        ly_print_(ctx->out, ">");
+        lyxml_dump_text(ctx->out, value, 0);
+        ly_print_(ctx->out, "</%s>%s", node->schema->name, DO_FORMAT ? "\n" : "");
     }
     if (dynamic) {
         free((void *)value);
@@ -341,53 +336,53 @@ xml_print_term(struct xmlpr_ctx *pctx, const struct lyd_node_term *node)
  * @return LY_ERR value.
  */
 static LY_ERR
-xml_print_inner(struct xmlpr_ctx *pctx, const struct lyd_node_inner *node)
+xml_print_inner(struct xmlpr_ctx *ctx, const struct lyd_node_inner *node)
 {
     LY_ERR ret;
     struct lyd_node *child;
 
-    xml_print_node_open(pctx, &node->node);
+    xml_print_node_open(ctx, &node->node);
 
     LY_LIST_FOR(node->child, child) {
-        if (lyd_node_should_print(child, pctx->options)) {
+        if (ly_should_print(child, ctx->options)) {
             break;
         }
     }
     if (!child) {
         /* there are no children that will be printed */
-        ly_print_(pctx->out, "/>%s", DO_FORMAT ? "\n" : "");
+        ly_print_(ctx->out, "/>%s", DO_FORMAT ? "\n" : "");
         return LY_SUCCESS;
     }
 
     /* children */
-    ly_print_(pctx->out, ">%s", DO_FORMAT ? "\n" : "");
+    ly_print_(ctx->out, ">%s", DO_FORMAT ? "\n" : "");
 
     LEVEL_INC;
     LY_LIST_FOR(node->child, child) {
-        ret = xml_print_node(pctx, child);
+        ret = xml_print_node(ctx, child);
         LY_CHECK_ERR_RET(ret, LEVEL_DEC, ret);
     }
     LEVEL_DEC;
 
-    ly_print_(pctx->out, "%*s</%s>%s", INDENT, node->schema->name, DO_FORMAT ? "\n" : "");
+    ly_print_(ctx->out, "%*s</%s>%s", INDENT, node->schema->name, DO_FORMAT ? "\n" : "");
 
     return LY_SUCCESS;
 }
 
 static LY_ERR
-xml_print_anydata(struct xmlpr_ctx *pctx, const struct lyd_node_any *node)
+xml_print_anydata(struct xmlpr_ctx *ctx, const struct lyd_node_any *node)
 {
     struct lyd_node_any *any = (struct lyd_node_any *)node;
     struct lyd_node *iter;
     uint32_t prev_opts, prev_lo;
     LY_ERR ret;
 
-    xml_print_node_open(pctx, &node->node);
+    xml_print_node_open(ctx, &node->node);
 
     if (!any->value.tree) {
         /* no content */
 no_content:
-        ly_print_(pctx->out, "/>%s", DO_FORMAT ? "\n" : "");
+        ly_print_(ctx->out, "/>%s", DO_FORMAT ? "\n" : "");
         return LY_SUCCESS;
     } else {
         if (any->value_type == LYD_ANYDATA_LYB) {
@@ -409,18 +404,18 @@ no_content:
         switch (any->value_type) {
         case LYD_ANYDATA_DATATREE:
             /* close opening tag and print data */
-            prev_opts = pctx->options;
-            pctx->options &= ~LYD_PRINT_WITHSIBLINGS;
+            prev_opts = ctx->options;
+            ctx->options &= ~LYD_PRINT_WITHSIBLINGS;
             LEVEL_INC;
 
-            ly_print_(pctx->out, ">%s", DO_FORMAT ? "\n" : "");
+            ly_print_(ctx->out, ">%s", DO_FORMAT ? "\n" : "");
             LY_LIST_FOR(any->value.tree, iter) {
-                ret = xml_print_node(pctx, iter);
+                ret = xml_print_node(ctx, iter);
                 LY_CHECK_ERR_RET(ret, LEVEL_DEC, ret);
             }
 
             LEVEL_DEC;
-            pctx->options = prev_opts;
+            ctx->options = prev_opts;
             break;
         case LYD_ANYDATA_STRING:
             /* escape XML-sensitive characters */
@@ -428,28 +423,28 @@ no_content:
                 goto no_content;
             }
             /* close opening tag and print data */
-            ly_print_(pctx->out, ">");
-            lyxml_dump_text(pctx->out, any->value.str, 0);
+            ly_print_(ctx->out, ">");
+            lyxml_dump_text(ctx->out, any->value.str, 0);
             break;
         case LYD_ANYDATA_XML:
             /* print without escaping special characters */
             if (!any->value.str[0]) {
                 goto no_content;
             }
-            ly_print_(pctx->out, ">%s", any->value.str);
+            ly_print_(ctx->out, ">%s", any->value.str);
             break;
         case LYD_ANYDATA_JSON:
         case LYD_ANYDATA_LYB:
             /* JSON and LYB format is not supported */
-            LOGWRN(pctx->ctx, "Unable to print anydata content (type %d) as XML.", any->value_type);
+            LOGWRN(LYD_CTX(node), "Unable to print anydata content (type %d) as XML.", any->value_type);
             goto no_content;
         }
 
         /* closing tag */
         if (any->value_type == LYD_ANYDATA_DATATREE) {
-            ly_print_(pctx->out, "%*s</%s>%s", INDENT, node->schema->name, DO_FORMAT ? "\n" : "");
+            ly_print_(ctx->out, "%*s</%s>%s", INDENT, node->schema->name, DO_FORMAT ? "\n" : "");
         } else {
-            ly_print_(pctx->out, "</%s>%s", node->schema->name, DO_FORMAT ? "\n" : "");
+            ly_print_(ctx->out, "</%s>%s", node->schema->name, DO_FORMAT ? "\n" : "");
         }
     }
 
@@ -457,42 +452,42 @@ no_content:
 }
 
 static LY_ERR
-xml_print_opaq(struct xmlpr_ctx *pctx, const struct lyd_node_opaq *node)
+xml_print_opaq(struct xmlpr_ctx *ctx, const struct lyd_node_opaq *node)
 {
     LY_ERR ret;
     struct lyd_node *child;
 
-    LY_CHECK_RET(xml_print_opaq_open(pctx, node));
+    LY_CHECK_RET(xml_print_opaq_open(ctx, node));
 
     if (node->value[0]) {
         /* print namespaces connected with the value's prefixes */
         if (node->val_prefix_data) {
-            xml_print_ns_prefix_data(pctx, node->format, node->val_prefix_data, LYXML_PREFIX_REQUIRED);
+            xml_print_ns_prefix_data(ctx, node->format, node->val_prefix_data, LYXML_PREFIX_REQUIRED);
         }
 
-        ly_print_(pctx->out, ">");
-        lyxml_dump_text(pctx->out, node->value, 0);
+        ly_print_(ctx->out, ">");
+        lyxml_dump_text(ctx->out, node->value, 0);
     }
 
     if (node->child) {
         /* children */
         if (!node->value[0]) {
-            ly_print_(pctx->out, ">%s", DO_FORMAT ? "\n" : "");
+            ly_print_(ctx->out, ">%s", DO_FORMAT ? "\n" : "");
         }
 
         LEVEL_INC;
         LY_LIST_FOR(node->child, child) {
-            ret = xml_print_node(pctx, child);
+            ret = xml_print_node(ctx, child);
             LY_CHECK_ERR_RET(ret, LEVEL_DEC, ret);
         }
         LEVEL_DEC;
 
-        ly_print_(pctx->out, "%*s</%s>%s", INDENT, node->name.name, DO_FORMAT ? "\n" : "");
+        ly_print_(ctx->out, "%*s</%s>%s", INDENT, node->name.name, DO_FORMAT ? "\n" : "");
     } else if (node->value[0]) {
-        ly_print_(pctx->out, "</%s>%s", node->name.name, DO_FORMAT ? "\n" : "");
+        ly_print_(ctx->out, "</%s>%s", node->name.name, DO_FORMAT ? "\n" : "");
     } else {
         /* no value or children */
-        ly_print_(pctx->out, "/>%s", DO_FORMAT ? "\n" : "");
+        ly_print_(ctx->out, "/>%s", DO_FORMAT ? "\n" : "");
     }
 
     return LY_SUCCESS;
@@ -506,21 +501,21 @@ xml_print_opaq(struct xmlpr_ctx *pctx, const struct lyd_node_opaq *node)
  * @return LY_ERR value.
  */
 static LY_ERR
-xml_print_node(struct xmlpr_ctx *pctx, const struct lyd_node *node)
+xml_print_node(struct xmlpr_ctx *ctx, const struct lyd_node *node)
 {
     LY_ERR ret = LY_SUCCESS;
     uint32_t ns_count;
 
-    if (!lyd_node_should_print(node, pctx->options)) {
+    if (!ly_should_print(node, ctx->options)) {
         /* do not print at all */
         return LY_SUCCESS;
     }
 
     /* remember namespace definition count on this level */
-    ns_count = pctx->ns.count;
+    ns_count = ctx->ns.count;
 
     if (!node->schema) {
-        ret = xml_print_opaq(pctx, (const struct lyd_node_opaq *)node);
+        ret = xml_print_opaq(ctx, (const struct lyd_node_opaq *)node);
     } else {
         switch (node->schema->nodetype) {
         case LYS_CONTAINER:
@@ -528,28 +523,28 @@ xml_print_node(struct xmlpr_ctx *pctx, const struct lyd_node *node)
         case LYS_NOTIF:
         case LYS_RPC:
         case LYS_ACTION:
-            ret = xml_print_inner(pctx, (const struct lyd_node_inner *)node);
+            ret = xml_print_inner(ctx, (const struct lyd_node_inner *)node);
             break;
         case LYS_LEAF:
         case LYS_LEAFLIST:
-            ret = xml_print_term(pctx, (const struct lyd_node_term *)node);
+            ret = xml_print_term(ctx, (const struct lyd_node_term *)node);
             break;
         case LYS_ANYXML:
         case LYS_ANYDATA:
-            ret = xml_print_anydata(pctx, (const struct lyd_node_any *)node);
+            ret = xml_print_anydata(ctx, (const struct lyd_node_any *)node);
             break;
         default:
-            LOGINT(pctx->ctx);
+            LOGINT(node->schema->module->ctx);
             ret = LY_EINT;
             break;
         }
     }
 
     /* remove all added namespaces */
-    while (ns_count < pctx->ns.count) {
-        lydict_remove(pctx->ctx, pctx->prefix.objs[pctx->prefix.count - 1]);
-        ly_set_rm_index(&pctx->prefix, pctx->prefix.count - 1, NULL);
-        ly_set_rm_index(&pctx->ns, pctx->ns.count - 1, NULL);
+    while (ns_count < ctx->ns.count) {
+        lydict_remove(ctx->ctx, ctx->prefix.objs[ctx->prefix.count - 1]);
+        ly_set_rm_index(&ctx->prefix, ctx->prefix.count - 1, NULL);
+        ly_set_rm_index(&ctx->ns, ctx->ns.count - 1, NULL);
     }
 
     return ret;
@@ -559,7 +554,7 @@ LY_ERR
 xml_print_data(struct ly_out *out, const struct lyd_node *root, uint32_t options)
 {
     const struct lyd_node *node;
-    struct xmlpr_ctx pctx = {0};
+    struct xmlpr_ctx ctx = {0};
 
     if (!root) {
         if ((out->type == LY_OUT_MEMORY) || (out->type == LY_OUT_CALLBACK)) {
@@ -568,23 +563,23 @@ xml_print_data(struct ly_out *out, const struct lyd_node *root, uint32_t options
         goto finish;
     }
 
-    pctx.out = out;
-    pctx.level = 0;
-    pctx.options = options;
-    pctx.ctx = LYD_CTX(root);
+    ctx.out = out;
+    ctx.level = 0;
+    ctx.options = options;
+    ctx.ctx = LYD_CTX(root);
 
     /* content */
     LY_LIST_FOR(root, node) {
-        LY_CHECK_RET(xml_print_node(&pctx, node));
+        LY_CHECK_RET(xml_print_node(&ctx, node));
         if (!(options & LYD_PRINT_WITHSIBLINGS)) {
             break;
         }
     }
 
 finish:
-    assert(!pctx.prefix.count && !pctx.ns.count);
-    ly_set_erase(&pctx.prefix, NULL);
-    ly_set_erase(&pctx.ns, NULL);
+    assert(!ctx.prefix.count && !ctx.ns.count);
+    ly_set_erase(&ctx.prefix, NULL);
+    ly_set_erase(&ctx.ns, NULL);
     ly_print_flush(out);
     return LY_SUCCESS;
 }
