@@ -32,7 +32,6 @@
 #include "schema_features.h"
 #include "set.h"
 #include "tree.h"
-#include "tree_data_internal.h"
 #include "tree_edit.h"
 #include "tree_schema.h"
 #include "tree_schema_internal.h"
@@ -269,56 +268,16 @@ cleanup:
     return ret;
 }
 
-static LY_ERR
-lysp_ext_children_dup(const struct ly_ctx *ctx, struct lysp_stmt **child, const struct lysp_stmt *orig_child)
-{
-    struct lysp_stmt *ch = NULL;
-
-    assert(!*child);
-
-    LY_LIST_FOR(orig_child, orig_child) {
-        /* new child */
-        if (!*child) {
-            *child = ch = calloc(1, sizeof *ch);
-            LY_CHECK_ERR_RET(!ch, LOGMEM(ctx), LY_EMEM);
-        } else {
-            ch->next = calloc(1, sizeof *ch);
-            LY_CHECK_ERR_RET(!ch->next, LOGMEM(ctx), LY_EMEM);
-            ch = ch->next;
-        }
-
-        /* fill */
-        DUP_STRING_RET(ctx, orig_child->stmt, ch->stmt);
-        ch->flags = orig_child->flags;
-        DUP_STRING_RET(ctx, orig_child->arg, ch->arg);
-        ch->format = orig_child->format;
-        LY_CHECK_RET(ly_dup_prefix_data(ctx, orig_child->format, orig_child->prefix_data, &(ch->prefix_data)));
-        ch->kw = orig_child->kw;
-
-        /* recursive children */
-        LY_CHECK_RET(lysp_ext_children_dup(ctx, &ch->child, orig_child->child));
-    }
-
-    return LY_SUCCESS;
-}
-
 static LY_ERR
 lysp_ext_dup(const struct ly_ctx *ctx, struct lysp_ext_instance *ext, const struct lysp_ext_instance *orig_ext)
 {
-    DUP_STRING_RET(ctx, orig_ext->name, ext->name);
-    DUP_STRING_RET(ctx, orig_ext->argument, ext->argument);
-    ext->format = orig_ext->format;
-    ext->parsed = NULL;
-    LY_CHECK_RET(ly_dup_prefix_data(ctx, orig_ext->format, orig_ext->prefix_data, &ext->prefix_data));
+    LY_ERR ret = LY_SUCCESS;
 
-    ext->child = NULL;
-    LY_CHECK_RET(lysp_ext_children_dup(ctx, &ext->child, orig_ext->child));
+    *ext = *orig_ext;
+    DUP_STRING(ctx, orig_ext->name, ext->name, ret);
+    DUP_STRING(ctx, orig_ext->argument, ext->argument, ret);
 
-    ext->parent = orig_ext->parent;
-    ext->parent_stmt = orig_ext->parent_stmt;
-    ext->parent_stmt_index = orig_ext->parent_stmt_index;
-    ext->flags = orig_ext->flags;
-    return LY_SUCCESS;
+    return ret;
 }
 
 static LY_ERR
@@ -1553,6 +1512,8 @@ lysc_refine_free(const struct ly_ctx *ctx, struct lysc_refine *rfn)
 void
 lysp_dev_node_free(const struct ly_ctx *ctx, struct lysp_node *dev_pnode)
 {
+    LY_ARRAY_COUNT_TYPE u;
+
     if (!dev_pnode) {
         return;
     }
@@ -1599,6 +1560,12 @@ lysp_dev_node_free(const struct ly_ctx *ctx, struct lysp_node *dev_pnode)
         return;
     }
 
+    /* extension parsed tree and children were not duplicated */
+    LY_ARRAY_FOR(dev_pnode->exts, u) {
+        dev_pnode->exts[u].parsed = NULL;
+        dev_pnode->exts[u].child = NULL;
+    }
+
     lysp_node_free((struct ly_ctx *)ctx, dev_pnode);
 }
 
