@@ -19,7 +19,6 @@
 #include "dict.h"
 #include "hash_table.h"
 #include "log.h"
-#include "plugins_exts/metadata.h"
 #include "plugins_types.h"
 #include "tree.h"
 #include "tree_data.h"
@@ -68,13 +67,13 @@ lyd_free_meta(struct lyd_meta *meta, ly_bool siblings)
     }
 }
 
-LIBYANG_API_DEF void
+API void
 lyd_free_meta_single(struct lyd_meta *meta)
 {
     lyd_free_meta(meta, 0);
 }
 
-LIBYANG_API_DEF void
+API void
 lyd_free_meta_siblings(struct lyd_meta *meta)
 {
     lyd_free_meta(meta, 1);
@@ -126,13 +125,13 @@ lyd_free_attr(const struct ly_ctx *ctx, struct lyd_attr *attr, ly_bool siblings)
     }
 }
 
-LIBYANG_API_DEF void
+API void
 lyd_free_attr_single(const struct ly_ctx *ctx, struct lyd_attr *attr)
 {
     lyd_free_attr(ctx, attr, 0);
 }
 
-LIBYANG_API_DEF void
+API void
 lyd_free_attr_siblings(const struct ly_ctx *ctx, struct lyd_attr *attr)
 {
     lyd_free_attr(ctx, attr, 1);
@@ -166,7 +165,7 @@ lyd_free_subtree(struct lyd_node *node, ly_bool top)
         ly_free_prefix_data(opaq->format, opaq->val_prefix_data);
     } else if (node->schema->nodetype & LYD_NODE_INNER) {
         /* remove children hash table in case of inner data node */
-        lyht_free(((struct lyd_node_inner *)node)->children_ht, NULL);
+        lyht_free(((struct lyd_node_inner *)node)->children_ht);
         ((struct lyd_node_inner *)node)->children_ht = NULL;
 
         /* free the children */
@@ -195,7 +194,7 @@ lyd_free_subtree(struct lyd_node *node, ly_bool top)
     free(node);
 }
 
-LIBYANG_API_DEF void
+API void
 lyd_free_tree(struct lyd_node *node)
 {
     if (!node) {
@@ -228,13 +227,13 @@ lyd_free_(struct lyd_node *node, ly_bool top)
     }
 }
 
-LIBYANG_API_DEF void
+API void
 lyd_free_siblings(struct lyd_node *node)
 {
     lyd_free_(node, 0);
 }
 
-LIBYANG_API_DEF void
+API void
 lyd_free_all(struct lyd_node *node)
 {
     lyd_free_(node, 1);
