@@ -3,7 +3,7 @@
  * @author Radek Krejci <rkrejci@cesnet.cz>
  * @brief Parsing and validation helper functions for data trees
  *
- * Copyright (c) 2015 - 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2018 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -29,7 +29,6 @@
 #include "log.h"
 #include "lyb.h"
 #include "parser_data.h"
-#include "plugins_exts.h"
 #include "printer_data.h"
 #include "set.h"
 #include "tree.h"
@@ -165,7 +164,7 @@ lyd_node_child_p(struct lyd_node *node)
     }
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyxp_vars_set(struct lyxp_var **vars, const char *name, const char *value)
 {
     LY_ERR ret = LY_SUCCESS;
@@ -203,7 +202,7 @@ error:
     return ret;
 }
 
-LIBYANG_API_DEF void
+API void
 lyxp_vars_free(struct lyxp_var *vars)
 {
     LY_ARRAY_COUNT_TYPE u;
@@ -220,7 +219,7 @@ lyxp_vars_free(struct lyxp_var *vars)
     LY_ARRAY_FREE(vars);
 }
 
-LIBYANG_API_DEF struct lyd_node *
+API struct lyd_node *
 lyd_child_no_keys(const struct lyd_node *node)
 {
     struct lyd_node **children;
@@ -246,7 +245,7 @@ lyd_child_no_keys(const struct lyd_node *node)
     }
 }
 
-LIBYANG_API_DEF const struct lys_module *
+API const struct lys_module *
 lyd_owner_module(const struct lyd_node *node)
 {
     const struct lyd_node_opaq *opaq;
@@ -401,19 +400,19 @@ lyd_parse_check_keys(struct lyd_node *node)
     return LY_SUCCESS;
 }
 
-LY_ERR
-lyd_parse_set_data_flags(struct lyd_node *node, struct lyd_meta **meta, struct lyd_ctx *lydctx,
-        struct lysc_ext_instance *ext)
+void
+lyd_parse_set_data_flags(struct lyd_node *node, struct ly_set *node_when, struct ly_set *node_exts, struct lyd_meta **meta,
+        uint32_t parse_opts)
 {
     struct lyd_meta *meta2, *prev_meta = NULL;
-    struct lyd_ctx_ext_val *ext_val;
 
     if (lysc_has_when(node->schema)) {
-        if (!(lydctx->parse_opts & LYD_PARSE_ONLY)) {
+        if (!(parse_opts & LYD_PARSE_ONLY)) {
             /* remember we need to evaluate this node's when */
-            LY_CHECK_RET(ly_set_add(&lydctx->node_when, node, 1, NULL));
+            LY_CHECK_RET(ly_set_add(node_when, node, 1, NULL), );
         }
     }
+    LY_CHECK_RET(lysc_node_ext_tovalidate(node_exts, node), );
 
     LY_LIST_FOR(*meta, meta2) {
         if (!strcmp(meta2->name, "default") && !strcmp(meta2->annotation->module->name, "ietf-netconf-with-defaults") &&
@@ -433,182 +432,9 @@ lyd_parse_set_data_flags(struct lyd_node *node, struct lyd_meta **meta, struct l
 
         prev_meta = meta2;
     }
-
-    if (ext) {
-        /* parsed for an extension */
-        node->flags |= LYD_EXT;
-
-        if (!(lydctx->parse_opts & LYD_PARSE_ONLY)) {
-            /* rememeber for validation */
-            ext_val = malloc(sizeof *ext_val);
-            LY_CHECK_ERR_RET(!ext_val, LOGMEM(LYD_CTX(node)), LY_EMEM);
-            ext_val->ext = ext;
-            ext_val->sibling = node;
-            LY_CHECK_RET(ly_set_add(&lydctx->ext_val, ext_val, 1, NULL));
-        }
-    }
-
-    return LY_SUCCESS;
 }
 
-/**
- * @brief Check list node parsed into an opaque node for the reason.
- *
- * @param[in] node Opaque node.
- * @param[in] snode Schema node of @p opaq.
- * @return LY_SUCCESS if the node is valid;
- * @return LY_ERR on error.
- */
-static LY_ERR
-lyd_parse_opaq_list_error(const struct lyd_node *node, const struct lysc_node *snode)
-{
-    LY_ERR ret = LY_SUCCESS;
-    struct ly_set key_set = {0};
-    const struct lysc_node *key = NULL;
-    const struct lyd_node *child;
-    const struct lyd_node_opaq *opaq_k;
-    uint32_t i;
-
-    assert(!node->schema);
-
-    /* get all keys into a set */
-    while ((key = lys_getnext(key, snode, NULL, 0)) && (snode->flags & LYS_KEY)) {
-        LY_CHECK_GOTO(ret = ly_set_add(&key_set, (void *)snode, 1, NULL), cleanup);
-    }
-
-    LY_LIST_FOR(lyd_child(node), child) {
-        if (child->schema) {
-            LOGERR(LYD_CTX(node), LY_EINVAL, "Unexpected node %s \"%s\".", lys_nodetype2str(child->schema->nodetype),
-                    LYD_NAME(child));
-            ret = LY_EINVAL;
-            goto cleanup;
-        }
-
-        opaq_k = (struct lyd_node_opaq *)child;
-
-        /* find the key schema node */
-        for (i = 0; i < key_set.count; ++i) {
-            key = key_set.snodes[i];
-            if (!strcmp(key->name, opaq_k->name.name)) {
-                break;
-            }
-        }
-        if (i == key_set.count) {
-            /* some other node, skip */
-            continue;
-        }
-
-        /* key found */
-        ly_set_rm_index(&key_set, i, NULL);
-
-        /* check value */
-        ret = lys_value_validate(LYD_CTX(node), key, opaq_k->value, strlen(opaq_k->value), opaq_k->format,
-                opaq_k->val_prefix_data);
-        LY_CHECK_GOTO(ret, cleanup);
-    }
-
-    if (key_set.count) {
-        /* missing keys */
-        LOGVAL(LYD_CTX(node), LY_VCODE_NOKEY, key_set.snodes[0]->name);
-        ret = LY_EVALID;
-        goto cleanup;
-    }
-
-cleanup:
-    ly_set_erase(&key_set, NULL);
-    return ret;
-}
-
-LIBYANG_API_DEF LY_ERR
-lyd_parse_opaq_error(const struct lyd_node *node)
-{
-    const struct ly_ctx *ctx;
-    const struct lyd_node_opaq *opaq;
-    const struct lyd_node *parent;
-    const struct lys_module *mod;
-    const struct lysc_node *snode;
-
-    LY_CHECK_ARG_RET(LYD_CTX(node), node, !node->schema, !lyd_parent(node) || lyd_parent(node)->schema, LY_EINVAL);
-
-    ctx = LYD_CTX(node);
-    opaq = (struct lyd_node_opaq *)node;
-    parent = lyd_parent(node);
-
-    /* is always filled by parsers */
-    LY_CHECK_ARG_RET(ctx, opaq->name.module_ns, LY_EINVAL);
-
-    /* module */
-    switch (opaq->format) {
-    case LY_VALUE_XML:
-        if (!parent || strcmp(opaq->name.module_ns, parent->schema->module->ns)) {
-            mod = ly_ctx_get_module_implemented_ns(ctx, opaq->name.module_ns);
-            if (!mod) {
-                LOGVAL(ctx, LYVE_REFERENCE, "No (implemented) module with namespace \"%s\" in the context.",
-                        opaq->name.module_ns);
-                return LY_EVALID;
-            }
-        } else {
-            /* inherit */
-            mod = parent->schema->module;
-        }
-        break;
-    case LY_VALUE_JSON:
-    case LY_VALUE_LYB:
-        if (!parent || strcmp(opaq->name.module_name, parent->schema->module->name)) {
-            mod = ly_ctx_get_module_implemented(ctx, opaq->name.module_name);
-            if (!mod) {
-                LOGVAL(ctx, LYVE_REFERENCE, "No (implemented) module named \"%s\" in the context.", opaq->name.module_name);
-                return LY_EVALID;
-            }
-        } else {
-            /* inherit */
-            mod = parent->schema->module;
-        }
-        break;
-    default:
-        LOGERR(ctx, LY_EINVAL, "Unsupported value format.");
-        return LY_EINVAL;
-    }
-
-    /* schema */
-    snode = lys_find_child(parent ? parent->schema : NULL, mod, opaq->name.name, 0, 0, 0);
-    if (!snode && parent && parent->schema && (parent->schema->nodetype & (LYS_RPC | LYS_ACTION))) {
-        /* maybe output node */
-        snode = lys_find_child(parent->schema, mod, opaq->name.name, 0, 0, LYS_GETNEXT_OUTPUT);
-    }
-    if (!snode) {
-        if (parent) {
-            LOGVAL(ctx, LYVE_REFERENCE, "Node \"%s\" not found as a child of \"%s\" node.", opaq->name.name,
-                    LYD_NAME(parent));
-        } else {
-            LOGVAL(ctx, LYVE_REFERENCE, "Node \"%s\" not found in the \"%s\" module.", opaq->name.name, mod->name);
-        }
-        return LY_EVALID;
-    }
-
-    if (snode->nodetype & LYD_NODE_TERM) {
-        /* leaf / leaf-list */
-        LY_CHECK_RET(lys_value_validate(ctx, snode, opaq->value, strlen(opaq->value), opaq->format, opaq->val_prefix_data));
-    } else if (snode->nodetype == LYS_LIST) {
-        /* list */
-        LY_CHECK_RET(lyd_parse_opaq_list_error(node, snode));
-    } else if (snode->nodetype & LYD_NODE_INNER) {
-        /* inner node */
-        if (opaq->value) {
-            LOGVAL(ctx, LYVE_DATA, "Invalid value \"%s\" for %s \"%s\".", opaq->value,
-                    lys_nodetype2str(snode->nodetype), snode->name);
-            return LY_EVALID;
-        }
-    } else {
-        LOGERR(ctx, LY_EINVAL, "Unexpected opaque schema node %s \"%s\".", lys_nodetype2str(snode->nodetype), snode->name);
-        return LY_EINVAL;
-    }
-
-    LOGERR(ctx, LY_EINVAL, "Unexpected valid opaque node %s \"%s\".", lys_nodetype2str(snode->nodetype), snode->name);
-    return LY_EINVAL;
-}
-
-LIBYANG_API_DEF const char *
+API const char *
 lyd_value_get_canonical(const struct ly_ctx *ctx, const struct lyd_value *value)
 {
     LY_CHECK_ARG_RET(ctx, ctx, value, NULL);
@@ -617,7 +443,7 @@ lyd_value_get_canonical(const struct ly_ctx *ctx, const struct lyd_value *value)
            (const char *)value->realtype->plugin->print(ctx, value, LY_VALUE_CANON, NULL, NULL, NULL);
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyd_any_value_str(const struct lyd_node *any, char **value_str)
 {
     const struct lyd_node_any *a;
@@ -674,7 +500,7 @@ cleanup:
     return ret;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 lyd_any_copy_value(struct lyd_node *trg, const union lyd_any_value *value, LYD_ANYDATA_VALUETYPE value_type)
 {
     struct lyd_node_any *t;
@@ -794,51 +620,6 @@ lyd_del_move_root(struct lyd_node **root, const struct lyd_node *to_del, const s
     }
 }
 
-LY_ERR
-ly_nested_ext_schema(const struct lyd_node *parent, const struct lysc_node *sparent, const char *prefix,
-        size_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name, size_t name_len,
-        const struct lysc_node **snode, struct lysc_ext_instance **ext)
-{
-    LY_ERR r;
-    LY_ARRAY_COUNT_TYPE u;
-    struct lysc_ext_instance *nested_exts = NULL;
-    lyplg_ext_data_snode_clb ext_snode_cb;
-
-    /* check if there are any nested extension instances */
-    if (parent && parent->schema) {
-        nested_exts = parent->schema->exts;
-    } else if (sparent) {
-        nested_exts = sparent->exts;
-    }
-    LY_ARRAY_FOR(nested_exts, u) {
-        if (!nested_exts[u].def->plugin) {
-            /* no plugin */
-            continue;
-        }
-
-        ext_snode_cb = nested_exts[u].def->plugin->snode;
-        if (!ext_snode_cb) {
-            /* not an extension with nested data */
-            continue;
-        }
-
-        /* try to get the schema node */
-        r = ext_snode_cb(&nested_exts[u], parent, sparent, prefix, prefix_len, format, prefix_data, name, name_len, snode);
-        if (!r) {
-            /* data successfully created, remember the ext instance */
-            *ext = &nested_exts[u];
-            return LY_SUCCESS;
-        } else if (r != LY_ENOT) {
-            /* fatal error */
-            return r;
-        }
-        /* data was not from this module, continue */
-    }
-
-    /* no extensions or none matched */
-    return LY_ENOT;
-}
-
 void
 ly_free_prefix_data(LY_VALUE_FORMAT format, void *prefix_data)
 {
@@ -853,7 +634,6 @@ ly_free_prefix_data(LY_VALUE_FORMAT format, void *prefix_data)
 
     switch (format) {
     case LY_VALUE_XML:
-    case LY_VALUE_STR_NS:
         ns_list = prefix_data;
         for (i = 0; i < ns_list->count; ++i) {
             free(((struct lyxml_ns *)ns_list->objs[i])->prefix);
@@ -909,7 +689,6 @@ ly_dup_prefix_data(const struct ly_ctx *ctx, LY_VALUE_FORMAT format, const void
         }
         break;
     case LY_VALUE_XML:
-    case LY_VALUE_STR_NS:
         /* copy all the namespaces */
         LY_CHECK_GOTO(ret = ly_set_new(&ns_list), cleanup);
         *prefix_data_p = ns_list;
@@ -996,31 +775,18 @@ ly_store_prefix_data(const struct ly_ctx *ctx, const void *value, size_t value_l
         }
         break;
     case LY_VALUE_XML:
-    case LY_VALUE_STR_NS:
         /* copy all referenced namespaces as prefix - namespace pairs */
         if (!*prefix_data_p) {
             /* new prefix data */
             LY_CHECK_GOTO(ret = ly_set_new(&ns_list), cleanup);
-            *format_p = format;
+            *format_p = LY_VALUE_XML;
             *prefix_data_p = ns_list;
         } else {
             /* reuse prefix data */
-            assert(*format_p == format);
+            assert(*format_p == LY_VALUE_XML);
             ns_list = *prefix_data_p;
         }
 
-        /* store default namespace */
-        ns = lyxml_ns_get(prefix_data, NULL, 0);
-        if (ns) {
-            new_ns = calloc(1, sizeof *new_ns);
-            LY_CHECK_ERR_GOTO(!new_ns, LOGMEM(ctx); ret = LY_EMEM, cleanup);
-            LY_CHECK_GOTO(ret = ly_set_add(ns_list, new_ns, 1, NULL), cleanup);
-
-            new_ns->prefix = NULL;
-            new_ns->uri = strdup(ns->uri);
-            LY_CHECK_ERR_GOTO(!new_ns->uri, LOGMEM(ctx); ret = LY_EMEM, cleanup);
-        }
-
         /* add all used prefixes */
         value_end = (char *)value + value_len;
         for (value_iter = value; value_iter; value_iter = value_next) {
@@ -1088,7 +854,7 @@ ly_format2str(LY_VALUE_FORMAT format)
     return NULL;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 ly_time_str2time(const char *value, time_t *time, char **fractions_s)
 {
     struct tm tm = {0};
@@ -1151,7 +917,7 @@ ly_time_str2time(const char *value, time_t *time, char **fractions_s)
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 ly_time_time2str(time_t time, const char *fractions_s, char **str)
 {
     struct tm tm;
@@ -1163,7 +929,6 @@ ly_time_time2str(time_t time, const char *fractions_s, char **str)
     /* initialize the local timezone */
     tzset();
 
-#ifdef HAVE_TM_GMTOFF
     /* convert */
     if (!localtime_r(&time, &tm)) {
         return LY_ESYS;
@@ -1180,16 +945,6 @@ ly_time_time2str(time_t time, const char *fractions_s, char **str)
         zonediff_m = tm.tm_gmtoff / 60 % 60;
     }
     sprintf(zoneshift, "%+03d:%02d", zonediff_h, zonediff_m);
-#else
-    /* convert */
-    if (!gmtime_r(&time, &tm)) {
-        return LY_ESYS;
-    }
-
-    (void)zonediff_h;
-    (void)zonediff_m;
-    sprintf(zoneshift, "-00:00");
-#endif
 
     /* print */
     if (asprintf(str, "%04d-%02d-%02dT%02d:%02d:%02d%s%s%s",
@@ -1201,7 +956,7 @@ ly_time_time2str(time_t time, const char *fractions_s, char **str)
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 ly_time_str2ts(const char *value, struct timespec *ts)
 {
     LY_ERR rc;
@@ -1230,7 +985,7 @@ ly_time_str2ts(const char *value, struct timespec *ts)
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF LY_ERR
+API LY_ERR
 ly_time_ts2str(const struct timespec *ts, char **str)
 {
     char frac_buf[10];
