@@ -810,8 +810,10 @@ cleanup:
  * @param[in] ctx libyang context where to work.
  * @param[in] name Name of module to load.
  * @param[in] revision Revision of module to load.
- * @param[in] mod_latest Module with the latest revision found in context, otherwise set to NULL.
- * @param[in,out] new_mods Set of all the new mods added to the context. Includes this module and all of its imports.
+ * @param[in] mod_latest Module with the latest revision found in
+ * context and the searchdirs should be searched, otherwise set to NULL.
+ * @param[in,out] new_mods Set of all the new mods added to the context.
+ * Includes this module and all of its imports.
  * @param[out] mod Loaded module.
  * @return LY_SUCCESS on success.
  * @return LY_ERR on error.
@@ -827,46 +829,30 @@ lys_parse_load_from_clb_or_file(struct ly_ctx *ctx, const char *name, const char
     struct lysp_load_module_check_data check_data = {0};
     struct ly_in *in;
 
-    *mod = NULL;
-
-    if (mod_latest && (!ctx->imp_clb || (mod_latest->latest_revision & LYS_MOD_LATEST_IMPCLB)) &&
-            ((ctx->flags & LY_CTX_DISABLE_SEARCHDIRS) || (mod_latest->latest_revision & LYS_MOD_LATEST_SEARCHDIRS))) {
-        /* we are not able to find a newer revision */
-        return LY_SUCCESS;
-    }
-
+    /* Module not present in the context, get the input data and parse it. */
     if (!(ctx->flags & LY_CTX_PREFER_SEARCHDIRS)) {
 search_clb:
-        /* check there is a callback and should be called */
-        if (ctx->imp_clb && (!mod_latest || !(mod_latest->latest_revision & LYS_MOD_LATEST_IMPCLB))) {
-            if (!ctx->imp_clb(name, revision, NULL, NULL, ctx->imp_clb_data, &format, &module_data, &module_data_free)) {
-                LY_CHECK_RET(ly_in_new_memory(module_data, &in));
-                check_data.name = name;
-                check_data.revision = revision;
-                lys_parse_in(ctx, in, format, lysp_load_module_check, &check_data, new_mods, mod);
-                ly_in_free(in, 0);
-                if (module_data_free) {
-                    module_data_free((void *)module_data, ctx->imp_clb_data);
-                }
+        if (ctx->imp_clb && !ctx->imp_clb(name, revision, NULL, NULL, ctx->imp_clb_data, &format, &module_data,
+                &module_data_free)) {
+            LY_CHECK_RET(ly_in_new_memory(module_data, &in));
+            check_data.name = name;
+            check_data.revision = revision;
+            lys_parse_in(ctx, in, format, lysp_load_module_check, &check_data, new_mods, mod);
+            ly_in_free(in, 0);
+            if (module_data_free) {
+                module_data_free((void *)module_data, ctx->imp_clb_data);
             }
         }
-        if (*mod && !revision) {
-            /* we got the latest revision module from the callback */
-            (*mod)->latest_revision |= LYS_MOD_LATEST_IMPCLB;
-        } else if (!*mod && !(ctx->flags & LY_CTX_PREFER_SEARCHDIRS)) {
+        if (!(*mod) && !(ctx->flags & LY_CTX_PREFER_SEARCHDIRS)) {
             goto search_file;
         }
     } else {
 search_file:
-        /* check we can use searchdirs and that we should */
-        if (!(ctx->flags & LY_CTX_DISABLE_SEARCHDIRS) &&
-                (!mod_latest || !(mod_latest->latest_revision & LYS_MOD_LATEST_SEARCHDIRS))) {
+        if (!(ctx->flags & LY_CTX_DISABLE_SEARCHDIRS)) {
+            /* Module was not received from the callback or there is no callback set. */
             lys_parse_localfile(ctx, name, revision, NULL, NULL, mod_latest ? 0 : 1, new_mods, (void **)mod);
         }
-        if (*mod && !revision) {
-            /* we got the latest revision module in the searchdirs */
-            (*mod)->latest_revision |= LYS_MOD_LATEST_IMPCLB;
-        } else if (!*mod && (ctx->flags & LY_CTX_PREFER_SEARCHDIRS)) {
+        if (!*mod && (ctx->flags & LY_CTX_PREFER_SEARCHDIRS)) {
             goto search_clb;
         }
     }
@@ -883,14 +869,18 @@ search_file:
  *
  * @param[in] ctx libyang context where module is searched.
  * @param[in] name Name of the searched module.
+ * @param[out] keep_search Flag set to 1 if searchpaths or module
+ * callback must be searched to obtain latest available revision.
  * @return Found module from context or NULL.
  */
 static struct lys_module *
-lys_get_module_without_revision(struct ly_ctx *ctx, const char *name)
+lys_get_module_without_revision(struct ly_ctx *ctx, const char *name, ly_bool *keep_search)
 {
     struct lys_module *mod, *mod_impl;
     uint32_t index;
 
+    *keep_search = 0;
+
     /* Try to find module with LYS_MOD_IMPORTED_REV flag. */
     index = 0;
     while ((mod = ly_ctx_get_module_iter(ctx, &index))) {
@@ -902,7 +892,8 @@ lys_get_module_without_revision(struct ly_ctx *ctx, const char *name)
     /* Try to find the implemented module. */
     mod_impl = ly_ctx_get_module_implemented(ctx, name);
     if (mod && mod_impl) {
-        LOGVRB("Implemented module \"%s@%s\" is not used for import, revision \"%s\" is imported instead.",
+        LOGVRB("Implemented module \"%s@%s\" is not used for import, "
+                "revision \"%s\" is imported instead.",
                 mod_impl->name, mod_impl->revision, mod->revision);
         return mod;
     } else if (mod_impl) {
@@ -911,6 +902,7 @@ lys_get_module_without_revision(struct ly_ctx *ctx, const char *name)
 
     /* Try to find the latest module in the current context. */
     mod = ly_ctx_get_module_latest(ctx, name);
+    *keep_search = 1;
 
     return mod;
 }
@@ -940,6 +932,7 @@ LY_ERR
 lys_parse_load(struct ly_ctx *ctx, const char *name, const char *revision, struct ly_set *new_mods,
         struct lys_module **mod)
 {
+    ly_bool keep_search;
     struct lys_module *mod_latest = NULL;
 
     assert(mod && new_mods);
@@ -951,9 +944,9 @@ lys_parse_load(struct ly_ctx *ctx, const char *name, const char *revision, struc
         /* Get the specific revision. */
         *mod = ly_ctx_get_module(ctx, name, revision);
     } else {
-        /* Get the requested module in a suitable revision in the context. */
-        *mod = lys_get_module_without_revision(ctx, name);
-        if (*mod && !(*mod)->implemented && !((*mod)->latest_revision & LYS_MOD_IMPORTED_REV)) {
+        /* Get the requested module of the latest revision in the context. */
+        *mod = lys_get_module_without_revision(ctx, name, &keep_search);
+        if (keep_search) {
             /* Let us now search with callback and searchpaths to check
              * if there is newer revision outside the context.
              */
@@ -964,7 +957,9 @@ lys_parse_load(struct ly_ctx *ctx, const char *name, const char *revision, struc
 
     if (!*mod) {
         /* No suitable module in the context, try to load it. */
-        LY_CHECK_RET(lys_parse_load_from_clb_or_file(ctx, name, revision, mod_latest, new_mods, mod));
+        LY_CHECK_RET(lys_parse_load_from_clb_or_file(ctx, name, revision,
+                mod_latest, new_mods, mod));
+
         if (!*mod && !mod_latest) {
             LOGVAL(ctx, LYVE_REFERENCE, "Loading \"%s\" module failed.", name);
             return LY_EVALID;
@@ -1040,10 +1035,10 @@ lysp_check_identifierchar(struct lys_parser_ctx *ctx, uint32_t c, ly_bool first,
  * @return LY_EVALID - YANG rule violation
  */
 static LY_ERR
-lysp_main_pmod_get_submodule(struct lys_parser_ctx *pctx, struct lysp_include *inc)
+lysp_get_submodule(struct lys_parser_ctx *pctx, struct lysp_include *inc)
 {
     LY_ARRAY_COUNT_TYPE i;
-    struct lysp_module *main_pmod = PARSER_CUR_PMOD(pctx)->mod->parsed;
+    struct lysp_module *main_pmod = pctx->parsed_mod->mod->parsed;
 
     LY_ARRAY_FOR(main_pmod->includes, i) {
         if (strcmp(main_pmod->includes[i].name, inc->name)) {
@@ -1053,7 +1048,7 @@ lysp_main_pmod_get_submodule(struct lys_parser_ctx *pctx, struct lysp_include *i
         if (inc->rev[0] && strncmp(inc->rev, main_pmod->includes[i].rev, LY_REV_SIZE)) {
             LOGVAL(PARSER_CTX(pctx), LYVE_REFERENCE,
                     "Submodule %s includes different revision (%s) of the submodule %s:%s included by the main module %s.",
-                    ((struct lysp_submodule *)PARSER_CUR_PMOD(pctx))->name, inc->rev,
+                    ((struct lysp_submodule *)pctx->parsed_mod)->name, inc->rev,
                     main_pmod->includes[i].name, main_pmod->includes[i].rev, main_pmod->mod->name);
             return LY_EVALID;
         }
@@ -1066,53 +1061,13 @@ lysp_main_pmod_get_submodule(struct lys_parser_ctx *pctx, struct lysp_include *i
         LOGVAL(PARSER_CTX(pctx), LYVE_REFERENCE,
                 "YANG 1.1 requires all submodules to be included from main module. "
                 "But submodule \"%s\" includes submodule \"%s\" which is not included by main module \"%s\".",
-                ((struct lysp_submodule *)PARSER_CUR_PMOD(pctx))->name, inc->name, main_pmod->mod->name);
+                ((struct lysp_submodule *)pctx->parsed_mod)->name, inc->name, main_pmod->mod->name);
         return LY_EVALID;
     } else {
         return LY_ENOT;
     }
 }
 
-/**
- * @brief Try to find the parsed submodule in currenlty parsed modules for the given include record.
- *
- * @param[in] pctx main parser context
- * @param[in] inc The include record with missing parsed submodule.
- * @return LY_SUCCESS - the parsed submodule was found and inserted into the @p inc record
- * @return LY_ENOT - the parsed module was not found.
- * @return LY_EVALID - YANG rule violation
- */
-static LY_ERR
-lysp_parsed_mods_get_submodule(struct lys_parser_ctx *pctx, struct lysp_include *inc)
-{
-    uint32_t i;
-    struct lysp_submodule *submod;
-
-    for (i = 0; i < pctx->parsed_mods->count - 1; ++i) {
-        submod = pctx->parsed_mods->objs[i];
-        if (!submod->is_submod) {
-            continue;
-        }
-
-        if (strcmp(submod->name, inc->name)) {
-            continue;
-        }
-
-        if (inc->rev[0] && submod->revs && strncmp(inc->rev, submod->revs[0].date, LY_REV_SIZE)) {
-            LOGVAL(PARSER_CTX(pctx), LYVE_REFERENCE,
-                    "Submodule %s includes different revision (%s) of the submodule %s:%s included by the main module %s.",
-                    ((struct lysp_submodule *)PARSER_CUR_PMOD(pctx))->name, inc->rev,
-                    submod->name, submod->revs[0].date, PARSER_CUR_PMOD(pctx)->mod->name);
-            return LY_EVALID;
-        }
-
-        inc->submodule = submod;
-        return LY_SUCCESS;
-    }
-
-    return LY_ENOT;
-}
-
 /**
  * @brief Make the copy of the given include record into the main module.
  *
@@ -1128,7 +1083,7 @@ lysp_inject_submodule(struct lys_parser_ctx *pctx, struct lysp_include *inc)
 {
     LY_ARRAY_COUNT_TYPE i;
     struct lysp_include *inc_new, *inc_tofill = NULL;
-    struct lysp_module *main_pmod = PARSER_CUR_PMOD(pctx)->mod->parsed;
+    struct lysp_module *main_pmod = pctx->parsed_mod->mod->parsed;
 
     /* first, try to find the corresponding record with missing parsed submodule */
     LY_ARRAY_FOR(main_pmod->includes, i) {
@@ -1162,7 +1117,7 @@ lysp_load_submodules(struct lys_parser_ctx *pctx, struct lysp_module *pmod, stru
     struct ly_ctx *ctx = PARSER_CTX(pctx);
 
     LY_ARRAY_FOR(pmod->includes, u) {
-        LY_ERR ret = LY_SUCCESS, r;
+        LY_ERR ret = LY_SUCCESS;
         struct lysp_submodule *submod = NULL;
         struct lysp_include *inc = &pmod->includes[u];
 
@@ -1172,14 +1127,11 @@ lysp_load_submodules(struct lys_parser_ctx *pctx, struct lysp_module *pmod, stru
 
         if (pmod->is_submod) {
             /* try to find the submodule in the main module or its submodules */
-            ret = lysp_main_pmod_get_submodule(pctx, inc);
-            LY_CHECK_RET(ret != LY_ENOT, ret);
+            ret = lysp_get_submodule(pctx, inc);
+            LY_CHECK_RET(ret && ret != LY_ENOT, ret);
+            LY_CHECK_RET(ret == LY_SUCCESS, LY_SUCCESS); /* submodule found in linked with the inc */
         }
 
-        /* try to use currently parsed submodule */
-        r = lysp_parsed_mods_get_submodule(pctx, inc);
-        LY_CHECK_RET(r != LY_ENOT, r);
-
         /* submodule not present in the main module, get the input data and parse it */
         if (!(ctx->flags & LY_CTX_PREFER_SEARCHDIRS)) {
 search_clb:
@@ -1190,13 +1142,13 @@ search_clb:
                 struct lysp_load_module_check_data check_data = {0};
                 struct ly_in *in;
 
-                if (ctx->imp_clb(PARSER_CUR_PMOD(pctx)->mod->name, NULL, inc->name,
+                if (ctx->imp_clb(pctx->parsed_mod->mod->name, NULL, inc->name,
                         inc->rev[0] ? inc->rev : NULL, ctx->imp_clb_data,
                         &format, &submodule_data, &submodule_data_free) == LY_SUCCESS) {
                     LY_CHECK_RET(ly_in_new_memory(submodule_data, &in));
                     check_data.name = inc->name;
                     check_data.revision = inc->rev[0] ? inc->rev : NULL;
-                    check_data.submoduleof = PARSER_CUR_PMOD(pctx)->mod->name;
+                    check_data.submoduleof = pctx->parsed_mod->mod->name;
                     lys_parse_submodule(ctx, in, format, pctx, lysp_load_module_check, &check_data, new_mods, &submod);
 
                     /* update inc pointer - parsing another (YANG 1.0) submodule can cause injecting
@@ -1217,7 +1169,7 @@ search_file:
             if (!(ctx->flags & LY_CTX_DISABLE_SEARCHDIRS)) {
                 /* submodule was not received from the callback or there is no callback set */
                 lys_parse_localfile(ctx, inc->name, inc->rev[0] ? inc->rev : NULL, pctx,
-                        PARSER_CUR_PMOD(pctx)->mod->name, 1, new_mods, (void **)&submod);
+                        pctx->parsed_mod->mod->name, 1, new_mods, (void **)&submod);
 
                 /* update inc pointer - parsing another (YANG 1.0) submodule can cause injecting
                  * submodule's include into main module, where it is missing */
@@ -1242,8 +1194,7 @@ search_file:
         }
         if (!inc->submodule) {
             LOGVAL(ctx, LYVE_REFERENCE, "Including \"%s\" submodule into \"%s\" failed.", inc->name,
-                    PARSER_CUR_PMOD(pctx)->is_submod ? ((struct lysp_submodule *)PARSER_CUR_PMOD(pctx))->name :
-                    PARSER_CUR_PMOD(pctx)->mod->name);
+                    pctx->parsed_mod->is_submod ? ((struct lysp_submodule *)pctx->parsed_mod)->name : pctx->parsed_mod->mod->name);
             return LY_EVALID;
         }
     }
@@ -1251,7 +1202,7 @@ search_file:
     return LY_SUCCESS;
 }
 
-LIBYANG_API_DEF const struct lysc_when *
+API const struct lysc_when *
 lysc_has_when(const struct lysc_node *node)
 {
     struct lysc_when **when;
@@ -1271,7 +1222,7 @@ lysc_has_when(const struct lysc_node *node)
     return NULL;
 }
 
-LIBYANG_API_DEF const struct lys_module *
+API const struct lys_module *
 lysc_owner_module(const struct lysc_node *node)
 {
     if (!node) {
@@ -1282,7 +1233,7 @@ lysc_owner_module(const struct lysc_node *node)
     return node->module;
 }
 
-LIBYANG_API_DEF const char *
+API const char *
 lys_nodetype2str(uint16_t nodetype)
 {
     switch (nodetype) {
@@ -1315,7 +1266,7 @@ lys_nodetype2str(uint16_t nodetype)
     }
 }
 
-LIBYANG_API_DEF enum ly_stmt
+API enum ly_stmt
 lys_nodetype2stmt(uint16_t nodetype)
 {
     switch (nodetype) {
@@ -1399,7 +1350,7 @@ lys_datatype2str(LY_DATA_TYPE basetype)
     }
 }
 
-LIBYANG_API_DEF const struct lysp_tpdf *
+API const struct lysp_tpdf *
 lysp_node_typedefs(const struct lysp_node *node)
 {
     switch (node->nodetype) {
@@ -1422,7 +1373,7 @@ lysp_node_typedefs(const struct lysp_node *node)
     }
 }
 
-LIBYANG_API_DEF const struct lysp_node_grp *
+API const struct lysp_node_grp *
 lysp_node_groupings(const struct lysp_node *node)
 {
     switch (node->nodetype) {
@@ -1464,7 +1415,7 @@ lysp_node_actions_p(struct lysp_node *node)
     }
 }
 
-LIBYANG_API_DEF const struct lysp_node_action *
+API const struct lysp_node_action *
 lysp_node_actions(const struct lysp_node *node)
 {
     struct lysp_node_action **actions;
@@ -1495,7 +1446,7 @@ lysp_node_notifs_p(struct lysp_node *node)
     }
 }
 
-LIBYANG_API_DEF const struct lysp_node_notif *
+API const struct lysp_node_notif *
 lysp_node_notifs(const struct lysp_node *node)
 {
     struct lysp_node_notif **notifs;
@@ -1535,7 +1486,7 @@ lysp_node_child_p(struct lysp_node *node)
     }
 }
 
-LIBYANG_API_DEF const struct lysp_node *
+API const struct lysp_node *
 lysp_node_child(const struct lysp_node *node)
 {
     struct lysp_node **child;
@@ -1653,7 +1604,7 @@ lysc_node_actions_p(struct lysc_node *node)
     }
 }
 
-LIBYANG_API_DEF const struct lysc_node_action *
+API const struct lysc_node_action *
 lysc_node_actions(const struct lysc_node *node)
 {
     struct lysc_node_action **actions;
@@ -1680,7 +1631,7 @@ lysc_node_notifs_p(struct lysc_node *node)
     }
 }
 
-LIBYANG_API_DEF const struct lysc_node_notif *
+API const struct lysc_node_notif *
 lysc_node_notifs(const struct lysc_node *node)
 {
     struct lysc_node_notif **notifs;
@@ -1717,7 +1668,7 @@ lysc_node_child_p(const struct lysc_node *node)
     }
 }
 
-LIBYANG_API_DEF const struct lysc_node *
+API const struct lysc_node *
 lysc_node_child(const struct lysc_node *node)
 {
     struct lysc_node **child;
@@ -1767,7 +1718,7 @@ lysc_node_musts_p(const struct lysc_node *node)
     }
 }
 
-LIBYANG_API_DEF struct lysc_must *
+API struct lysc_must *
 lysc_node_musts(const struct lysc_node *node)
 {
     struct lysc_must **must_p;
@@ -1813,7 +1764,7 @@ lysc_node_when_p(const struct lysc_node *node)
     }
 }
 
-LIBYANG_API_DEF struct lysc_when **
+API struct lysc_when **
 lysc_node_when(const struct lysc_node *node)
 {
     struct lysc_when ***when_p;
@@ -2192,7 +2143,7 @@ lysp_ext_instance_iter(struct lysp_ext_instance *ext, LY_ARRAY_COUNT_TYPE index,
     return LY_ARRAY_COUNT(ext);
 }
 
-LIBYANG_API_DEF const struct lysc_node *
+const struct lysc_node *
 lysc_data_node(const struct lysc_node *schema)
 {
     const struct lysc_node *parent;
@@ -2243,34 +2194,19 @@ lys_has_compiled(const struct lys_module *mod)
 }
 
 ly_bool
-lys_has_dep_mods(const struct lys_module *mod)
+lys_has_groupings(const struct lys_module *mod)
 {
     LY_ARRAY_COUNT_TYPE u;
 
-    /* features */
-    if (mod->parsed->features) {
-        return 1;
-    }
-
-    /* groupings */
     if (mod->parsed->groupings) {
         return 1;
     }
+
     LY_ARRAY_FOR(mod->parsed->includes, u) {
         if (mod->parsed->includes[u].submodule->groupings) {
             return 1;
         }
     }
 
-    /* augments (adding nodes with leafrefs) */
-    if (mod->parsed->augments) {
-        return 1;
-    }
-    LY_ARRAY_FOR(mod->parsed->includes, u) {
-        if (mod->parsed->includes[u].submodule->augments) {
-            return 1;
-        }
-    }
-
     return 0;
 }
