@@ -3,7 +3,7 @@
  * @author Radek Krejci <rkrejci@cesnet.cz>
  * @brief internal functions for YANG schema trees.
  *
- * Copyright (c) 2015 - 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2021 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -41,6 +41,20 @@ struct lys_glob_unres;
  */
 #define LY_MAX_BLOCK_DEPTH 500
 
+/**
+ * @brief Informational structure for YANG statements
+ */
+struct stmt_info_s {
+    const char *name;      /**< name of the statement */
+    const char *arg;       /**< name of YIN's attribute to present the statement */
+    uint8_t flags;         /**< various flags to clarify printing of the statement */
+#define STMT_FLAG_YIN 0x1 /**< has YIN element */
+#define STMT_FLAG_ID 0x2  /**< the value is identifier -> no quotes */
+};
+
+/* statements informations filled in tree_schema.c */
+extern struct stmt_info_s stmt_attr_info[];
+
 /* list of the deviate modifications strings */
 extern const char * const ly_devmod_list[];
 #define ly_devmod2str(TYPE) ly_devmod_list[TYPE]
@@ -53,7 +67,7 @@ extern const char * const ly_devmod_list[];
  * @param[in] PARENT parent statement where the KW is present - for logging.
  */
 #define PARSER_CHECK_STMTVER2_RET(CTX, KW, PARENT) \
-    if (PARSER_CUR_PMOD(CTX)->version < LYS_VERSION_1_1) {LOGVAL_PARSER((CTX), LY_VCODE_INCHILDSTMT2, KW, PARENT); return LY_EVALID;}
+    if ((CTX)->parsed_mod->version < LYS_VERSION_1_1) {LOGVAL_PARSER((CTX), LY_VCODE_INCHILDSTMT2, KW, PARENT); return LY_EVALID;}
 
 /* These 2 macros checks YANG's identifier grammar rule */
 #define is_yangidentstartchar(c) ((c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || c == '_')
@@ -124,20 +138,17 @@ enum yang_arg {
     Y_MAYBE_STR_ARG       /**< optional YANG "string" rule */
 };
 
-#define PARSER_CUR_PMOD(CTX) ((struct lysp_module *)(CTX)->parsed_mods->objs[(CTX)->parsed_mods->count - 1])
-#define PARSER_CTX(CTX) ((CTX) ? PARSER_CUR_PMOD(CTX)->mod->ctx : NULL)
-#define LOGVAL_PARSER(CTX, ...) LOGVAL(PARSER_CTX(CTX), __VA_ARGS__)
+#define PARSER_CTX(CTX) ((CTX)->parsed_mod->mod->ctx)
+#define LOGVAL_PARSER(CTX, ...) LOGVAL((CTX) ? PARSER_CTX(CTX) : NULL, __VA_ARGS__)
 
-struct lysp_ctx {
+struct lys_parser_ctx {
     LYS_INFORMAT format;             /**< parser format */
     struct ly_set tpdfs_nodes;       /**< Set of nodes that contain typedef(s). Invalid in case of
-                                          submodule, use ::lysp_ctx.main_ctx instead. */
+                                          submodule, use ::lys_parser_ctx.main_ctx instead. */
     struct ly_set grps_nodes;        /**< Set of nodes that contain grouping(s). Invalid in case of
-                                          submodule, use ::lysp_ctx.main_ctx instead. */
-    struct ly_set ext_inst;          /**< parsed extension instances to finish parsing */
-
-    struct ly_set *parsed_mods;      /**< (sub)modules being parsed, the last one is the current */
-    struct lysp_ctx *main_ctx;       /**< This pointer must not be NULL. If this context deals with the submodule,
+                                          submodule, use ::lys_parser_ctx.main_ctx instead. */
+    struct lysp_module *parsed_mod;  /**< (sub)module being parsed */
+    struct lys_parser_ctx *main_ctx; /**< This pointer must not be NULL. If this context deals with the submodule,
                                           then should be set to the context of the module to which it belongs,
                                           otherwise it points to the beginning of this structure. */
 };
@@ -145,16 +156,14 @@ struct lysp_ctx {
 /**
  * @brief Internal context for yang schema parser.
  */
-struct lysp_yang_ctx {
+struct lys_yang_parser_ctx {
     LYS_INFORMAT format;             /**< parser format */
     struct ly_set tpdfs_nodes;       /**< Set of nodes that contain typedef(s). Invalid in case of
-                                          submodule, use ::lysp_ctx.main_ctx instead. */
+                                          submodule, use ::lys_parser_ctx.main_ctx instead. */
     struct ly_set grps_nodes;        /**< Set of nodes that contain grouping(s). Invalid in case of
-                                          submodule, use ::lysp_ctx.main_ctx instead. */
-    struct ly_set ext_inst;          /**< parsed extension instances to finish parsing */
-
-    struct ly_set *parsed_mods;      /**< (sub)modules being parsed, the last one is the current */
-    struct lysp_ctx *main_ctx;       /**< This pointer must not be NULL. If this context deals with the submodule,
+                                          submodule, use ::lys_parser_ctx.main_ctx instead. */
+    struct lysp_module *parsed_mod;  /**< (sub)module being parsed */
+    struct lys_parser_ctx *main_ctx; /**< This pointer must not be NULL. If this context deals with the submodule,
                                           then should be set to the context of the module to which it belongs,
                                           otherwise it points to the beginning of this structure. */
     struct ly_in *in;                /**< input handler for the parser */
@@ -162,48 +171,58 @@ struct lysp_yang_ctx {
     uint32_t depth;                  /**< current number of nested blocks, see ::LY_MAX_BLOCK_DEPTH */
 };
 
+/**
+ * @brief free lys parser context.
+ */
+void yang_parser_ctx_free(struct lys_yang_parser_ctx *ctx);
+
 /**
  * @brief Internal context for yin schema parser.
  */
-struct lysp_yin_ctx {
+struct lys_yin_parser_ctx {
     LYS_INFORMAT format;             /**< parser format */
     struct ly_set tpdfs_nodes;       /**< Set of nodes that contain typedef(s). Invalid in case of
-                                          submodule, use ::lysp_ctx.main_ctx instead. */
+                                          submodule, use ::lys_parser_ctx.main_ctx instead. */
     struct ly_set grps_nodes;        /**< Set of nodes that contain grouping(s). Invalid in case of
-                                          submodule, use ::lysp_ctx.main_ctx instead. */
-    struct ly_set ext_inst;          /**< parsed extension instances to finish parsing */
-
-    struct ly_set *parsed_mods;      /**< (sub)modules being parsed, the last one is the current */
-    struct lysp_ctx *main_ctx;       /**< This pointer must not be NULL. If this context deals with the submodule,
+                                          submodule, use ::lys_parser_ctx.main_ctx instead. */
+    struct lysp_module *parsed_mod;  /**< (sub)module being parsed */
+    struct lys_parser_ctx *main_ctx; /**< This pointer must not be NULL. If this context deals with the submodule,
                                           then should be set to the context of the module to which it belongs,
                                           otherwise it points to the beginning of this structure. */
     struct lyxml_ctx *xmlctx;        /**< context for xml parser */
 };
 
 /**
- * @brief Check that @p c is valid UTF8 code point for YANG string.
+ * @brief free yin parser context
+ *
+ * @param[in] ctx Context to free.
+ */
+void yin_parser_ctx_free(struct lys_yin_parser_ctx *ctx);
+
+/**
+ * @brief Check that \p c is valid UTF8 code point for YANG string.
  *
  * @param[in] ctx parser context for logging.
  * @param[in] c UTF8 code point of a character to check.
  * @return LY_ERR values.
  */
-LY_ERR lysp_check_stringchar(struct lysp_ctx *ctx, uint32_t c);
+LY_ERR lysp_check_stringchar(struct lys_parser_ctx *ctx, uint32_t c);
 
 /**
- * @brief Check that @p c is valid UTF8 code point for YANG identifier.
+ * @brief Check that \p c is valid UTF8 code point for YANG identifier.
  *
- * @param[in] ctx parser context for logging. If NULL, does not log.
+ * @param[in] ctx parser context for logging.
  * @param[in] c UTF8 code point of a character to check.
  * @param[in] first Flag to check the first character of an identifier, which is more restricted.
  * @param[in,out] prefix Storage for internally used flag in case of possible prefixed identifiers:
  * 0 - colon not yet found (no prefix)
- * 1 - @p c is the colon character
+ * 1 - \p c is the colon character
  * 2 - prefix already processed, now processing the identifier
  *
  * If the identifier cannot be prefixed, NULL is expected.
  * @return LY_ERR values.
  */
-LY_ERR lysp_check_identifierchar(struct lysp_ctx *ctx, uint32_t c, ly_bool first, uint8_t *prefix);
+LY_ERR lysp_check_identifierchar(struct lys_parser_ctx *ctx, uint32_t c, ly_bool first, uint8_t *prefix);
 
 /**
  * @brief Check the currently present prefixes in the module for collision with the new one.
@@ -214,7 +233,7 @@ LY_ERR lysp_check_identifierchar(struct lysp_ctx *ctx, uint32_t c, ly_bool first
  * @param[in] value Newly added prefix value (including its location to distinguish collision with itself).
  * @return LY_EEXIST when prefix is already used in the module, LY_SUCCESS otherwise
  */
-LY_ERR lysp_check_prefix(struct lysp_ctx *ctx, struct lysp_import *imports, const char *module_prefix, const char **value);
+LY_ERR lysp_check_prefix(struct lys_parser_ctx *ctx, struct lysp_import *imports, const char *module_prefix, const char **value);
 
 /**
  * @brief Check date string (4DIGIT "-" 2DIGIT "-" 2DIGIT)
@@ -225,22 +244,7 @@ LY_ERR lysp_check_prefix(struct lysp_ctx *ctx, struct lysp_import *imports, cons
  * @param[in] stmt Statement name for error message.
  * @return LY_ERR value.
  */
-LY_ERR lysp_check_date(struct lysp_ctx *ctx, const char *date, size_t date_len, const char *stmt);
-
-/**
- * @brief Find type specified type definition.
- *
- * @param[in] id Name of the type including possible prefix. Module where the prefix is being searched is start_module.
- * @param[in] start_node Context node where the type is being instantiated to be able to search typedefs in parents.
- * @param[in] start_module Module where the type is being instantiated for search for typedefs.
- * @param[in] ext Extension where the type is being instantiated, if any.
- * @param[out] type Built-in type identifier of the id. If #LY_TYPE_UNKNOWN, tpdf is expected to contain found YANG schema typedef statement.
- * @param[out] tpdf Found type definition.
- * @param[out] node Node where the found typedef is defined, NULL in case of a top-level typedef.
- * @return LY_ERR value.
- */
-LY_ERR lysp_type_find(const char *id, struct lysp_node *start_node, const struct lysp_module *start_module,
-        const struct lysc_ext_instance *ext, LY_DATA_TYPE *type, const struct lysp_tpdf **tpdf, struct lysp_node **node);
+LY_ERR lysp_check_date(struct lys_parser_ctx *ctx, const char *date, size_t date_len, const char *stmt);
 
 /**
  * @brief Check names of typedefs in the parsed module to detect collisions.
@@ -249,7 +253,7 @@ LY_ERR lysp_type_find(const char *id, struct lysp_node *start_node, const struct
  * @param[in] mod Module where the type is being defined.
  * @return LY_ERR value.
  */
-LY_ERR lysp_check_dup_typedefs(struct lysp_ctx *ctx, struct lysp_module *mod);
+LY_ERR lysp_check_dup_typedefs(struct lys_parser_ctx *ctx, struct lysp_module *mod);
 
 /**
  * @brief Check names of groupings in the parsed module to detect collisions.
@@ -258,7 +262,7 @@ LY_ERR lysp_check_dup_typedefs(struct lysp_ctx *ctx, struct lysp_module *mod);
  * @param[in] mod Module where the type is being defined.
  * @return LY_ERR value.
  */
-LY_ERR lysp_check_dup_groupings(struct lysp_ctx *ctx, struct lysp_module *mod);
+LY_ERR lysp_check_dup_groupings(struct lys_parser_ctx *ctx, struct lysp_module *mod);
 
 /**
  * @brief Check names of features in the parsed module and submodules to detect collisions.
@@ -267,7 +271,7 @@ LY_ERR lysp_check_dup_groupings(struct lysp_ctx *ctx, struct lysp_module *mod);
  * @param[in] mod Module where the type is being defined.
  * @return LY_ERR value.
  */
-LY_ERR lysp_check_dup_features(struct lysp_ctx *ctx, struct lysp_module *mod);
+LY_ERR lysp_check_dup_features(struct lys_parser_ctx *ctx, struct lysp_module *mod);
 
 /**
  * @brief Check names of identities in the parsed module and submodules to detect collisions.
@@ -276,7 +280,7 @@ LY_ERR lysp_check_dup_features(struct lysp_ctx *ctx, struct lysp_module *mod);
  * @param[in] mod Module where the type is being defined.
  * @return LY_ERR value.
  */
-LY_ERR lysp_check_dup_identities(struct lysp_ctx *ctx, struct lysp_module *mod);
+LY_ERR lysp_check_dup_identities(struct lys_parser_ctx *ctx, struct lysp_module *mod);
 
 /**
  * @brief Just move the newest revision into the first position, does not sort the rest
@@ -284,6 +288,19 @@ LY_ERR lysp_check_dup_identities(struct lysp_ctx *ctx, struct lysp_module *mod);
  */
 void lysp_sort_revisions(struct lysp_revision *revs);
 
+/**
+ * @brief Find type specified type definition.
+ *
+ * @param[in] id Name of the type including possible prefix. Module where the prefix is being searched is start_module.
+ * @param[in] start_node Context node where the type is being instantiated to be able to search typedefs in parents.
+ * @param[in] start_module Module where the type is being instantiated for search for typedefs.
+ * @param[out] type Built-in type identifier of the id. If #LY_TYPE_UNKNOWN, tpdf is expected to contain found YANG schema typedef statement.
+ * @param[out] tpdf Found type definition.
+ * @param[out] node Node where the found typedef is defined, NULL in case of a top-level typedef.
+ */
+LY_ERR lysp_type_find(const char *id, struct lysp_node *start_node, const struct lysp_module *start_module,
+        LY_DATA_TYPE *type, const struct lysp_tpdf **tpdf, struct lysp_node **node);
+
 /**
  * @brief Validate enum name.
  *
@@ -293,7 +310,7 @@ void lysp_sort_revisions(struct lysp_revision *revs);
  *
  * @return LY_ERR values
  */
-LY_ERR lysp_check_enum_name(struct lysp_ctx *ctx, const char *name, size_t name_len);
+LY_ERR lysp_check_enum_name(struct lys_parser_ctx *ctx, const char *name, size_t name_len);
 
 /**
  * @brief Find source data for a specific module, parse it, and add into the context.
@@ -320,7 +337,31 @@ LY_ERR lys_parse_load(struct ly_ctx *ctx, const char *name, const char *revision
  * @param[in,out] new_mods Set of all the new mods added to the context. Includes this module and all of its imports.
  * @return LY_ERR value.
  */
-LY_ERR lysp_load_submodules(struct lysp_ctx *pctx, struct lysp_module *pmod, struct ly_set *new_mods);
+LY_ERR lysp_load_submodules(struct lys_parser_ctx *pctx, struct lysp_module *pmod, struct ly_set *new_mods);
+
+/**
+ * @brief Free a parsed restriction.
+ *
+ * @param[in] ctx libyang context.
+ * @param[in] restr Restriction to free.
+ */
+void lysp_restr_free(struct ly_ctx *ctx, struct lysp_restr *restr);
+
+/**
+ * @brief Free a parsed qualified name.
+ *
+ * @param[in] ctx libyang context.
+ * @param[in] qname Qualified name to free.
+ */
+void lysp_qname_free(struct ly_ctx *ctx, struct lysp_qname *qname);
+
+/**
+ * @brief Free a parsed node.
+ *
+ * @param[in] ctx libyang context.
+ * @param[in] node Node to free.
+ */
+void lysp_node_free(struct ly_ctx *ctx, struct lysp_node *node);
 
 /**
  * @brief Get address of a node's actions list if any.
@@ -437,8 +478,8 @@ struct lysc_must **lysc_node_musts_p(const struct lysc_node *node);
  *
  * @param[in] ctx libyang context.
  * @param[in] ext Extension instance for which the definition will be searched.
- * @param[out] ext_mod Module of the extension definition of @p ext.
- * @param[out] ext_def Optional found extension definition.
+ * @param[in, out] ext_mod Pointer to the module where the extension definition of the @p ext to correctly resolve prefixes.
+ * @param[out] ext_def Pointer to return found extension definition.
  * @return LY_SUCCESS when the definition was found.
  * @return LY_EVALID when the extension instance is invalid and/or the definition not found.
  */
@@ -466,17 +507,21 @@ const struct lysc_node *lysc_ext_find_node(const struct lysc_ext_instance *ext,
  * (it might come from import modules which is not yet parsed at that time). Therefore, all the attributes are stored
  * as substatements and resolving argument is postponed.
  *
+ * There are 3 places which need the argument, so they resolve it when missing - YIN and YANG printers and extension instance
+ * compiler.
+ *
  * @param[in] ctx libyang context
  * @param[in] ext_p Parsed extension to be updated.
+ * @param[in] ext_def Extension definition, found with ::lysp_ext_find_definition().
  * @return LY_ERR value.
  */
-LY_ERR lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_instance *ext_p);
+LY_ERR lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_instance *ext_p, struct lysp_ext *ext_def);
 
 /**
  * @brief Iterate over the specified type of the extension instances
  *
  * @param[in] ext ([Sized array](@ref sizedarrays)) of extensions to explore
- * @param[in] index Index in the @p ext array where to start searching (first call with 0, the consequent calls with
+ * @param[in] index Index in the \p ext array where to start searching (first call with 0, the consequent calls with
  *            the returned index increased by 1 (until the iteration is not terminated by returning LY_ARRAY_COUNT(ext).
  * @param[in] substmt The statement the extension is supposed to belong to.
  * @result index in the ext array, LY_ARRAY_COUNT(ext) value if not present.
@@ -484,8 +529,16 @@ LY_ERR lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_in
 LY_ARRAY_COUNT_TYPE lysp_ext_instance_iter(struct lysp_ext_instance *ext, LY_ARRAY_COUNT_TYPE index, enum ly_stmt substmt);
 
 /**
- * @brief Stringify YANG built-in type.
+ * @brief Get the covering schema module structure for the given parsed module structure.
  *
+ * @param[in] ctx libyang context to search.
+ * @param[in] mod Parsed schema structure.
+ * @return Corresponding lys_module structure for the given parsed schema structure.
+ */
+struct lys_module *lysp_find_module(struct ly_ctx *ctx, const struct lysp_module *mod);
+
+/**
+ * @brief Stringify YANG built-in type.
  * @param[in] basetype Built-in type ID to stringify.
  * @return Constant string with the name of the built-in type.
  */
@@ -562,7 +615,7 @@ LY_ERR lys_parse_in(struct ly_ctx *ctx, struct ly_in *in, LYS_INFORMAT format, l
  * @param[out] submodule Parsed submodule.
  * @return LY_ERR value.
  */
-LY_ERR lys_parse_submodule(struct ly_ctx *ctx, struct ly_in *in, LYS_INFORMAT format, struct lysp_ctx *main_ctx,
+LY_ERR lys_parse_submodule(struct ly_ctx *ctx, struct ly_in *in, LYS_INFORMAT format, struct lys_parser_ctx *main_ctx,
         lys_custom_check custom_check, void *check_data, struct ly_set *new_mods, struct lysp_submodule **submodule);
 
 /**
@@ -582,6 +635,182 @@ void lys_parser_fill_filepath(struct ly_ctx *ctx, struct ly_in *in, const char *
  */
 uint8_t lysc_iff_getop(uint8_t *list, size_t pos);
 
+/**
+ * @brief Macro to free [sized array](@ref sizedarrays) of items using the provided free function. The ARRAY itself is also freed,
+ * but the memory is not sanitized.
+ */
+#define FREE_ARRAY(CTX, ARRAY, FUNC) {LY_ARRAY_COUNT_TYPE c__; LY_ARRAY_FOR(ARRAY, c__){(FUNC)(CTX, &(ARRAY)[c__]);}LY_ARRAY_FREE(ARRAY);}
+
+/**
+ * @brief Macro to free the specified MEMBER of a structure using the provided free function. The memory is not sanitized.
+ */
+#define FREE_MEMBER(CTX, MEMBER, FUNC) if (MEMBER) {(FUNC)(CTX, MEMBER);free(MEMBER);}
+
+/**
+ * @brief Macro to free [sized array](@ref sizedarrays) of strings stored in the context's dictionary. The ARRAY itself is also freed,
+ * but the memory is not sanitized.
+ */
+#define FREE_STRINGS(CTX, ARRAY) {LY_ARRAY_COUNT_TYPE c__; LY_ARRAY_FOR(ARRAY, c__){lydict_remove(CTX, ARRAY[c__]);}LY_ARRAY_FREE(ARRAY);}
+
+/**
+ * @brief Free the printable YANG schema tree structure. Works for both modules and submodules.
+ *
+ * @param[in] module Printable YANG schema tree structure to free.
+ */
+void lysp_module_free(struct lysp_module *module);
+
+/**
+ * @brief Free the parsed type structure.
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in] type Parsed schema type structure to free. Note that the type itself is not freed.
+ */
+void lysp_type_free(struct ly_ctx *ctx, struct lysp_type *type);
+
+/**
+ * @brief Free the parsed extension instance structure.
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in] ext Parsed extension instance structure to free. Note that the instance itself is not freed.
+ */
+void lysp_ext_instance_free(struct ly_ctx *ctx, struct lysp_ext_instance *ext);
+
+/**
+ * @brief Parse generic statement structure into a specific parsed-schema structure.
+ *
+ * @param[in] ctx The compilation context of the @p stmt being processed
+ * @param[in] stmt Generic statement structure to process.
+ * @param[out] result Specific parsed-schema structure for the given statement. For the specific type for the particular statement, check the function code.
+ * @param[in,out] exts [sized array](@ref sizedarrays) For extension instances in case of statements that do not store extension instances in their own list.
+ * @return LY_ERR value.
+ */
+LY_ERR lysp_stmt_parse(struct lysc_ctx *ctx, const struct lysp_stmt *stmt, void **result, struct lysp_ext_instance **exts);
+
+/**
+ * @brief Free a parsed node.
+ *
+ * @param[in] ctx libyang context.
+ * @param[in] node Node to free.
+ */
+void lysp_node_free(struct ly_ctx *ctx, struct lysp_node *node);
+
+/**
+ * @brief Free a bit/enum item.
+ *
+ * @param[in] ctx libyang context.
+ * @param[in] item Bit/enum item to free.
+ */
+void lysc_enum_item_free(struct ly_ctx *ctx, struct lysc_type_bitenum_item *item);
+
+/**
+ * @brief Free the compiled type structure.
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] type Compiled type structure to be freed. The structure has refcount, so it is freed only in case the value is decreased to 0.
+ */
+void lysc_type_free(struct ly_ctx *ctx, struct lysc_type *type);
+
+/**
+ * @brief Free the compiled if-feature structure.
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] iff Compiled if-feature structure to be cleaned.
+ * Since the structure is typically part of the sized array, the structure itself is not freed.
+ */
+void lysc_iffeature_free(struct ly_ctx *ctx, struct lysc_iffeature *iff);
+
+/**
+ * @brief Free the compiled identity structure.
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] ident Compiled identity structure to be cleaned.
+ * Since the structure is typically part of the sized array, the structure itself is not freed.
+ */
+void lysc_ident_free(struct ly_ctx *ctx, struct lysc_ident *ident);
+
+/**
+ * @brief Free the compiled must structure.
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] must Compiled must structure to be cleaned.
+ * Since the structure is typically part of the sized array, the structure itself is not freed.
+ */
+void lysc_must_free(struct ly_ctx *ctx, struct lysc_must *must);
+
+/**
+ * @brief Free the data inside compiled input/output structure.
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] inout Compiled inout structure to be cleaned.
+ * Since the structure is part of the RPC/action structure, it is not freed itself.
+ */
+void lysc_node_action_inout_free(struct ly_ctx *ctx, struct lysc_node_action_inout *inout);
+
+/**
+ * @brief Free the data inside compiled RPC/action structure.
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] action Compiled action structure to be cleaned.
+ * Since the structure is typically part of the sized array, the structure itself is not freed.
+ */
+void lysc_node_action_free(struct ly_ctx *ctx, struct lysc_node_action *action);
+
+/**
+ * @brief Free the items inside the compiled Notification structure.
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] notif Compiled Notification structure to be cleaned.
+ * Since the structure is typically part of the sized array, the structure itself is not freed.
+ */
+void lysc_node_notif_free(struct ly_ctx *ctx, struct lysc_node_notif *notif);
+
+/**
+ * @brief Free the compiled extension definition and NULL the provided pointer.
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] ext Compiled extension definition to be freed.
+ */
+void lysc_extension_free(struct ly_ctx *ctx, struct lysc_ext **ext);
+
+/**
+ * @brief Free the compiled extension instance structure.
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] ext Compiled extension instance structure to be cleaned.
+ * Since the structure is typically part of the sized array, the structure itself is not freed.
+ */
+void lysc_ext_instance_free(struct ly_ctx *ctx, struct lysc_ext_instance *ext);
+
+/**
+ * @brief Free the compiled node structure.
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in] node Compiled node structure to be freed.
+ * @param[in] unlink Whether to first unlink the node before freeing.
+ */
+void lysc_node_free(struct ly_ctx *ctx, struct lysc_node *node, ly_bool unlink);
+
+/**
+ * @brief Free the compiled container node structure.
+ *
+ * Only the container-specific members are freed, for generic node free function,
+ * use ::lysc_node_free().
+ *
+ * @param[in] ctx libyang context where the string data resides in a dictionary.
+ * @param[in,out] node Compiled container node structure to be freed.
+ */
+void lysc_node_container_free(struct ly_ctx *ctx, struct lysc_node_container *node);
+
+/**
+ * @brief Free the compiled schema structure.
+ *
+ * @param[in,out] module Compiled schema module structure to free.
+ */
+void lysc_module_free(struct lysc_module *module);
+
+/**
+ * @brief Free the schema structure. It just frees, it does not remove the schema from its context.
+ *
+ * @param[in,out] module Schema module structure to free.
+ */
+void lys_module_free(struct lys_module *module);
+
 /**
  * @brief match yang keyword
  *
@@ -606,6 +835,19 @@ enum ly_stmt lysp_match_kw(struct ly_in *in, uint64_t *indent);
 char *lysc_path_until(const struct lysc_node *node, const struct lysc_node *parent, LYSC_PATH_TYPE pathtype, char *buffer,
         size_t buflen);
 
+/**
+ * @brief Get nearest @p schema parent (including the node itself) that can be instantiated in data.
+ *
+ * @param[in] schema Schema node to get the nearest data node for.
+ * @return Schema data node, NULL if top-level (in data).
+ */
+const struct lysc_node *lysc_data_node(const struct lysc_node *schema);
+
+/**
+ * @brief Same as ::lysc_data_node() but never returns the node itself.
+ */
+#define lysc_data_parent(SCHEMA) lysc_data_node((SCHEMA)->parent)
+
 /**
  * @brief Get format-specific prefix for a module.
  *
@@ -685,61 +927,6 @@ ly_bool lys_has_compiled(const struct lys_module *mod);
  * @param[in] mod Module to examine.
  * @return Whether it has groupings or not.
  */
-ly_bool lys_has_dep_mods(const struct lys_module *mod);
-
-/**
- * @brief Get YANG string keyword of a statement.
- *
- * @return YANG string keyword of the statement.
- */
-const char *lys_stmt_str(enum ly_stmt stmt);
-
-/**
- * @brief Get YIN argument (attribute) name of a statement.
- *
- * @return YIN argument name, if any.
- */
-const char *lys_stmt_arg(enum ly_stmt stmt);
-
-#define LY_STMT_FLAG_YIN 0x1 /**< has YIN element */
-#define LY_STMT_FLAG_ID 0x2  /**< the value is identifier -> no quotes */
-
-/**
- * @brief Get statement printer flags.
- *
- * @return Additional statement information as LY_STMT_FLAG_* flags.
- */
-uint8_t lys_stmt_flags(enum ly_stmt stmt);
-
-/**
- * @brief Learn whether the module qualifies for a single dep set with only this module or not.
- *
- * @param[in] mod Module to examine.
- * @return Whether it qualifies as a single dep set or not.
- */
-#define LYS_IS_SINGLE_DEP_SET(mod) \
-        (!(mod)->parsed->features && (!lys_has_compiled(mod) || ((mod)->compiled && !lys_has_recompiled(mod))))
-
-/**
- * @brief Get pointer to a compiled ext instance storage for a specific statement.
- *
- * @param[in] ext Compiled ext instance.
- * @param[in] stmt Compiled statement. Can be a mask when the first match is returned, it is expected the storage is
- * the same for all the masked statements.
- * @param[out] storage_p Pointer to a compiled ext instance substatement storage, NULL if was not compiled.
- * @return LY_SUCCESS on success.
- * @return LY_ENOT if the substatement is not supported.
- */
-LY_ERR lyplg_ext_get_storage_p(const struct lysc_ext_instance *ext, int stmt, const void ***storage_p);
-
-/**
- * @brief Warning if the filename does not match the expected module name and version
- *
- * @param[in] ctx Context for logging
- * @param[in] name Expected module name
- * @param[in] revision Expected module revision, or NULL if not to be checked
- * @param[in] filename File path to be checked
- */
-void ly_check_module_filename(const struct ly_ctx *ctx, const char *name, const char *revision, const char *filename);
+ly_bool lys_has_groupings(const struct lys_module *mod);
 
 #endif /* LY_TREE_SCHEMA_INTERNAL_H_ */
