@@ -52,10 +52,9 @@ LYPLG_EXTENSIONS = {
 
         .plugin.id = "libyang 2 - simple test, version 1",
         .plugin.compile = &hint_compile,
+        .plugin.validate = NULL,
         .plugin.sprinter = NULL,
-        .plugin.free = NULL,
-        .plugin.snode = NULL,
-        .plugin.validate = NULL
+        .plugin.free = NULL
     },
     {0} /* terminating zeroed item */
 };
