@@ -22,74 +22,6 @@
 #include "tree_schema_internal.h"
 #include "utests.h"
 
-#ifdef _WIN32
-static void
-slashes_to_backslashes(char *path)
-{
-    while ((path = strchr(path, '/'))) {
-        *path++ = '\\';
-    }
-}
-
-static void
-test_searchdirs(void **state)
-{
-    const char * const *list;
-    char *path1 = strdup(TESTS_BIN "/utests");
-    char *path2 = strdup(TESTS_SRC);
-
-    slashes_to_backslashes(path1);
-    slashes_to_backslashes(path2);
-
-    assert_int_equal(LY_EINVAL, ly_ctx_set_searchdir(NULL, NULL));
-    CHECK_LOG("Invalid argument ctx (ly_ctx_set_searchdir()).", NULL);
-    assert_null(ly_ctx_get_searchdirs(NULL));
-    CHECK_LOG("Invalid argument ctx (ly_ctx_get_searchdirs()).", NULL);
-    assert_int_equal(LY_EINVAL, ly_ctx_unset_searchdir(NULL, NULL));
-    CHECK_LOG("Invalid argument ctx (ly_ctx_unset_searchdir()).", NULL);
-
-    /* correct path */
-    assert_int_equal(LY_SUCCESS, ly_ctx_set_searchdir(UTEST_LYCTX, path1));
-    assert_int_equal(1, UTEST_LYCTX->search_paths.count);
-    assert_string_equal(path1, UTEST_LYCTX->search_paths.objs[0]);
-
-    /* duplicated paths */
-    assert_int_equal(LY_EEXIST, ly_ctx_set_searchdir(UTEST_LYCTX, path1));
-    assert_int_equal(1, UTEST_LYCTX->search_paths.count);
-    assert_string_equal(path1, UTEST_LYCTX->search_paths.objs[0]);
-
-    /* another path */
-    assert_int_equal(LY_SUCCESS, ly_ctx_set_searchdir(UTEST_LYCTX, path2));
-    assert_int_equal(2, UTEST_LYCTX->search_paths.count);
-    assert_string_equal(path2, UTEST_LYCTX->search_paths.objs[1]);
-
-    /* get searchpaths */
-    list = ly_ctx_get_searchdirs(UTEST_LYCTX);
-    assert_non_null(list);
-    assert_string_equal(path1, list[0]);
-    assert_string_equal(path2, list[1]);
-    assert_null(list[2]);
-
-    /* removing searchpaths */
-    /* nonexisting */
-    assert_int_equal(LY_EINVAL, ly_ctx_unset_searchdir(UTEST_LYCTX, "/nonexistingfile"));
-    CHECK_LOG_CTX("Invalid argument value (ly_ctx_unset_searchdir()).", NULL);
-
-    /* first */
-    assert_int_equal(LY_SUCCESS, ly_ctx_unset_searchdir(UTEST_LYCTX, path1));
-    assert_int_equal(1, UTEST_LYCTX->search_paths.count);
-    assert_string_not_equal(path1, list[0]);
-
-    /* second */
-    assert_int_equal(LY_SUCCESS, ly_ctx_unset_searchdir(UTEST_LYCTX, path2));
-    assert_int_equal(0, UTEST_LYCTX->search_paths.count);
-
-    free(path1);
-    free(path2);
-}
-
-#else
-
 static void
 test_searchdirs(void **state)
 {
@@ -106,6 +38,9 @@ test_searchdirs(void **state)
     /* readable and executable, but not a directory */
     assert_int_equal(LY_EINVAL, ly_ctx_set_searchdir(UTEST_LYCTX, TESTS_BIN "/utest_context"));
     CHECK_LOG_CTX("Given search directory \""TESTS_BIN "/utest_context\" is not a directory.", NULL);
+    /* not executable */
+    assert_int_equal(LY_EINVAL, ly_ctx_set_searchdir(UTEST_LYCTX, __FILE__));
+    CHECK_LOG_CTX("Unable to fully access search directory \""__FILE__ "\" (Permission denied).", NULL);
     /* not existing */
     assert_int_equal(LY_EINVAL, ly_ctx_set_searchdir(UTEST_LYCTX, "/nonexistingfile"));
     CHECK_LOG_CTX("Unable to use search directory \"/nonexistingfile\" (No such file or directory).", NULL);
@@ -169,16 +104,12 @@ test_searchdirs(void **state)
     /* test searchdir list in ly_ctx_new() */
     assert_int_equal(LY_EINVAL, ly_ctx_new("/nonexistingfile", 0, &UTEST_LYCTX));
     CHECK_LOG("Unable to use search directory \"/nonexistingfile\" (No such file or directory).", NULL);
-    assert_int_equal(LY_SUCCESS,
-            ly_ctx_new(TESTS_SRC PATH_SEPARATOR TESTS_BIN PATH_SEPARATOR TESTS_BIN PATH_SEPARATOR TESTS_SRC,
-            LY_CTX_DISABLE_SEARCHDIRS, &UTEST_LYCTX));
+    assert_int_equal(LY_SUCCESS, ly_ctx_new(TESTS_SRC ":"TESTS_BIN ":"TESTS_BIN ":"TESTS_SRC, LY_CTX_DISABLE_SEARCHDIRS, &UTEST_LYCTX));
     assert_int_equal(2, UTEST_LYCTX->search_paths.count);
     assert_string_equal(TESTS_SRC, UTEST_LYCTX->search_paths.objs[0]);
     assert_string_equal(TESTS_BIN, UTEST_LYCTX->search_paths.objs[1]);
 }
 
-#endif
-
 static void
 test_options(void **state)
 {
@@ -440,10 +371,7 @@ test_get_models(void **state)
     struct lys_glob_unres unres = {0};
 
     unsigned int index = 0;
-    const char *names[] = {
-        "ietf-yang-metadata", "yang", "ietf-inet-types", "ietf-yang-types", "ietf-yang-schema-mount",
-        "ietf-datastores", "ietf-yang-library", "a", "a", "a"
-    };
+    const char *names[] = {"ietf-yang-metadata", "yang", "ietf-inet-types", "ietf-yang-types", "ietf-datastores", "ietf-yang-library", "a", "a", "a"};
 
     assert_int_equal(LY_SUCCESS, ly_in_new_memory(str0, &in0));
     assert_int_equal(LY_SUCCESS, ly_in_new_memory(str1, &in1));
@@ -478,7 +406,7 @@ test_get_models(void **state)
     /* invalid attempts - implementing module of the same name and inserting the same module */
     assert_int_equal(LY_SUCCESS, lys_parse_in(UTEST_LYCTX, in2, LYS_IN_YANG, NULL, NULL, &unres.creating, &mod2));
     assert_int_equal(LY_EDENIED, lys_implement(mod2, NULL, &unres));
-    CHECK_LOG_CTX("Module \"a@2018-10-24\" is already implemented in revision \"2018-10-23\".", NULL);
+    CHECK_LOG_CTX("Module \"a@2018-10-24\" is present in the context in other implemented revision (2018-10-23).", NULL);
     lys_unres_glob_erase(&unres);
     ly_in_reset(in1);
     /* it is already there, fine */
@@ -510,7 +438,7 @@ test_get_models(void **state)
     while ((mod = (struct lys_module *)ly_ctx_get_module_iter(UTEST_LYCTX, &index))) {
         assert_string_equal(names[index - 1], mod->name);
     }
-    assert_int_equal(10, index);
+    assert_int_equal(9, index);
 
     /* cleanup */
     ly_in_free(in0, 0);
