@@ -1,10 +1,9 @@
-/**
+/*
  * @file test_parser_xml.c
- * @author Radek Krejci <rkrejci@cesnet.cz>
- * @author Michal Vasko <mvasko@cesnet.cz>
+ * @author: Radek Krejci <rkrejci@cesnet.cz>
  * @brief unit tests for functions from parser_xml.c
  *
- * Copyright (c) 2019 - 2022 CESNET, z.s.p.o.
+ * Copyright (c) 2019-2020 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -31,10 +30,12 @@ setup(void **state)
             "    namespace urn:tests:a;\n"
             "    prefix a;\n"
             "    yang-version 1.1;\n"
-            "    list l1 { key \"a b c\"; leaf a {type string;} leaf b {type string;} leaf c {type int16;}"
-            "        leaf d {type string;}"
-            "        container cont {leaf e {type boolean;}}"
-            "    }"
+            "    list l1 {\n"
+            "        key \"a b c\";\n"
+            "        leaf a {type string;}\n"
+            "        leaf b {type string;}\n"
+            "        leaf c {type int16;}\n"
+            "        leaf d {type string;}}\n"
             "    leaf foo { type string;}\n"
             "    container c {\n"
             "        leaf x {type string;}\n"
@@ -42,7 +43,6 @@ setup(void **state)
             "        notification n1 { leaf nl {type string;}}}\n"
             "    container cp {presence \"container switch\"; leaf y {type string;} leaf z {type int8;}}\n"
             "    anydata any {config false;}\n"
-            "    anyxml anyx;\n"
             "    leaf foo2 { type string; default \"default-val\"; }\n"
             "    leaf foo3 { type uint32; }\n"
             "    notification n2;}";
@@ -85,6 +85,7 @@ test_leaf(void **state)
     leaf = (struct lyd_node_term *)tree->next->next;
     CHECK_LYD_VALUE(leaf->value, STRING, "default-val");
     assert_true(leaf->flags & LYD_DEFAULT);
+
     lyd_free_all(tree);
 
     /* make foo2 explicit */
@@ -97,6 +98,7 @@ test_leaf(void **state)
     leaf = (struct lyd_node_term *)tree;
     CHECK_LYD_VALUE(leaf->value, STRING, "default-val");
     assert_false(leaf->flags & LYD_DEFAULT);
+
     lyd_free_all(tree);
 
     /* parse foo2 but make it implicit, skip metadata xxx from missing schema */
@@ -110,20 +112,14 @@ test_leaf(void **state)
     leaf = (struct lyd_node_term *)tree;
     CHECK_LYD_VALUE(leaf->value, STRING, "default-val");
     assert_true(leaf->flags & LYD_DEFAULT);
-    lyd_free_all(tree);
 
-    /* invalid value */
-    data = "<l1 xmlns=\"urn:tests:a\"><a>val-a</a><b>val-b</b><c>1</c><cont><e>0</e></cont></l1>";
-    PARSER_CHECK_ERROR(data, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "Invalid boolean value \"0\".",
-            "Data location \"/a:l1[a='val-a'][b='val-b'][c='1']/cont/e\", line number 1.");
+    lyd_free_all(tree);
 }
 
 static void
 test_anydata(void **state)
 {
     const char *data;
-    char *str;
     struct lyd_node *tree;
 
     data = "<any xmlns=\"urn:tests:a\">\n"
@@ -137,7 +133,6 @@ test_anydata(void **state)
     tree = tree->next;
     CHECK_LYSC_NODE(tree->schema, NULL, 0, LYS_CONFIG_R | LYS_STATUS_CURR | LYS_SET_CONFIG, 1, "any",
             1, LYS_ANYDATA, 0, 0, NULL, 0);
-
     const char *data_expected =
             "<any xmlns=\"urn:tests:a\">\n"
             "  <element1>\n"
@@ -148,48 +143,6 @@ test_anydata(void **state)
 
     CHECK_LYD_STRING(tree, LYD_PRINT_WITHSIBLINGS, data_expected);
 
-    assert_int_equal(LY_SUCCESS, lyd_any_value_str(tree, &str));
-    lyd_free_all(tree);
-
-    assert_int_equal(LY_SUCCESS, lyd_new_path2(NULL, UTEST_LYCTX, "/a:any", str, strlen(str), LYD_ANYDATA_XML, 0, &tree, NULL));
-    free(str);
-    CHECK_LYD_STRING(tree, LYD_PRINT_WITHSIBLINGS, data_expected);
-    lyd_free_all(tree);
-}
-
-static void
-test_anyxml(void **state)
-{
-    const char *data;
-    char *str;
-    struct lyd_node *tree;
-
-    data = "<anyx xmlns=\"urn:tests:a\">\n"
-            "  <element1>\n"
-            "    <element2 x:attr2=\"test\" xmlns:x=\"urn:x\">data</element2>\n"
-            "  </element1>\n"
-            "  <element1a/>\n"
-            "</anyx>\n";
-    CHECK_PARSE_LYD(data, 0, LYD_VALIDATE_PRESENT, tree);
-    assert_non_null(tree);
-    tree = tree->next;
-
-    const char *data_expected =
-            "<anyx xmlns=\"urn:tests:a\">\n"
-            "  <element1>\n"
-            "    <element2 xmlns:x=\"urn:x\" x:attr2=\"test\">data</element2>\n"
-            "  </element1>\n"
-            "  <element1a/>\n"
-            "</anyx>\n";
-
-    CHECK_LYD_STRING(tree, LYD_PRINT_WITHSIBLINGS, data_expected);
-
-    assert_int_equal(LY_SUCCESS, lyd_any_value_str(tree, &str));
-    lyd_free_all(tree);
-
-    assert_int_equal(LY_SUCCESS, lyd_new_path2(NULL, UTEST_LYCTX, "/a:anyx", str, strlen(str), LYD_ANYDATA_XML, 0, &tree, NULL));
-    free(str);
-    CHECK_LYD_STRING(tree, LYD_PRINT_WITHSIBLINGS, data_expected);
     lyd_free_all(tree);
 }
 
@@ -214,22 +167,17 @@ test_list(void **state)
 
     /* missing keys */
     PARSER_CHECK_ERROR("<l1 xmlns=\"urn:tests:a\"><c>1</c><b>b</b></l1>", 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "List instance is missing its key \"a\".", "Data location \"/a:l1[b='b'][c='1']\", line number 1.");
-    CHECK_LOG_CTX("Invalid position of the key \"b\" in a list.", NULL);
+            "List instance is missing its key \"a\".", "Schema location /a:l1, data location /a:l1[b='b'][c='1'], line number 1.");
 
     PARSER_CHECK_ERROR("<l1 xmlns=\"urn:tests:a\"><a>a</a></l1>", 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "List instance is missing its key \"b\".", "Data location \"/a:l1[a='a']\", line number 1.");
+            "List instance is missing its key \"b\".", "Schema location /a:l1, data location /a:l1[a='a'], line number 1.");
 
     PARSER_CHECK_ERROR("<l1 xmlns=\"urn:tests:a\"><b>b</b><a>a</a></l1>", 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "List instance is missing its key \"c\".", "Data location \"/a:l1[a='a'][b='b']\", line number 1.");
-    CHECK_LOG_CTX("Invalid position of the key \"a\" in a list.", NULL);
+            "List instance is missing its key \"c\".", "Schema location /a:l1, data location /a:l1[a='a'][b='b'], line number 1.");
 
     /* key duplicate */
     PARSER_CHECK_ERROR("<l1 xmlns=\"urn:tests:a\"><c>1</c><b>b</b><a>a</a><c>1</c></l1>", 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "Duplicate instance of \"c\".",
-            "Data location \"/a:l1[a='a'][b='b'][c='1'][c='1']/c\", line number 1.");
-    CHECK_LOG_CTX("Invalid position of the key \"a\" in a list.", NULL);
-    CHECK_LOG_CTX("Invalid position of the key \"b\" in a list.", NULL);
+            "Duplicate instance of \"c\".", "Schema location /a:l1/c, data location /a:l1[a='a'][b='b'][c='1'][c='1']/c, line number 1.");
 
     /* keys order */
     CHECK_PARSE_LYD("<l1 xmlns=\"urn:tests:a\"><d>d</d><a>a</a><c>1</c><b>b</b></l1>", 0, LYD_VALIDATE_PRESENT, tree);
@@ -243,7 +191,7 @@ test_list(void **state)
     assert_non_null(leaf = (struct lyd_node_term *)leaf->next);
     CHECK_LYSC_NODE(leaf->schema, NULL, 0, LYS_CONFIG_W | LYS_STATUS_CURR | LYS_KEY, 1, "c", 1, LYS_LEAF, 1, 0, NULL, 0);
     assert_non_null(leaf = (struct lyd_node_term *)leaf->next);
-    CHECK_LYSC_NODE(leaf->schema, NULL, 0, LYS_CONFIG_W | LYS_STATUS_CURR, 1, "d", 1, LYS_LEAF, 1, 0, NULL, 0);
+    CHECK_LYSC_NODE(leaf->schema, NULL, 0, LYS_CONFIG_W | LYS_STATUS_CURR, 1, "d", 0, LYS_LEAF, 1, 0, NULL, 0);
     CHECK_LOG_CTX("Invalid position of the key \"b\" in a list.", NULL);
     lyd_free_all(tree);
 
@@ -258,11 +206,10 @@ test_list(void **state)
     assert_non_null(leaf = (struct lyd_node_term *)leaf->next);
     CHECK_LYSC_NODE(leaf->schema, NULL, 0, LYS_CONFIG_W | LYS_STATUS_CURR | LYS_KEY, 1, "c", 1, LYS_LEAF, 1, 0, NULL, 0);
     CHECK_LOG_CTX("Invalid position of the key \"a\" in a list.", NULL);
-    CHECK_LOG_CTX("Invalid position of the key \"b\" in a list.", NULL);
     lyd_free_all(tree);
 
     PARSER_CHECK_ERROR(data, LYD_PARSE_STRICT, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "Invalid position of the key \"b\" in a list.", "Data location \"/a:l1[c='1']/b\", line number 1.");
+            "Invalid position of the key \"b\" in a list.", "Schema location /a:l1/b, data location /a:b, line number 1.");
 }
 
 static void
@@ -296,7 +243,7 @@ test_opaq(void **state)
     /* invalid value, no flags */
     data = "<foo3 xmlns=\"urn:tests:a\"/>";
     PARSER_CHECK_ERROR(data, 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "Invalid type uint32 empty value.", "Schema location \"/a:foo3\", line number 1.");
+            "Invalid empty uint32 value.", "Schema location /a:foo3, line number 1.");
 
     /* opaq flag */
     CHECK_PARSE_LYD(data, LYD_PARSE_OPAQ | LYD_PARSE_ONLY, 0, tree);
@@ -318,8 +265,7 @@ test_opaq(void **state)
             "  <d>val_d</d>\n"
             "</l1>\n";
     PARSER_CHECK_ERROR(data, 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "List instance is missing its key \"c\".",
-            "Data location \"/a:l1[a='val_a'][b='val_b']\", line number 5.");
+            "List instance is missing its key \"c\".", "Schema location /a:l1, data location /a:l1[a='val_a'][b='val_b'], line number 5.");
 
     /* opaq flag */
     CHECK_PARSE_LYD(data, LYD_PARSE_OPAQ | LYD_PARSE_ONLY, 0, tree);
@@ -334,8 +280,7 @@ test_opaq(void **state)
             "  <c>val_c</c>\n"
             "</l1>\n";
     PARSER_CHECK_ERROR(data, 0, LYD_VALIDATE_PRESENT, tree, LY_EVALID,
-            "Invalid type int16 value \"val_c\".",
-            "Data location \"/a:l1[a='val_a'][b='val_b']/c\", line number 4.");
+            "Invalid int16 value \"val_c\".", "Schema location /a:l1/c, data location /a:l1[a='val_a'][b='val_b'], line number 4.");
 
     /* opaq flag */
     CHECK_PARSE_LYD(data, LYD_PARSE_OPAQ | LYD_PARSE_ONLY, 0, tree);
@@ -788,64 +733,6 @@ test_netconf_reply_or_notification(void **state)
     /* TODO */
 }
 
-static void
-test_restconf_rpc(void **state)
-{
-    const char *data;
-    struct ly_in *in;
-    struct lyd_node *tree, *envp;
-
-    assert_non_null((ly_ctx_load_module(UTEST_LYCTX, "ietf-netconf-nmda", "2019-01-07", NULL)));
-
-    assert_int_equal(LY_SUCCESS, lyd_new_path(NULL, UTEST_LYCTX, "/ietf-netconf-nmda:edit-data", NULL, 0, &tree));
-
-    data = "<input xmlns=\"urn:ietf:params:xml:ns:yang:ietf-netconf-nmda\">"
-            "<datastore xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">ds:running</datastore>"
-            "<config>"
-            "<cp xmlns=\"urn:tests:a\"><z xmlns:nc=\"urn:ietf:params:xml:ns:netconf:base:1.0\" nc:operation=\"replace\"/></cp>"
-            "<l1 xmlns=\"urn:tests:a\" xmlns:nc=\"urn:ietf:params:xml:ns:netconf:base:1.0\" nc:operation=\"replace\">"
-            "<a>val_a</a><b>val_b</b><c>val_c</c>"
-            "</l1>"
-            "</config></input>";
-    assert_int_equal(LY_SUCCESS, ly_in_new_memory(data, &in));
-    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, tree, in, LYD_XML, LYD_TYPE_RPC_RESTCONF, &envp, NULL));
-    ly_in_free(in, 0);
-
-    /* the same just connected to the edit-data RPC */
-    data = "<edit-data xmlns=\"urn:ietf:params:xml:ns:yang:ietf-netconf-nmda\">"
-            "<datastore xmlns:ds=\"urn:ietf:params:xml:ns:yang:ietf-datastores\">ds:running</datastore>"
-            "<config>"
-            "<cp xmlns=\"urn:tests:a\"><z xmlns:nc=\"urn:ietf:params:xml:ns:netconf:base:1.0\" nc:operation=\"replace\"/></cp>"
-            "<l1 xmlns=\"urn:tests:a\" xmlns:nc=\"urn:ietf:params:xml:ns:netconf:base:1.0\" nc:operation=\"replace\">"
-            "<a>val_a</a><b>val_b</b><c>val_c</c>"
-            "</l1>"
-            "</config></edit-data>";
-    CHECK_LYD_STRING(tree, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS, data);
-    lyd_free_all(tree);
-    lyd_free_all(envp);
-}
-
-static void
-test_restconf_reply(void **state)
-{
-    const char *data;
-    struct ly_in *in;
-    struct lyd_node *tree, *envp;
-
-    assert_int_equal(LY_SUCCESS, lyd_new_path(NULL, UTEST_LYCTX, "/a:c/act", NULL, 0, &tree));
-
-    data = "<output xmlns=\"urn:tests:a\"><al>25</al></output>";
-    assert_int_equal(LY_SUCCESS, ly_in_new_memory(data, &in));
-    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, lyd_child(tree), in, LYD_XML, LYD_TYPE_REPLY_RESTCONF, &envp, NULL));
-    ly_in_free(in, 0);
-
-    /* connected to the RPC with the parent */
-    data = "<c xmlns=\"urn:tests:a\"><act><al>25</al></act></c>";
-    CHECK_LYD_STRING(tree, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS, data);
-    lyd_free_all(tree);
-    lyd_free_all(envp);
-}
-
 static void
 test_filter_attributes(void **state)
 {
@@ -858,7 +745,6 @@ test_filter_attributes(void **state)
     const char *feats[] = {"writable-running", NULL};
 
     assert_non_null((ly_ctx_load_module(UTEST_LYCTX, "ietf-netconf", "2011-06-01", feats)));
-    assert_non_null((ly_ctx_load_module(UTEST_LYCTX, "notifications", "2008-07-14", NULL)));
 
     data = "<get xmlns=\"urn:ietf:params:xml:ns:netconf:base:1.0\">\n"
             "  <filter type=\"xpath\" select=\"/*\"/>\n"
@@ -877,20 +763,11 @@ test_filter_attributes(void **state)
     dsc = "This parameter specifies the portion of the system\nconfiguration and state data to retrieve.";
     CHECK_LYSC_NODE(node->schema, dsc, 1, LYS_STATUS_CURR | LYS_IS_INPUT, 1, "filter", 0, LYS_ANYXML, 1, 0, NULL, 0);
 
-    CHECK_LYD_STRING(tree, LYD_PRINT_WITHSIBLINGS, data);
-    lyd_free_all(tree);
+    CHECK_LYD_STRING(tree, LYD_PRINT_WITHSIBLINGS,
+            "<get xmlns=\"urn:ietf:params:xml:ns:netconf:base:1.0\">\n"
+            "  <filter type=\"xpath\" select=\"/*\"/>\n"
+            "</get>\n");
 
-    data = "<create-subscription xmlns=\"urn:ietf:params:xml:ns:netconf:notification:1.0\">\n"
-            "  <filter type=\"subtree\">\n"
-            "    <inner-node xmlns=\"my:urn\"/>\n"
-            "  </filter>\n"
-            "</create-subscription>\n";
-    assert_int_equal(LY_SUCCESS, ly_in_new_memory(data, &in));
-    assert_int_equal(LY_SUCCESS, lyd_parse_op(UTEST_LYCTX, NULL, in, LYD_XML, LYD_TYPE_RPC_YANG, &tree, NULL));
-    ly_in_free(in, 0);
-    assert_non_null(tree);
-
-    CHECK_LYD_STRING(tree, LYD_PRINT_WITHSIBLINGS, data);
     lyd_free_all(tree);
 }
 
@@ -926,7 +803,6 @@ main(void)
     const struct CMUnitTest tests[] = {
         UTEST(test_leaf, setup),
         UTEST(test_anydata, setup),
-        UTEST(test_anyxml, setup),
         UTEST(test_list, setup),
         UTEST(test_container, setup),
         UTEST(test_opaq, setup),
@@ -937,8 +813,6 @@ main(void)
         UTEST(test_netconf_rpc, setup),
         UTEST(test_netconf_action, setup),
         UTEST(test_netconf_reply_or_notification, setup),
-        UTEST(test_restconf_rpc, setup),
-        UTEST(test_restconf_reply, setup),
         UTEST(test_filter_attributes, setup),
         UTEST(test_data_skip, setup),
     };
