@@ -386,13 +386,13 @@ test_data_xml(void **state)
     /* test print error */
     TEST_ERROR_XML("TRANGE_0", "-1");
     CHECK_LOG_CTX("error message",
-            "Schema location \"/TRANGE_0:port\", line number 1.");
+            "Schema location /TRANGE_0:port, line number 1.");
     TEST_ERROR_XML("TRANGE_0", "51");
     CHECK_LOG_CTX("error message",
-            "Schema location \"/TRANGE_0:port\", line number 1.");
+            "Schema location /TRANGE_0:port, line number 1.");
     TEST_ERROR_XML("TRANGE_0", "127");
     CHECK_LOG_CTX("error message",
-            "Schema location \"/TRANGE_0:port\", line number 1.");
+            "Schema location /TRANGE_0:port, line number 1.");
 
     /* xml test */
     schema = MODULE_CREATE_YANG("TRANGE_1", "leaf port {type uint8 {"
@@ -407,13 +407,13 @@ test_data_xml(void **state)
     /* test print error */
     TEST_ERROR_XML("TRANGE_1", "0");
     CHECK_LOG_CTX("error message",
-            "Schema location \"/TRANGE_1:port\", line number 1.");
+            "Schema location /TRANGE_1:port, line number 1.");
     TEST_ERROR_XML("TRANGE_1", "51");
     CHECK_LOG_CTX("error message",
-            "Schema location \"/TRANGE_1:port\", line number 1.");
+            "Schema location /TRANGE_1:port, line number 1.");
     TEST_ERROR_XML("TRANGE_1", "127");
     CHECK_LOG_CTX("error message",
-            "Schema location \"/TRANGE_1:port\", line number 1.");
+            "Schema location /TRANGE_1:port, line number 1.");
 
 }
 
